<?php
/**
 * \ingroup cliobject
 * \defgroup configaacl configAacl
 * @{
*/
class Aacl {
    private $aacl, $parent;
    private $adminusers, $admingroups;
    public function __construct($aaclObj, $parentObj) {
        $this->aacl = $aaclObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        aacl_destroy($this->getAaclObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAaclObj() {
        return $this->aacl;
    }
    /**
     * Returns an array with all the available resources
     * @return array
     */
    public function listResources() {
        $resources = array();
        $resIterObj = aacl_resources_iterator_begin($this->getAaclObj());
        if (!Debug::checkError($resIterObj, "_p_aacl_resources_iterator", Debug::INFOERROR, Message::LISTRESOURCES)) return false;
        while (aacl_resources_iterator_has_value($resIterObj)) {
            array_push($resources, aacl_resources_iterator_value($resIterObj));
            aacl_resources_iterator_next($resIterObj);
        }
        aacl_resources_iterator_destroy($resIterObj);
        return $resources;
    }
    /**
     * Returns an array with all the available admin groups
     * @return array
     */
    public function listAdminGroups() {
        $list = array();
        $listObj = aacl_admin_groups_iterator_begin($this->getAaclObj());
        while (aacl_admin_groups_iterator_has_value($listObj)) {
            array_push($list, aacl_admin_groups_iterator_value($listObj));
            aacl_admin_groups_iterator_next($listObj);
        }
        aacl_admin_groups_iterator_destroy($listObj);
        return $list;
    }
    /**
     * Returns an array with all the available admin users
     * @return array
     */
    public function listAdminUsers() {
        $list = array();
        $listObj = aacl_admin_users_iterator_begin($this->getAaclObj());
        while (aacl_admin_users_iterator_has_value($listObj)) {
            array_push($list, aacl_admin_users_iterator_value($listObj));
            aacl_admin_users_iterator_next($listObj);
        }
        aacl_admin_users_iterator_destroy($listObj);
        return $list;
    }
    /**
     * Returns an array with all the available server principals
     * @return array
     */
    public function listServerPrincipals() {
        if (!$this) return false;
        $serprincipals = array();
        $serIterObj = aacl_server_principals_iterator_begin($this->getAaclObj());
        if (!Debug::checkError($serIterObj, "_p_aacl_server_principals_iterator", Debug::INFOERROR, Message::LISTSERVERPRINCIPALS)) return false;
        while (aacl_server_principals_iterator_has_value($serIterObj)) {
            array_push($serprincipals, aacl_server_principals_iterator_value($serIterObj));
            aacl_server_principals_iterator_next($serIterObj);
        }
        aacl_server_principals_iterator_destroy($serIterObj);
        return $serprincipals;
    }
    /**
     * Returns an array with all the available domain principals (per specific domain)
     * @return array
     * @param $domain string the domain name for which you want to see the principals
     */
    public function listDomainPrincipals($domain) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $domprincipals = array();
        load_domain_principals($this->getAaclObj() , $this->getSessionObj() , $domain);
        $domIterObj = aacl_domain_principals_iterator_begin($this->getAaclObj());
        if (!Debug::checkError($domIterObj, "_p_aacl_domain_principals_iterator", Debug::INFOERROR, Message::LISTDOMAINPRINCIPALS)) return false;
        while (aacl_domain_principals_iterator_has_value($domIterObj)) {
            array_push($domprincipals, aacl_domain_principals_iterator_value($domIterObj));
            aacl_domain_principals_iterator_next($domIterObj);
        }
        aacl_domain_principals_iterator_destroy($domIterObj);
        return $domprincipals;
    }
    /**
     * this method purges all resources
     * @return bool
     */
    public function purgeResources() {
        $resp = aacl_purge_resources($this->getAaclObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGERESOURCES);
    }
    /**
     * Adds a new admin group
     * @return bool
     * @param $name string the new group name
     */
    public function addAdminGroup($name) {
        $resp = aacl_admin_group_add($this->getAaclObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDADMINGROUP);
    }
    /**
     * Removes an admin group
     * @return bool
     * @param $name string the group name that will be removed
     * @param $forced string force group removal
     */
    public function removeAdminGroup($name, $forced = false) {
        $resp = aacl_admin_group_remove($this->getAaclObj() , $this->getSessionObj() , $name, $forced);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEADMINGROUP);
    }
    /**
     * Updates an admin group
     * @return object AdminGroup
     * @param $name string the name of the group you want to update
     */
    public function updateAdminGroup($name) {
        if (!$this) return false;
        if (!is_object($this->admingroups[$name])) {
            $admingroupObj = aacl_admin_group_get($this->getAaclObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($admingroupObj, "_p_admin_group", Debug::FATALERROR, Message::LOADAACLADMINGROUP)) return false;
            $this->admingroups[$name] = new AdminGroup($admingroupObj, $this);
        }
        return $this->admingroups[$name];
    }
    /**
     * Adds a new admin user
     * @return bool
     * @param $name string the new user name
     * @param $password string the new user password
     */
    public function addAdminUser($name, $password) {
        $resp = aacl_admin_user_add($this->getAaclObj() , $this->getSessionObj() , $name, $password);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDADMINUSER);
    }
    /**
     * This method removes an admin user
     * @return bool
     * @param $name string the name of the user to be removed
     */
    public function removeAdminUser($name) {
        $resp = aacl_admin_user_remove($this->getAaclObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEADMINUSER);
    }
    /**
     * Updates an admin user
     * @return object AdminUser
     * @param $name string the name of the user to be updated
     */
    public function updateAdminUser($name) {
        if (!$this) return false;
        if (!is_object($this->adminusers[$name])) {
            $adminusersObj = aacl_admin_user_get($this->getAaclObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($adminusersObj, "_p_admin_user", Debug::FATALERROR, Message::LOADAACLADMINUSER)) return false;
            $this->adminusers[$name] = new AdminUser($adminusersObj, $this);
        }
        return $this->adminusers[$name];
    }
}
/** @} */ // end of group
?>
