<?php
/** 
 * \ingroup configCli configFtpBackup configImap configImapProxy configPop3 configPop3Proxy configSmtpIn configWebadmin configWebmail configWebmailProxy
 * \defgroup configAccessControl configAccessControl
 * @{
*/
class AccessControl {
    private $accesscontrol, $parent, $rules;
    public function __construct($accesscontrolObj, $parent) {
        $this->accesscontrol = $accesscontrolObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        access_control_destroy($this->getAccessControlObj());
        if (!is_resource($this->rules)) {
            rules_destroy($this->rules);
        }
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAccessControlObj() {
        return $this->accesscontrol;
    }
    public function getRulesObj() {
        if (!is_resource($this->rules)) {
            $this->rules = access_control_get_rules($this->getAccessControlObj() , $this->getSessionObj());
            if (!Debug::checkError($this->rules, "_p_rules", Debug::FATALERROR, Message::ACCESSCONTROLGETRULES)) return false;
        }
        return $this->rules;
    }
    public function saveRules() {
        $resp = rules_save($this->getRulesObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLSAVERULES);
    }
    /**
     * Returns an array with all the allow rules
     * @return array
     */
    public function listAllowRules() {
        $list = array();
        $rulesIterObj = allow_rule_iterator_begin($this->getRulesObj());
        if (!Debug::checkError($rulesIterObj, "_p_allow_rule_iterator", Debug::INFOERROR, Message::ACCESSCONTROLLISTALLOWRULES)) return false;
        while (allow_rule_iterator_has_value($rulesIterObj)) {
            $ruleObj = allow_rule_iterator_value($rulesIterObj);
            unset($tmp);
            if (allow_rule_is_ip_set_form($ruleObj)) {
                $tmp['ipStart'] = allow_rule_start_ip_get($ruleObj);
                $tmp['ipEnd'] = allow_rule_end_ip_get($ruleObj);
            } else {
                $tmp['network'] = allow_rule_network_get($ruleObj);
                $tmp['netmask'] = allow_rule_netmask_get($ruleObj);
            }
            if (allow_rule_enable_get($ruleObj) == 1) $tmp['enable'] = true;
            else $tmp['enable'] = false;
            $tmp['priority'] = allow_rule_priority_get($ruleObj);
            $tmp['maxConnections'] = allow_rule_maxConnections_get($ruleObj);
            $tmp['maxIntervalConnections'] = allow_rule_maxIntervalConnections_get($ruleObj);
            $tmp['timeInterval'] = allow_rule_timeInterval_get($ruleObj);
            $tmp['peerMaxConnections'] = allow_rule_peerMaxConnections_get($ruleObj);
            $tmp['peerMaxIntervalConnections'] = allow_rule_peerMaxIntervalConnections_get($ruleObj);
            $tmp['peerTimeInterval'] = allow_rule_peerTimeInterval_get($ruleObj);
            array_push($list, $tmp);
            allow_rule_iterator_next($rulesIterObj);
        }
        allow_rule_iterator_destroy($rulesIterObj);
        return $list;
    }
    /**
     *  returns an array with all the deny rules
     * @return array
     */
    public function listDenyRules() {
        $list = array();
        $rulesIterObj = deny_rule_iterator_begin($this->getRulesObj());
        if (!Debug::checkError($rulesIterObj, "_p_deny_rule_iterator", Debug::INFOERROR, Message::ACCESSCONTROLLISTDENYRULES)) return false;
        while (deny_rule_iterator_has_value($rulesIterObj)) {
            $ruleObj = deny_rule_iterator_value($rulesIterObj);
            unset($tmp);
            if (deny_rule_is_ip_set_form($ruleObj)) {
                $tmp['ipStart'] = deny_rule_start_ip_get($ruleObj);
                $tmp['ipEnd'] = deny_rule_end_ip_get($ruleObj);
            } else {
                $tmp['network'] = deny_rule_network_get($ruleObj);
                $tmp['netmask'] = deny_rule_netmask_get($ruleObj);
            }
            if (deny_rule_enable_get($ruleObj) == 1) $tmp['enable'] = true;
            else $tmp['enable'] = false;
            $tmp['priority'] = deny_rule_priority_get($ruleObj);
            array_push($list, $tmp);
            deny_rule_iterator_next($rulesIterObj);
        }
        deny_rule_iterator_destroy($rulesIterObj);
        return $list;
    }
    /**
     * Adds a deny rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string enable rule (optional default: yes)
     * @param $priority int rule priority (optional default: auto)
     */
    public function addDenyRule($ipRangeNetwork, $enable = "yes", $priority = null) {
        if (strstr($ipRangeNetwork, '-')) {
            $tmp = explode("-", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 0;
        } elseif (strstr($ipRangeNetwork, '/')) {
            $tmp = explode("/", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 1;
        } else return false;
        $deny = deny_rule_add($this->getRulesObj() , $start_ip, $end_ip_mask, $is_subnet);
        if (!Debug::checkError($deny, "_p_deny_rule", Debug::INFOERROR, Message::ACCESSCONTROLADDDENYRULE)) return false;
        if (strtolower($enable) == "yes") {
            $resp = deny_rule_enable_set($deny, 1);
        } else {
            $resp = deny_rule_enable_set($deny, 0);
        }
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLDENYRULESETENABLE);
        if (is_int($priority)) {
            $resp = deny_rule_priority_set($deny, $priority);
            Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLDENYRULESETPRIORITY);
        }
        return $this->saveRules();
    }
    /**
     * Removes a deny rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function removeDenyRule($ipRangeNetwork) {
        $resp = rules_deny_rule_remove_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLREMOVEDENYRULE)) return false;
        return $this->saveRules();
    }
    /**
     * This method updates a deny rule
     * @return
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string enable/disable rule (yes/no)
     * @param $priority int rule priority
     */
    public function updateDenyRule($ipRangeNetwork, $enable = null, $priority = null) {
        $deny = rules_deny_rule_get_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($deny, "_p_deny_rule", Debug::INFOERROR, Message::ACCESSCONTROLUPDATEDENYRULE)) return false;
        if (!is_null($enable)) {
            if (strtolower($enable) == "yes") {
                $resp = deny_rule_enable_set($deny, 1);
            } else {
                $resp = deny_rule_enable_set($deny, 0);
            }
            if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLDENYRULESETENABLE)) return false;
        }
        if (is_int($priority)) {
            $resp = deny_rule_priority_set($deny, $priority);
            if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLDENYRULESETPRIORITY)) return false;
        }
        return $this->saveRules();
    }
    /**
     * Adds an allow rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string enable rule (optional default: yes)
     * @param $priority int rule priority (optional default: auto)
     */
    public function addAllowRule($ipRangeNetwork, $enable = "yes", $priority = null) {
        if (strstr($ipRangeNetwork, '-')) {
            $tmp = explode("-", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 0;
        } elseif (strstr($ipRangeNetwork, '/')) {
            $tmp = explode("/", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 1;
        } else return false;
        $allow = allow_rule_add($this->getRulesObj() , $this->getSessionObj() , $start_ip, $end_ip_mask, $is_subnet);
        if (!Debug::checkError($allow, "_p_allow_rule", Debug::INFOERROR, Message::ACCESSCONTROLADDALLOWRULE)) return false;
        if ($enable == "yes") {
            $resp = allow_rule_enable_set($allow, 1);
        } else {
            $resp = allow_rule_enable_set($allow, 0);
        }
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLALLOWRULESETENABLE);
        if (is_int($priority)) {
            $resp = allow_rule_priority_set($allow, $priority);
            Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLALLOWRULESETPRIORITY);
        }
        return $this->saveRules();
    }
    /**
     * Removes an allow rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function removeAllowRule($ipRangeNetwork) {
        $resp = rules_allow_rule_remove_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCESSCONTROLREMOVEALLOWRULE)) return false;
        return $this->saveRules();
    }
    /**
     * Returns an object with an allow rule loaded
     * @return object AllowRule
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function updateAllowRule($ipRangeNetwork) {
        if (!is_object($this->allowrule)) {
            $allow = rules_allow_rule_get_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
            if (!Debug::checkError($allow, "_p_allow_rule", Debug::FATALERROR, Message::ACCESSCONTROLUPDATEALLOWRULE)) return false;
            $this->allowrule = new AllowRule($allow, $this);
        }
        return $this->allowrule;
    }
    /**
     * This method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = access_control_save($this->getAccessControlObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEACCESSCONTROLSDATA);
    }
    /**
     * Set members.
     * <table>
     * <tr><th>member</th><th>description</th>
     * <tr><td>maxConnections</td><td>maximum number of connections</td>
     * <tr><td>timeInterval</td><td>the time interval</td>
     * <tr><td>maxIntervalConnections</td><td>maximum number of connections in time interval</td>
     * <tr><td>peerMaxConnections</td><td>maximum number of connections from a single host</td>
     * <tr><td>peerTimeInterval</td><td>the time interval - single host</td>
     * <tr><td>peerMaxIntervalConnections</td><td>maximum number of connections in time interval - single host
     * </table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "maxconnections":
                $resp = access_control_max_connections_set($this->getAccessControlObj() , $varValue);
            break;
            case "timeinterval":
                $resp = access_control_time_interval_set($this->getAccessControlObj() , $varValue);
            break;
            case "maxintervalconnections":
                $resp = access_control_max_interval_connections_set($this->getAccessControlObj() , $varValue);
            break;
            case "peermaxconnections":
                $resp = access_control_peer_max_connections_set($this->getAccessControlObj() , $varValue);
            break;
            case "peertimeinterval":
                $resp = access_control_peer_time_interval_set($this->getAccessControlObj() , $varValue);
            break;
            case "peermaxintervalconnections":
                $resp = access_control_peer_max_interval_connections_set($this->getAccessControlObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETALLOWRULE);
                return false;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETALLOWRULE);
    }

    /**
     * Get members.
     * <table>
     * <tr><th>member</th><th>description</th>
     * <tr><td>maxConnections</td><td>maximum number of connections</td>
     * <tr><td>timeInterval</td><td>the time interval</td>
     * <tr><td>maxIntervalConnections</td><td>maximum number of connections in time interval</td>
     * <tr><td>peerMaxConnections</td><td>maximum number of connections from a single host</td>
     * <tr><td>peerTimeInterval</td><td>the time interval - single host</td>
     * <tr><td>peerMaxIntervalConnections</td><td>maximum number of connections in time interval - single host
     * </table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "maxconnections":
                return access_control_max_connections_get($this->getAccessControlObj());
            break;
            case "timeinterval":
                return access_control_time_interval_get($this->getAccessControlObj());
            break;
            case "maxintervalconnections":
                return access_control_max_interval_connections_get($this->getAccessControlObj());
            break;
            case "peermaxconnections":
                return access_control_peer_max_connections_get($this->getAccessControlObj());
            break;
            case "peertimeinterval":
                return access_control_peer_time_interval_get($this->getAccessControlObj());
            break;
            case "peermaxintervalconnections":
                return access_control_peer_max_interval_connections_get($this->getAccessControlObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETALLOWRULE);
        }
    }
}
/** @} */ // end of group
?>
