<?php
/**
 * \ingroup updateDomain
 * \defgroup updateAccountClass updateAccountClass
 * @{ 
*/
class AccountClass {
    public $accountClass, $parent, $filters, $quotas, $limits, $sendRecvRestrictions, $webmailAdvertising;
    public function __construct($accountClassObj, $parent) {
        $this->accountClass = $accountClassObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        account_class_destroy($this->getAccountClassObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAccountClassObj() {
        return $this->accountClass;
    }
    /**
     * Returns the Filters object for the selected account class
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = account_class_filters_get($this->getAccountClassObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADACCOUNTCLASSFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * Returns the Quotas object for the selected account class
     * @return object Quotas
     */
    public function configQuotas() {
        if (!$this) return false;
        if (!is_object($this->quotas)) {
            $quotasObj = account_class_quotas_get($this->getAccountClassObj() , $this->getSessionObj());
            if (!Debug::checkError($quotasObj, "_p_quotas", Debug::FATALERROR, Message::LOADACCOUNTCLASSQUOTAS)) return false;
            $this->quotas = new Quotas($quotasObj, $this);
        }
        return $this->quotas;
    }
    /**
     * Returns the Limits object for the selected account class
     * @return object Limits
     */
    public function configLimits() {
        if (!$this) return false;
        if (!is_object($this->limits)) {
            $accountDLimitsObj = account_class_limits_get($this->getAccountClassObj() , $this->getSessionObj());
            if (!Debug::checkError($accountDLimitsObj, "_p_limits", Debug::FATALERROR, Message::LOADACCOUNTCLASSLIMITS)) return false;
            $this->limits = new Limits($accountDLimitsObj, $this);
        }
        return $this->limits;
    }
    /**
     * Returns an object of SendRecvRestrictions type for the selected account class
     * @return object SendRecvRestrictions
     */
    public function configSendRecvRestrictions() {
        if (!$this) return false;
        if (!is_object($this->sendRecvRestrictions)) {
            $sendRecvObj = account_class_send_recv_restrictions($this->getAccountClassObj() , $this->getSessionObj());
            if (!Debug::checkError($sendRecvObj, "_p_send_recv_restrictions", Debug::FATALERROR, Message::ACCOUNTCLASSLOADSENDRECV)) return false;
            $this->sendRecvRestrictions = new SendRecvRestrictions($sendRecvObj, $this);
        }
        return $this->sendRecvRestrictions;
    }
    /**
     * Saves the changed members of the account class
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = account_class_save($this->getAccountClassObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEACCOUNTCLASSDATA);
    }
    /**
     * Set members.
     * Use "name" to set the account class name
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                $resp = account_class_name_set($this->getAccountClassObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETACCOUNTCLASSVARERROR);
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETACCOUNTCLASSVARERROR);
    }
    /**
     * Get members.
     * Use "name" to get the account class name.
     */
    public function __get($varName) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                return account_class_name_get($this->getAccountClassObj());
            break;
            case "storageId":
                return account_class_storage_id_get($this->getAccountClassObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETACCOUNTCLASSVARERROR);
        }
    }
}
/** @} */ // end of group
?>
