<?php
/**
 * \ingroup configAacl
 * \defgroup updateAdminGroup updateAdminGroup
 * @{
 */
class AdminGroup {
    private $admingroup, $parent;
    private $domaineffective, $domain, $serverefective, $server;
    public function __construct($admingroupObj, $parentObj) {
        $this->admingroup = $admingroupObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        admin_group_destroy($this->getAdminGroupObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAdminGroupObj() {
        return $this->admingroup;
    }
    /**
     * Returns an array with all the group's parents
     * @return array
     */
    public function listParents() {
        if (!$this) return false;
        return $this->getAllGroupParents();
    }
    private function getAllGroupParents($obj = null) {
        if (is_null($obj)) {
            $obj = $this->getAdminGroupObj();
        }
        $tmp = array();
        $adminIterObj = admin_group_parent_iterator_begin($obj);
        if (!Debug::checkError($adminIterObj, "_p_admin_group_parent_iterator", Debug::INFOERROR, Message::LOADADMINGROUPPARENTS)) return false;
        while (admin_group_parent_iterator_has_value($adminIterObj)) {
            $groupname = admin_group_parent_iterator_value($adminIterObj);
            $groupObj = aacl_admin_group_get($this->parent->getAaclObj() , $this->getSessionObj() , $groupname);
            $tmp[$groupname] = $this->getAllGroupParents($groupObj);
            admin_group_destroy($groupObj);
            admin_group_parent_iterator_next($adminIterObj);
        }
        admin_group_parent_iterator_destroy($adminIterObj);
        return $tmp;
    }

    /**
    * Returns an array with all the avaible domains
    * @return array
    */
    public function listAvailableDomains() {
        $domains = array();
        $dObj = admin_group_domain_permissions_iterator_begin( $this->getAdminGroupObj() );
        while ( admin_group_domain_permissions_iterator_has_value( $dObj ) ){
            $domains[] = admin_group_domain_permissions_iterator_domain_name( $dObj );
            admin_group_domain_permissions_iterator_next( $dObj );
        }
        admin_group_domain_permissions_iterator_destroy( $dObj);

        return $domains;
    }


    /**
     * Returns an array with all the members
     * @return array
     */
    public function listMembers() {
        if (!$this) return false;
        return $this->getAllGroupMembers();
    }
    private function getAllGroupMembers($obj = null) {
        if (is_null($obj)) {
            $obj = $this->getAdminGroupObj();
        }
        $tmp = array();
        $tmp['Users'] = $this->listUserMembers($obj);
        $adminIterObj = group_members_iterator_begin($obj);
        if (!Debug::checkError($adminIterObj, "_p_group_members_iterator", Debug::INFOERROR, Message::LOADADMINGROUPGROUPMEMBERS)) return false;
        while (group_members_iterator_has_value($adminIterObj)) {
            $groupname = group_members_iterator_value($adminIterObj);
            $groupObj = aacl_admin_group_get($this->parent->getAaclObj() , $this->getSessionObj() , $groupname);
            $group[$groupname] = $this->getAllGroupMembers($groupObj);
            $tmp['Groups'] = $group;
            admin_group_destroy($groupObj);
            group_members_iterator_next($adminIterObj);
        }
        group_members_iterator_destroy($adminIterObj);
        return $tmp;
    }
    private function listUserMembers($obj) {
        $admingrouplist = array();
        $adminIterObj = user_members_iterator_begin($obj);
        if (!Debug::checkError($adminIterObj, "_p_user_members_iterator", Debug::INFOERROR, Message::LOADADMINGROUPUSERMEMBERS)) return false;
        while (user_members_iterator_has_value($adminIterObj)) {
            array_push($admingrouplist, user_members_iterator_value($adminIterObj));
            user_members_iterator_next($adminIterObj);
        }
        user_members_iterator_destroy($adminIterObj);
        return $admingrouplist;
    }
    /**
     * This method adds a new parent group
     * @return bool
     * @param $parentGroup string the parent group that you want to add
     */
    public function addParentGroup($parentGroup) {
        $resp = admin_group_add_parent_group($this->getAdminGroupObj() , $this->getSessionObj() , $parentGroup);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDADMINGROUPPARENT);
    }
    /**
     * Removes a parent group
     * @return bool
     * @param $parentGroup string the parent group that you want to remove
     */
    public function removeParentGroup($parentGroup) {
        $resp = admin_group_remove_parent_group($this->getAdminGroupObj() , $this->getSessionObj() , $parentGroup);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEADMINGROUPPARENT);
    }
    /**
     * this method returns an object with all the effective permissions loaded
     * @return object Permissions
     * @param $domain string  the domain name from where the permission will be loaded; if it is null, the server permissions will be loaded (this parameter is optional - server is default)
     */
    public function getEffectivePermissions($domain = null) {
        if (is_null($domain)) {
            if (!is_object($this->serverefective)) {
                $permissionsObj = admin_group_get_effective_permissions_on_server($this->getAdminGroupObj() , $this->getSessionObj());
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADGROUPPERMISSION)) return false;
                $this->serverefective = new Permissions($permissionsObj, $this);
                $this->serverefective->effective = true;
                $this->serverefective->type = "server";
            }
            return $this->serverefective;
        } else {
            if (!is_object($this->domaineffective[$domain])) {
                $permissionsObj = admin_group_get_effective_permissions_on_domain($this->getAdminGroupObj() , $this->getSessionObj() , $domain);
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADGROUPPERMISSION)) return false;
                $this->domaineffective[$domain] = new Permissions($permissionsObj, $this);
                $this->domaineffective[$domain]->effective = true;
                $this->domaineffective[$domain]->type = "domain";
            }
            return $this->domaineffective[$domain];
        }
    }
    /**
     * this method returns an object with all the permissions loaded
     * @return object Permissions
     * @param $domain string the domain name from where the permission will be loaded; if it is null, the server permissions will be loaded (this parameter is optional - server is default)
     */
    public function getPermissions($domain = null) {
        if (is_null($domain)) {
            if (!is_object($this->server)) {
                $permissionsObj = admin_group_get_server_permissions($this->getAdminGroupObj());
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADGROUPPERMISSION)) return false;
                $this->server = new Permissions($permissionsObj, $this);
                $this->server->effective = false;
                $this->server->type = "server";
            }
            return $this->server;
        } else {
            if (!is_object($this->domain[$domain])) {
                $permissionsObj = admin_group_get_domain_permissions($this->getAdminGroupObj() , $domain);
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADGROUPPERMISSION)) return false;
                $this->domain[$domain] = new Permissions($permissionsObj, $this);
                $this->domain[$domain]->effective = false;
                $this->domain[$domain]->type = "domain";
            }
            return $this->domain[$domain];
        }
    }
    public function savePermissions($permissions) {
        return admin_group_permissions_save($permissions, $this->getAdminGroupObj() , $this->getSessionObj());
    }
    /**
     * Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>group name</td>
<tr><td>description</td><td>group description</td>
</table>
    */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                $resp = admin_group_name_set($this->getAdminGroupObj() , $varValue);
            break;
            case "description":
                $resp = admin_group_description_set($this->getAdminGroupObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETADMINGROUPVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETADMINGROUPVARERROR);
    }
    /**
     * Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>group name</td>
<tr><td>description</td><td>group description</td>
</table>
    */
    public function __get($varName) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                return admin_group_name_get($this->getAdminGroupObj());
            break;
            case "description":
                return admin_group_description_get($this->getAdminGroupObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETADMINGROUPVARERROR);
        }
    }
}
/** @} */ // end of group
?>
