<?php
/** 
 * \ingroup updateDomain
 * \defgroup configAdminLimits configAdminLimits
 * @{
*/
class AdminLimits {
    private $adminlimits, $parent, $services;
    public function __construct($adminlimitsObj, $parentObj) {
        $this->adminlimits = $adminlimitsObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        admin_limits_destroy($this->getAdminLimitsObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAdminLimitsObj() {
        return $this->adminlimits;
    }
    public function getServices() {
        if (!is_resource($this->services)) {
            $this->services = admin_limits_available_services_get($this->getAdminLimitsObj());
            if (!Debug::checkError($this->services, "_p_services", Debug::FATALERROR, Message::GETADMINLIMITSSSERVICES)) return false;
        }
        return $this->services;
    }
    /**
     * This method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = admin_limits_save($this->getAdminLimitsObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEADMINLIMITSDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxAccounts</td>
<td>maxAccounts on domain admin limits</td>
<tr><td>maxMaillists</td>
<td>maxMaillists on domain admin limits</td>
<tr><td>maxGroups</td>
<td>maxGroups on domain admin limits</td>
<tr><td>maxFolderRecipients</td>
<td>maxFolderRecipients on domain admin limits</td>
<tr><td>maxAccountClasses</td>
<td>maxAccountClasses on domain admin limits</td>
<tr><td>maxAccountMessageSizeQuota</td>
<td>maxAccountMessageSizeQuota on domain admin limits</td>
<tr><td>maxAccountMessageCountQuota</td>
<td>maxAccountMessageCountQuota on domain admin limits</td>
<tr><td>maxAccountFolderCountQuota</td>
<td>maxAccountFolderCountQuota on domain admin limits</td>
<tr><td>maxAccountFolderMessageSizeQuota</td>
<td>maxAccountFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxAccountFolderMessageCountQuota</td>
<td>maxAccountFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxMaillistMessageSizeQuota</td>
<td>maxMaillistMessageSizeQuota on domain admin limits</td>
<tr><td>maxMaillistMessageCountQuota</td>
<td>maxMaillistMessageCountQuota on domain admin limits</td>
<tr><td>maxMaillistFolderCountQuota</td>
<td>maxMaillistFolderCountQuota on domain admin limits</td>
<tr><td>maxMaillistFolderMessageSizeQuota</td>
<td>maxMaillistFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxMaillistFolderMessageCountQuota</td>
<td>maxMaillistFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderMessageSizeQuota</td>
<td>maxPublicFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxPublicFolderMessageCountQuota</td>
<td>maxPublicFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderCountQuota</td>
<td>maxPublicFolderFolderCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderMessageSizeQuota</td>
<td>maxPublicFolderFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderMessageCountQuota</td>
<td>maxPublicFolderFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxSubdomains</td>
<td>maxSubdomains on domain admin limits</td>
<tr><td>subdomainStorageLocation</td>
<td>subdomainStorageLocation on domain admin limits</td>
<tr><td>subdomainObjectStorageLocation</td>
<td>subdomainObjectStorageLocation on domain admin limits</td>
<tr><td>enableSmtpIncoming</td>
<td>the enable/disable status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enable/disable status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enable/disable status for POP3</td>
<tr><td>enableRpop</td>
<td>the enable/disable status for RPOP</td>
<tr><td>enableImap</td>
<td>the enable/disable status for IMAP</td>
<tr><td>enableWebmail</td>
<td>the enable/disable status for Webmail</td>
<tr><td>purgeConstraint</td>
<td>the purge search constraint</td>
<tr><td>purgeFolders </td>
<td>the allowed folders for purge (list is separated by , and names with spaces are between brackets)</td>
<tr><td>maxActiveSyncMailboxCount</td>
<td>maxActiveSyncMailboxCount on domain admin limits</td>
<tr><td>maxIAMailboxCount</td>
<td>maxIAMailboxCount on domain admin limits</td>
<tr><td>maxKASMailboxCount</td>
<td>maxKASMailboxCount on domain admin limits</td>
<tr><td>maxKAVMailboxCount</td>
<td>maxKAVMailboxCount on domain admin limits</td>
<tr><td>maxOutlookConnectorMailboxCount</td>
<td>maxOutlookConnectorMailboxCount on domain admin limits</td>
<tr><td>maxPersonalOrganizerMailboxCount</td>
<td>maxPersonalOrganizerMailboxCount on domain admin limits</td>
<tr><td>maxPremiumMailboxCount</td>
<td>maxPersonalOrganizerMailboxCount on domain admin limits</td>
<tr><td>maxSharingMailboxCount</td>
<td>maxSharingMailboxCount on domain admin limits</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "maxaccounts":
                $resp = admin_limits_max_accounts_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillists":
                $resp = admin_limits_max_maillists_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxgroups":
                $resp = admin_limits_max_groups_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxfolderrecipients":
                $resp = admin_limits_max_folder_recipients_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountclasses":
                $resp = admin_limits_max_account_classes_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountmessagesizequota":
                $resp = admin_limits_max_account_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountmessagecountquota":
                $resp = admin_limits_max_account_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountfoldercountquota":
                $resp = admin_limits_max_account_folder_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountfoldermessagesizequota":
                $resp = admin_limits_max_account_folder_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxaccountfoldermessagecountquota":
                $resp = admin_limits_max_account_folder_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillistmessagesizequota":
                $resp = admin_limits_max_maillist_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillistmessagecountquota":
                $resp = admin_limits_max_maillist_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillistfoldercountquota":
                $resp = admin_limits_max_maillist_folder_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillistfoldermessagesizequota":
                $resp = admin_limits_max_maillist_folder_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxmaillistfoldermessagecountquota":
                $resp = admin_limits_max_maillist_folder_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpublicfoldermessagesizequota":
                $resp = admin_limits_max_public_folder_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpublicfoldermessagecountquota":
                $resp = admin_limits_max_public_folder_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpublicfolderfoldercountquota":
                $resp = admin_limits_max_public_folder_folder_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpublicfolderfoldermessagesizequota":
                $resp = admin_limits_max_public_folder_folder_message_size_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpublicfolderfoldermessagecountquota":
                $resp = admin_limits_max_public_folder_folder_message_count_quota_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxsubdomains":
                $resp = admin_limits_max_subdomains_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "subdomainstoragelocation":
                $resp = admin_limits_subdomain_storage_location_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "subdomainobjectstoragelocation":
                $resp = admin_limits_subdomain_object_storage_location_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "enablesmtpincoming":
                $resp = services_smtp_incoming_set_enable($this->getServices() , $varValue);
            break;
            case "enablesmtpoutgoing":
                $resp = services_smtp_outgoing_set_enable($this->getServices() , $varValue);
            break;
            case "enablepop3":
                $resp = services_pop3_set_enable($this->getServices() , $varValue);
            break;
            case "enablerpop":
                $resp = services_rpop_set_enable($this->getServices() , $varValue);
            break;
            case "enableimap":
                $resp = services_imap_set_enable($this->getServices() , $varValue);
            break;
            case "enablewebmail":
                $resp = services_webmail_set_enable($this->getServices() , $varValue);
            break;
            case "purgefolders":
                $resp = admin_limits_purge_folders_set($this->getAdminLimitsObj() , "({$varValue})");
            break;
            case "purgeconstraint":
                $resp = admin_limits_purge_constraint_set($this->getAdminLimitsObj() , $varValue);
            break;


            case "maxactivesyncmailboxcount":
                $resp = admin_limits_max_activesync_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxiamailboxcount":
                $resp = admin_limits_max_ia_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxkasmailboxcount":
                $resp = admin_limits_max_kas_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxkavmailboxcount":
                $resp = admin_limits_max_kav_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxoutlookconnectormailboxcount":
                $resp = admin_limits_max_outlook_connector_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpersonalorganizermailboxcount":
                $resp = admin_limits_max_personal_organizer_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxpremiummailboxcount":
                $resp = admin_limits_max_premium_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;
            case "maxsharingmailboxcount":
                $resp = admin_limits_max_sharing_mailbox_count_set($this->getAdminLimitsObj() , $varValue);
            break;


            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETADMINLIMITSVARERROR);
                return -1;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETADMINLIMITSVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxAccounts</td>
<td>maxAccounts on domain admin limits</td>
<tr><td>maxMaillists</td>
<td>maxMaillists on domain admin limits</td>
<tr><td>maxGroups</td>
<td>maxGroups on domain admin limits</td>
<tr><td>maxFolderRecipients</td>
<td>maxFolderRecipients on domain admin limits</td>
<tr><td>maxAccountClasses</td>
<td>maxAccountClasses on domain admin limits</td>
<tr><td>maxAccountMessageSizeQuota</td>
<td>maxAccountMessageSizeQuota on domain admin limits</td>
<tr><td>maxAccountMessageCountQuota</td>
<td>maxAccountMessageCountQuota on domain admin limits</td>
<tr><td>maxAccountFolderCountQuota</td>
<td>maxAccountFolderCountQuota on domain admin limits</td>
<tr><td>maxAccountFolderMessageSizeQuota</td>
<td>maxAccountFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxAccountFolderMessageCountQuota</td>
<td>maxAccountFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxMaillistMessageSizeQuota</td>
<td>maxMaillistMessageSizeQuota on domain admin limits</td>
<tr><td>maxMaillistMessageCountQuota</td>
<td>maxMaillistMessageCountQuota on domain admin limits</td>
<tr><td>maxMaillistFolderCountQuota</td>
<td>maxMaillistFolderCountQuota on domain admin limits</td>
<tr><td>maxMaillistFolderMessageSizeQuota</td>
<td>maxMaillistFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxMaillistFolderMessageCountQuota</td>
<td>maxMaillistFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderMessageSizeQuota</td>
<td>maxPublicFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxPublicFolderMessageCountQuota</td>
<td>maxPublicFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderCountQuota</td>
<td>maxPublicFolderFolderCountQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderMessageSizeQuota</td>
<td>maxPublicFolderFolderMessageSizeQuota on domain admin limits</td>
<tr><td>maxPublicFolderFolderMessageCountQuota</td>
<td>maxPublicFolderFolderMessageCountQuota on domain admin limits</td>
<tr><td>maxSubdomains</td>
<td>maxSubdomains on domain admin limits</td>
<tr><td>subdomainStorageLocation</td>
<td>subdomainStorageLocation on domain admin limits</td>
<tr><td>subdomainObjectStorageLocation</td>
<td>subdomainObjectStorageLocation on domain admin limits</td>
<tr><td>enableSmtpIncoming</td>
<td>the enable/disable status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enable/disable status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enable/disable status for POP3</td>
<tr><td>enableRpop</td>
<td>the enable/disable status for RPOP</td>
<tr><td>enableImap</td>
<td>the enable/disable status for IMAP</td>
<tr><td>enableWebmail</td>
<td>the enable/disable status for Webmail</td>
<tr><td>purgeConstraint</td>
<td>the purge search constraint</td>
<tr><td>purgeFolders </td>
<td>the allowed folders for purge (list is separated by , and names with spaces are between brackets)</td>
<tr><td>maxActiveSyncMailboxCount</td>
<td>maxActiveSyncMailboxCount on domain admin limits</td>
<tr><td>maxIAMailboxCount</td>
<td>maxIAMailboxCount on domain admin limits</td>
<tr><td>maxKASMailboxCount</td>
<td>maxKASMailboxCount on domain admin limits</td>
<tr><td>maxKAVMailboxCount</td>
<td>maxKAVMailboxCount on domain admin limits</td>
<tr><td>maxOutlookConnectorMailboxCount</td>
<td>maxOutlookConnectorMailboxCount on domain admin limits</td>
<tr><td>maxPersonalOrganizerMailboxCount</td>
<td>maxPersonalOrganizerMailboxCount on domain admin limits</td>
<tr><td>maxPremiumMailboxCount</td>
<td>maxPersonalOrganizerMailboxCount on domain admin limits</td>
<tr><td>maxSharingMailboxCount</td>
<td>maxSharingMailboxCount on domain admin limits</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "maxaccounts":
                return admin_limits_max_accounts_get($this->getAdminLimitsObj());
            break;
            case "maxmaillists":
                return admin_limits_max_maillists_get($this->getAdminLimitsObj());
            break;
            case "maxgroups":
                return admin_limits_max_groups_get($this->getAdminLimitsObj());
            break;
            case "maxfolderrecipients":
                return admin_limits_max_folder_recipients_get($this->getAdminLimitsObj());
            break;
            case "maxaccountclasses":
                return admin_limits_max_account_classes_get($this->getAdminLimitsObj());
            break;
            case "maxaccountmessagesizequota":
                return admin_limits_max_account_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxaccountmessagecountquota":
                return admin_limits_max_account_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxaccountfoldercountquota":
                return admin_limits_max_account_folder_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxaccountfoldermessagesizequota":
                return admin_limits_max_account_folder_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxaccountfoldermessagecountquota":
                return admin_limits_max_account_folder_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxmaillistmessagesizequota":
                return admin_limits_max_maillist_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxmaillistmessagecountquota":
                return admin_limits_max_maillist_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxmaillistfoldercountquota":
                return admin_limits_max_maillist_folder_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxmaillistfoldermessagesizequota":
                return admin_limits_max_maillist_folder_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxmaillistfoldermessagecountquota":
                return admin_limits_max_maillist_folder_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxpublicfoldermessagesizequota":
                return admin_limits_max_public_folder_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxpublicfoldermessagecountquota":
                return admin_limits_max_public_folder_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxpublicfolderfoldercountquota":
                return admin_limits_max_public_folder_folder_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxpublicfolderfoldermessagesizequota":
                return admin_limits_max_public_folder_folder_message_size_quota_get($this->getAdminLimitsObj());
            break;
            case "maxpublicfolderfoldermessagecountquota":
                return admin_limits_max_public_folder_folder_message_count_quota_get($this->getAdminLimitsObj());
            break;
            case "maxsubdomains":
                return admin_limits_max_subdomains_get($this->getAdminLimitsObj());
            break;
            case "subdomainstoragelocation":
                return admin_limits_subdomain_storage_location_get($this->getAdminLimitsObj());
            break;
            case "subdomainobjectstoragelocation":
                return admin_limits_subdomain_object_storage_location_get($this->getAdminLimitsObj());
            break;
            case "enablesmtpincoming":
                return services_smtp_incoming_is_enable($this->getServices());
            break;
            case "enablesmtpoutgoing":
                return services_smtp_outgoing_is_enable($this->getServices());
            break;
            case "enablepop3":
                return services_pop3_is_enable($this->getServices());
            break;
            case "enablerpop":
                return services_rpop_is_enable($this->getServices());
            break;
            case "enableimap":
                return services_imap_is_enable($this->getServices());
            break;
            case "enablewebmail":
                return services_webmail_is_enable($this->getServices());
            break;
            case "purgeconstraint":
                return admin_limits_purge_constraint_get($this->getAdminLimitsObj());
            break;
            case "purgefolders":
                return admin_limits_purge_folders_get($this->getAdminLimitsObj());
            break;


            case "maxactivesyncmailboxcount":
                return admin_limits_max_activesync_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxiamailboxcount":
                return admin_limits_max_ia_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxkasmailboxcount":
                return admin_limits_max_kas_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxkavmailboxcount":
                return admin_limits_max_kav_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxoutlookconnectormailboxcount":
                return admin_limits_max_outlook_connector_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxpersonalorganizermailboxcount":
                return admin_limits_max_personal_organizer_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxpremiummailboxcount":
                return admin_limits_max_premium_mailbox_count_get($this->getAdminLimitsObj());
            break;
            case "maxsharingmailboxcount":
                return admin_limits_max_sharing_mailbox_count_get($this->getAdminLimitsObj());
            break;


            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETADMINLIMITSVARERROR);
                return;
        }
    }
    /**
     * List message storage locations for this sub-domain
     * @return array
     */
    public function listSubdomainMessageStorageLocations() {
        if (!$this) return false;
        $list = array();
        $iterObj = admin_limits_subdomainMessageStorageLocation_iterator_begin($this->getAdminLimitsObj());
        if (!Debug::checkError($iterObj, "_p_admin_limits_subdomainMessageStorageLocation_iterator", Debug::INFOERROR, Message::LISTADMINLIMITSMESSAGES)) return false;
        while (admin_limits_subdomainMessageStorageLocation_iterator_has_value($iterObj)) {
            $obj = admin_limits_subdomainMessageStorageLocation_iterator_value($iterObj);
            array_push($list, admin_limits_subdomainMessageStorageLocation_get_name($obj));
            admin_limits_subdomainMessageStorageLocation_iterator_next($iterObj);
        }
        admin_limits_subdomainMessageStorageLocation_iterator_destroy($iterObj);
        return $list;
    }
    /**
     * Adds a message storage location for this sub-domain
     * @return bool
     * @param $path string the message storage location path
     */
    public function addSubdomainMessageStorageLocation($path) {
        if (!$this) return false;
        if (!is_string($path)) return false;
        $resp = admin_limits_subdomain_message_storage_location_add($this->getAdminLimitsObj() , $this->getSessionObj() , $path);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADMINLIMITSADDMESSAGE);
    }
    /**
     * Removes a message storage location for this sub-domain
     * @return bool
     * @param $path string the message storage location path
     */
    public function removeSubdomainMessageStorageLocation($path) {
        if (!$this) return false;
        if (!is_string($path)) return false;
        $resp = admin_limits_subdomain_message_storage_location_remove($this->getAdminLimitsObj() , $this->getSessionObj() , $path);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADMINLIMITSREMOVEMESSAGE);
    }

    /**
     * list the reserved rcpts
     * @return array
     */
    public function listReservedRcpts() {
        if (!$this) return false;
        $list = array();
        $iterObj = admin_limits_reservedRcpt_iterator_begin($this->getAdminLimitsObj());
        if (!Debug::checkError($iterObj, "_p_admin_limits_reservedRcpt_iterator", Debug::INFOERROR, Message::LISTADMINLIMITSRESERVEDRCPT)) return false;
        while (admin_limits_reservedRcpt_iterator_has_value($iterObj)) {
            $obj = admin_limits_reservedRcpt_iterator_value($iterObj);
            array_push($list, admin_limits_reservedRcpt_get_name($obj));
            admin_limits_reservedRcpt_iterator_next($iterObj);
        }
        admin_limits_reservedRcpt_iterator_destroy($iterObj);
        return $list;
    }
    /**
     * adds a new reserved rcpt
     * @return bool
     * @param $reservedRcpt string the reserved rcpt
     */
    public function addReservedRcpt($reservedRcpt) {
        if (!$this) return false;
        if (!is_string($reservedRcpt)) return false;
        $resp = admin_limits_reserved_rcpt_add($this->getAdminLimitsObj() , $this->getSessionObj() , $reservedRcpt);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADMINLIMITSADRESERVEDRCPT);
    }
    /**
     * removes a reserved rcpt from list
     * @return bool
     * @param $reservedRcpt string the reserved rcpt
     */
    public function removeReservedRcpt($reservedRcpt) {
        if (!$this) return false;
        if (!is_string($reservedRcpt)) return false;
        $resp = admin_limits_reserved_rcpt_remove($this->getAdminLimitsObj() , $this->getSessionObj() , $reservedRcpt);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADMINLIMITSREMOVERESERVEDRCPT);
    }
}
/** @} */ // end of group
?>
