<?php
/**
 * \ingroup configAacl
 * \defgroup updateAdminUser updateAdminUser
 * @{
*/
class AdminUser {
    private $adminuser, $parent;
    private $domaineffective, $domain, $serverefective, $server;
    public function __construct($adminuserObj, $parentObj) {
        $this->adminuser = $adminuserObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        admin_user_destroy($this->getAdminUserObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAdminUserObj() {
        return $this->adminuser;
    }
    /**
     * Returns an array with all user's parents
     * @return array
     */
    public function listParents() {
        return $this->getAllUserParents();
    }
    private function getAllUserParents($obj = null) {
        if (is_null($obj)) {
            $obj = $this->getAdminUserObj();
        }
        $tmp = array();
        $adminIterObj = admin_user_parent_iterator_begin($obj);
        if (!Debug::checkError($adminIterObj, "_p_admin_user_parent_iterator", Debug::INFOERROR, Message::LOADADMINUSERPARENTS)) return false;
        while (admin_user_parent_iterator_has_value($adminIterObj)) {
            $groupname = admin_user_parent_iterator_value($adminIterObj);
            $groupObj = aacl_admin_group_get($this->parent->getAaclObj() , $this->getSessionObj() , $groupname);
            $tmp[$groupname] = $this->getAllGroupParents($groupObj);
            admin_user_destroy($userObj);
            admin_user_parent_iterator_next($adminIterObj);
        }
        admin_user_parent_iterator_destroy($adminIterObj);
        return $tmp;
    }
    private function getAllGroupParents($obj) {
        $tmp = array();
        $adminIterObj = admin_group_parent_iterator_begin($obj);
        if (!Debug::checkError($adminIterObj, "_p_admin_group_parent_iterator", Debug::INFOERROR, Message::LOADADMINUSERPARENTS)) return false;
        while (admin_group_parent_iterator_has_value($adminIterObj)) {
            $groupname = admin_group_parent_iterator_value($adminIterObj);
            $groupObj = aacl_admin_group_get($this->parent->getAaclObj() , $this->getSessionObj() , $groupname);
            $tmp[$groupname] = $this->getAllGroupParents($groupObj);
            admin_group_destroy($groupObj);
            admin_group_parent_iterator_next($adminIterObj);
        }
        admin_group_parent_iterator_destroy($adminIterObj);
        return $tmp;
    }
    /**
     * Adds a new parent group
     * @return bool
     * @param $parentGroup string the parent group that you want to add
     */
    public function addParentGroup($parentGroup) {
        $resp = admin_user_add_parent_group($this->getAdminUserObj() , $this->getSessionObj() , $parentGroup);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDADMINUSERPARENT);
    }
    /**
     * this method removes a parent group
     * @return bool
     * @param $parentGroup string the parent group that you want to remove
     */
    public function removeParentGroup($parentGroup) {
        $resp = admin_user_remove_parent_group($this->getAdminUserObj() , $this->getSessionObj() , $parentGroup);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEADMINUSERPARENT);
    }
    /**
     * Returns an object with all the effective permissions loaded.
     * Note: the returned object is read only, use getPermissions if you need to grant, deny or revoke rights
     * @return object Permissions
     * @param $domain string the domain name from where the permission will be loaded, if it's null the server permissions will be loaded (this parameter is optional - server is default)
     */
    public function getEffectivePermissions($domain = null) {
        if (is_null($domain)) {
            if (!is_object($this->serverefective)) {
                $permissionsObj = admin_user_get_effective_permissions_on_server($this->getAdminUserObj() , $this->getSessionObj());
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADUSERPERMISSION)) return false;
                $this->serverefective = new Permissions($permissionsObj, $this);
                $this->serverefective->effective = true;
                $this->serverefective->type = "server";
            }
            return $this->serverefective;
        } else {
            if (!is_object($this->domaineffective[$domain])) {
                $permissionsObj = admin_user_get_effective_permissions_on_domain($this->getAdminUserObj() , $this->getSessionObj() , $domain);
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADUSERPERMISSION)) return false;
                $this->domaineffective[$domain] = new Permissions($permissionsObj, $this);
                $this->domaineffective[$domain]->effective = true;
                $this->domaineffective[$domain]->type = "domain";
            }
            return $this->domaineffective[$domain];
        }
    }
    /**
    * Returns an array with all the available domains
    * @return array
    */
    public function listAvailableDomains() {
        $domains = array();
        $dObj = admin_user_domain_permissions_iterator_begin( $this->getAdminUserObj() );
        while ( admin_user_domain_permissions_iterator_has_value( $dObj ) ){
            $domains[] = admin_user_domain_permissions_iterator_domain_name( $dObj );
            admin_user_domain_permissions_iterator_next( $dObj );
        }
        admin_user_domain_permissions_iterator_destroy( $dObj);

        return $domains;
    }

    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>user name</td>
<tr><td>description</td><td>user description</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                $resp = admin_user_name_set($this->getAdminUserObj(), $this->getSessionObj(), $varValue);
            break;
            case "description":
                $resp = admin_user_display_name_set($this->getAdminUserObj(), $this->getSessionObj(), $varValue);
            break;
            case "password":
                $resp = admin_user_password_set($this->getAdminUserObj(), $this->getSessionObj(), $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETADMINUSERVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETADMINUSERVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>user name</td>
<tr><td>description</td><td>user description</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                return admin_user_name_get($this->getAdminUserObj());
            break;
            case "description":
                return admin_user_display_name_get($this->getAdminUserObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETADMINUSERVARERROR);
        }
    }

    /**
     * Save admin user permissions.
    */
    public function savePermissions($permissions) {
        return admin_user_permissions_save($permissions, $this->getAdminUserObj(), $this->getSessionObj());
    }

    /**
     * Returns an object with all the server/domain permissions loaded.
     * Note: the returned object is writable (you can use deny, revoke, grant calls on it).
     * @return object Permissions
     * @param $domain string the domain name from where the permission will be loaded, if it's null the server permissions will be loaded (this parameter is optional - server is default)
     */
    public function getPermissions($domain = null) {
        if (is_null($domain)) {
            if (!is_object($this->server)) {
                $permissionsObj = admin_user_get_server_permissions($this->getAdminUserObj());
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADUSERPERMISSION)) return false;
                $this->server = new Permissions($permissionsObj, $this);
                $this->server->effective = false;
                $this->server->type = "server";
            }
            return $this->server;
        } else {
            if (!is_object($this->domain[$domain])) {
                $permissionsObj = admin_user_get_domain_permissions($this->getAdminUserObj() , $domain);
                if (!Debug::checkError($permissionsObj, "_p_permissions", Debug::INFOERROR, Message::LOADUSERPERMISSION)) return false;
                $this->domain[$domain] = new Permissions($permissionsObj, $this);
                $this->domain[$domain]->effective = false;
                $this->domain[$domain]->type = "domain";
            }
            return $this->domain[$domain];
        }
    }

}
/** @} */ // end of group
?>
