<?php
/** 
 * \ingroup configAccessControl
 * \defgroup updateAllowRule updateAllowRule
 * @{
*/
class AllowRule {
    private $allowrule, $parent;
    public function __construct($allowruleObj, $parent) {
        $this->allowrule = $allowruleObj;
        $this->parent = $parent;
    }
    public function __destruct() {
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAllowRule() {
        return $this->allowrule;
    }
    /**
     * This method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        return $this->parent->saveRules();
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>ipSet</td>
<td>the ipSet parameter</td>
<tr><td>enable</td>
<td>the enable/disable status for the rule</td>
<tr><td>priority</td>
<td>the rule's priority</td>
<tr><td>maxConnections</td>
<td>maximum number of connections</td>
<tr><td>timeInterval</td>
<td>the time interval</td>
<tr><td>maxIntervalConnections</td>
<td>maximum number of connections in time interval</td>
<tr><td>peerMaxConnections</td>
<td>maximum number of connections from a single host</td>
<tr><td>peerTimeInterval</td>
<td>the time interval - single host</td>
<tr><td>peerMaxIntervalConnections</td>
<td>desc maximum number of connections in time interval - single host</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "ipset":
                $isStartEnd = true;
                if (strstr($varValue, "-")) {
                    $isStartEnd = true;
                    $tmp = explode("-", $varValue);
                    $s1 = $tmp[0];
                    $s2 = $tmp[1];
                } elseif (strstr($varValue, "/")) {
                    $isStartEnd = false;
                    $tmp = explode("/", $varValue);
                    $s1 = $tmp[0];
                    $s2 = $tmp[1];
                } else {
                    return false;
                }
                if ($isStartEnd) {
                    $r1 = allow_rule_start_ip_set($this->getAllowRule() , $s1);
                    $r2 = allow_rule_end_ip_set($this->getAllowRule() , $s2);
                    if (($r1 == 0) && ($r2 == 0)) {
                        $resp = 0;
                    } else {
                        $resp = -1;
                    }
                } else {
                    $r1 = allow_rule_network_set($this->getAllowRule() , $s1);
                    $r2 = allow_rule_netmask_set($this->getAllowRule() , $s2);
                    if (($r1 == 0) && ($r2 == 0)) {
                        $resp = 0;
                    } else {
                        $resp = -1;
                    }
                }
            break;
            case "enable":
                $resp = allow_rule_enable_set($this->getAllowRule() , $varValue);
            break;
            case "priority":
                $resp = allow_rule_priority_set($this->getAllowRule() , $varValue);
            break;
            case "maxconnections":
                $resp = allow_rule_maxConnections_set($this->getAllowRule() , $varValue);
            break;
            case "timeinterval":
                $resp = allow_rule_timeInterval_set($this->getAllowRule() , $varValue);
            break;
            case "maxintervalconnections":
                $resp = allow_rule_maxIntervalConnections_set($this->getAllowRule() , $varValue);
            break;
            case "peermaxconnections":
                $resp = allow_rule_peerMaxConnections_set($this->getAllowRule() , $varValue);
            break;
            case "peertimeinterval":
                $resp = allow_rule_peerTimeInterval_set($this->getAllowRule() , $varValue);
            break;
            case "peermaxintervalconnections":
                $resp = allow_rule_peerMaxIntervalConnections_set($this->getAllowRule() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETALLOWRULE);
                return false;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETALLOWRULE);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>ipSet</td>
<td>the ipSet parameter</td>
<tr><td>enable</td>
<td>the enable/disable status for the rule</td>
<tr><td>priority</td>
<td>the rule's priority</td>
<tr><td>maxConnections</td>
<td>maximum number of connections</td>
<tr><td>timeInterval</td>
<td>the time interval</td>
<tr><td>maxIntervalConnections</td>
<td>maximum number of connections in time interval</td>
<tr><td>peerMaxConnections</td>
<td>maximum number of connections from a single host</td>
<tr><td>peerTimeInterval</td>
<td>the time interval - single host</td>
<tr><td>peerMaxIntervalConnections</td>
<td>desc maximum number of connections in time interval - single host</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "ipset":
                if (allow_rule_is_ip_set_form($this->getAllowRule()) == 1) {
                    $r1 = allow_rule_start_ip_get($this->getAllowRule());
                    $r2 = allow_rule_end_ip_get($this->getAllowRule());
                    $ipSet = $r1 . "-" . $r2;
                } else {
                    $r1 = allow_rule_network_get($this->getAllowRule());
                    $r2 = allow_rule_netmask_get($this->getAllowRule());
                    $ipSet = $r1 . "/" . $r2;
                }
                return $ipSet;
            break;
            case "enable":
                if (allow_rule_enable_get($this->getAllowRule()) == 1) return true;
                else return false;
                break;
            case "priority":
                return allow_rule_priority_get($this->getAllowRule());
                break;
            case "maxconnections":
                return allow_rule_maxConnections_get($this->getAllowRule());
                break;
            case "timeinterval":
                return allow_rule_timeInterval_get($this->getAllowRule());
                break;
            case "maxintervalconnections":
                return allow_rule_maxIntervalConnections_get($this->getAllowRule());
                break;
            case "peermaxconnections":
                return allow_rule_peerMaxConnections_get($this->getAllowRule());
                break;
            case "peertimeinterval":
                return allow_rule_peerTimeInterval_get($this->getAllowRule());
                break;
            case "peermaxintervalconnections":
                return allow_rule_peerMaxIntervalConnections_get($this->getAllowRule());
                break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETALLOWRULE);
            }
        }
}
/** @} */ // end of group
?>
