<?php
/**
 * \ingroup configServer
 * \defgroup configCli configCli
 * @{
*/
class Cli {
    private $cliObj, $parent, $listener, $accesscontrol;
    public function __construct($cliObj, $parent) {
        $this->cliObj = $cliObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        cli_destroy($this->getCliObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getCliObj() {
        return $this->cliObj;
    }
    /**
     * Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td><td>the maximum number of threads involved in I/O for the CLI service</td>
<tr><td>minConnThreads</td><td>the minimum number of threads involved in I/O for the CLI service</td>
<tr><td>maxErrors</td><td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td><td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>maxAuthCommands</td><td>the maximum number of commands the CLI service performs before the user logs in</td>
<tr><td>logLevel</td><td>the log level for the CLI service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the CLI service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'maxErrors':
                return $this->getMaxErrors();
            break;
            case 'maxAuthErrors':
                return $this->getMaxAuthErrors();
            break;
            case 'maxAuthCommands':
                return $this->getMaxAuthCommands();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            default:;
            break;
        }
    }
    /**
     * Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td><td>the maximum number of threads involved in I/O for the CLI service</td>
<tr><td>minConnThreads</td><td>the minimum number of threads involved in I/O for the CLI service</td>
<tr><td>maxErrors</td><td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td><td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>maxAuthCommands</td><td>the maximum number of commands the CLI service performs before the user logs in</td>
<tr><td>logLevel</td><td>the log level for the CLI service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the CLI service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxErrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxAuthErrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'maxAuthCommands':
                return $this->setMaxAuthCommands($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return cli_max_connection_threads_get($this->getCliObj());
    }
    /**
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return cli_min_connection_threads_get($this->getCliObj());
    }
    /**
     * This function returns the maximum number of protocol errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return cli_max_errors_get($this->getCliObj());
    }
    /**
     * This function returns the maximum number of authentication errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return cli_max_auth_errors_get($this->getCliObj());
    }
    /**
     * This function returns 1 if secure connections (which start with STARTTLS) are allowed for this service and 0 otherwise
     *
     * @return int
     */
    public function getMaxAuthCommands() {
        return cli_max_auth_commands_get($this->getCliObj());
    }
    /**
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return cli_log_level_get($this->getCliObj());
    }
    /**
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return cli_log_host_get($this->getCliObj());
    }
    /**
     * This function returns the log for this service
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return cli_log_type_get($this->getCliObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = cli_max_connection_threads_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETMAXCONNTHREADS);
    }
    /**
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = cli_min_connection_threads_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETMINCONNTHREADS);
    }
    /**
     * This function sets the maximum number of protocol errors after which the connection is terminated.
     * @return bool
     *
     * @param $value int max errors
     */
    public function setMaxErrors($value) {
        $set = cli_max_errors_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETMAXERRORS);
    }
    /**
     * This function sets the maximum number of authentication errors after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = cli_max_auth_errors_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETAUTHERRORS);
    }
    /**
     *  is function sets the maximum number of commands the CLI service performs before the user logs in
     * @return bool
     *
     * @param $value int maximum number of authentication commands
     */
    public function setMaxAuthCommands($value) {
        $set = cli_max_auth_commands_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETMAXAUTHCOMMANDS);
    }
    /**
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = cli_log_level_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETLOGLEVEL);
    }
    /**
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value int log host
     */
    public function setLogHost($value) {
        $set = cli_log_host_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETLOGHOST);
    }
    /**
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value int Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = cli_log_type_set($this->getCliObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::CLISETLOGTYPE);
    }
    /**
     * This function saves the CLI configuration on the Axigen server
     *
     * @return bool
     */
    public function save() {
        $save = cli_save($this->getCliObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::CLISAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = cli_reset($this->getCliObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::CLIRESET);
    }
    /**
     * This function stops the CLI service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("cli");
    }
    /**
     * This function starts the CLI service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("cli");
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address int the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = cli_listeners_get($this->getCliObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::CLIGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::CLIADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address int the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = cli_listeners_get($this->getCliObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::CLIGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CLIREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object
     * @object Listener
     * @param $address int the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = cli_listeners_get($this->getCliObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::CLIGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::CLIUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = cli_listeners_get($this->getCliObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::CLIGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::CLIGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = cli_get_access_control($this->getCliObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::CLIACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
}
/** @} */ // end of group
?>
