<?php
/**
 * \ingroup updateAccount
 * \defgroup configContactInfo configContactInfo
 * @{
 * This is the object containing the contact info for the selected account.
 */
class ContactInfo {
    private $contactinfo, $parent;
    public function __construct($contactinfoObj, $parentObj) {
        $this->contactinfo = $contactinfoObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        contact_info_destroy($this->getContactInfo());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getContactInfo() {
        return $this->contactinfo;
    }
    /**      
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = contact_info_save($this->getContactInfo() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEACCOUNTCONTACTINFO);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>firstName</td>
<td>the first name for this user</td>
<tr><td>lastName</td>
<td>the last name for this user</td>
<tr><td>nickName</td>
<td>the nickname for this user</td>
<tr><td>personalEmail</td>
<td>the personal email address for this user</td>
<tr><td>businessEmail</td>
<td>the business email address for this user</td>
<tr><td>phone</td>
<td>the phone for this user</td>
<tr><td>mobilePhone</td>
<td>the mobile phone number for this user</td>
<tr><td>homePhone</td>
<td>the home phone number for this user</td>
<tr><td>businessPhone</td>
<td>the business phone number for this user</td>
<tr><td>homeAddress</td>
<td>the home address for this user</td>
<tr><td>businessAddress</td>
<td>the business address for this user</td>
<tr><td>personalVoIPAddress</td>
<td>personalVoIPAddress</td>
<tr><td>birthday</td>
<td>birthday</td>
<tr><td>spouseName</td>
<td>spouseName</td>
<tr><td>businessVoIPAddress </td>
<td>businessVoIPAddress</td>
<tr><td>company</td>
<td>company</td>
<tr><td>department</td>
<td>department</td>
<tr><td>office</td>
<td>office</td>
<tr><td>position</td>
<td>position</td>
<tr><td>profession</td>
<td>profession</td>
<tr><td>managerName</td>
<td>managerName</td>
<tr><td>assistantName</td>
<td>assistantName</td>
<tr><td>website</td>
<td>website</td>
<td>website</td>
<tr><td>yahooMessengerId</td>
<td>yahooMessengerId</td>
<tr><td>googleTalkId</td>
<td>googleTalkId</td>
<tr><td>liveMessengerAddress</td>
<td>liveMessengerAddress</td>
<tr><td>icqNumber</td>
<td>icqNumber</td>
<tr><td>aolScreenName</td>
<td>aolScreenName</td>
<tr><td>skypeId</td>
<td>skypeId</td>
<tr><td>title</td>
<td>title</td>
<tr><td>middleName</td>
<td>middleName</td>
<tr><td>suffix</td>
<td>suffix</td>
<tr><td>businessFax</td>
<td>businessFax</td>
<tr><td>contactNotes</td>
<td>contactNotes</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "businessaddress":
                $resp = contact_info_business_address_set($this->getContactInfo() , $varValue);
            break;
            case "homeaddress":
                $resp = contact_info_home_address_set($this->getContactInfo() , $varValue);
            break;
            case "businessphone":
                $resp = contact_info_business_phone_set($this->getContactInfo() , $varValue);
            break;
            case "mobilephone":
                $resp = contact_info_mobile_phone_set($this->getContactInfo() , $varValue);
            break;
            case "homephone":
                $resp = contact_info_home_phone_set($this->getContactInfo() , $varValue);
            break;
            case "phone":
                $resp = contact_info_phone_set($this->getContactInfo() , $varValue);
            break;
            case "businessemail":
                $resp = contact_info_business_email_set($this->getContactInfo() , $varValue);
            break;
            case "personalemail":
                $resp = contact_info_personal_email_set($this->getContactInfo() , $varValue);
            break;
            case "nickname":
                $resp = contact_info_nick_name_set($this->getContactInfo() , $varValue);
            break;
            case "lastname":
                $resp = contact_info_last_name_set($this->getContactInfo() , $varValue);
            break;
            case "firstname":
                $resp = contact_info_first_name_set($this->getContactInfo() , $varValue);
            break;
            case "personalvoipaddress":
                $resp = contact_info_personal_voip_address_set($this->getContactInfo() , $varValue);
            break;
            case "birthday":
                $resp = contact_info_birthday_set($this->getContactInfo() , $varValue);
            break;
            case "spousename":
                $resp = contact_info_spouse_name_set($this->getContactInfo() , $varValue);
            break;
            case "businessvoipaddress":
                $resp = contact_info_business_voip_address_set($this->getContactInfo() , $varValue);
            break;
            case "company":
                $resp = contact_info_company_set($this->getContactInfo() , $varValue);
            break;
            case "department":
                $resp = contact_info_department_set($this->getContactInfo() , $varValue);
            break;
            case "office":
                $resp = contact_info_office_set($this->getContactInfo() , $varValue);
            break;
            case "position":
                $resp = contact_info_position_set($this->getContactInfo() , $varValue);
            break;
            case "profession":
                $resp = contact_info_profession_set($this->getContactInfo() , $varValue);
            break;
            case "managername":
                $resp = contact_info_manager_name_set($this->getContactInfo() , $varValue);
            break;
            case "assistantname":
                $resp = contact_info_assistant_name_set($this->getContactInfo() , $varValue);
            break;
            case "website":
                $resp = contact_info_website_set($this->getContactInfo() , $varValue);
            break;
            case "yahoomessengerid":
                $resp = contact_info_yahoo_messenger_id_set($this->getContactInfo() , $varValue);
            break;
            case "googletalkid":
                $resp = contact_info_google_talk_id_set($this->getContactInfo() , $varValue);
            break;
            case "livemessengeraddress":
                $resp = contact_info_live_messenger_address_set($this->getContactInfo() , $varValue);
            break;
            case "icqnumber":
                $resp = contact_info_icq_number_set($this->getContactInfo() , $varValue);
            break;
            case "aolscreenname":
                $resp = contact_info_aol_screen_name_set($this->getContactInfo() , $varValue);
            break;
            case "skypeid":
                $resp = contact_info_skype_id_set($this->getContactInfo() , $varValue);
            break;
            case "title":
                $resp = contact_info_title_set($this->getContactInfo() , $varValue);
            break;
            case "middlename":
                $resp = contact_info_middle_name_set($this->getContactInfo() , $varValue);
            break;
            case "suffix":
                $resp = contact_info_suffix_set($this->getContactInfo() , $varValue);
            break;
            case "businessfax":
                $resp = contact_info_business_fax_set($this->getContactInfo() , $varValue);
            break;
            case "contactnotes":
                $resp = contact_info_contact_notes_set($this->getContactInfo() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETACCOUNTCONTACTINFOVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETACCOUNTCONTACTINFOVARERROR);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>firstName</td>
<td>the first name for this user</td>
<tr><td>lastName</td>
<td>the last name for this user</td>
<tr><td>nickName</td>
<td>the nickname for this user</td>
<tr><td>personalEmail</td>
<td>the personal email address for this user</td>
<tr><td>businessEmail</td>
<td>the business email address for this user</td>
<tr><td>phone</td>
<td>the phone for this user</td>
<tr><td>mobilePhone</td>
<td>the mobile phone number for this user</td>
<tr><td>homePhone</td>
<td>the home phone number for this user</td>
<tr><td>businessPhone</td>
<td>the business phone number for this user</td>
<tr><td>homeAddress</td>
<td>the home address for this user</td>
<tr><td>businessAddress</td>
<td>the business address for this user</td>
<tr><td>personalVoIPAddress</td>
<td>personalVoIPAddress</td>
<tr><td>birthday</td>
<td>birthday</td>
<tr><td>spouseName</td>
<td>spouseName</td>
<tr><td>businessVoIPAddress </td>
<td>businessVoIPAddress</td>
<tr><td>company</td>
<td>company</td>
<tr><td>department</td>
<td>department</td>
<tr><td>office</td>
<td>office</td>
<tr><td>position</td>
<td>position</td>
<tr><td>profession</td>
<td>profession</td>
<tr><td>managerName</td>
<td>managerName</td>
<tr><td>assistantName</td>
<td>assistantName</td>
<tr><td>website</td>
<td>website</td>
<td>website</td>
<tr><td>yahooMessengerId</td>
<td>yahooMessengerId</td>
<tr><td>googleTalkId</td>
<td>googleTalkId</td>
<tr><td>liveMessengerAddress</td>
<td>liveMessengerAddress</td>
<tr><td>icqNumber</td>
<td>icqNumber</td>
<tr><td>aolScreenName</td>
<td>aolScreenName</td>
<tr><td>skypeId</td>
<td>skypeId</td>
<tr><td>title</td>
<td>title</td>
<tr><td>middleName</td>
<td>middleName</td>
<tr><td>suffix</td>
<td>suffix</td>
<tr><td>businessFax</td>
<td>businessFax</td>
<tr><td>contactNotes</td>
<td>contactNotes</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "businessaddress":
                return contact_info_business_address_get($this->getContactInfo());
            break;
            case "homeaddress":
                return contact_info_home_address_get($this->getContactInfo());
            break;
            case "businessphone":
                return contact_info_business_phone_get($this->getContactInfo());
            break;
            case "mobilephone":
                return contact_info_mobile_phone_get($this->getContactInfo());
            break;
            case "homephone":
                return contact_info_home_phone_get($this->getContactInfo());
            break;
            case "phone":
                return contact_info_phone_get($this->getContactInfo());
            break;
            case "businessemail":
                return contact_info_business_email_get($this->getContactInfo());
            break;
            case "personalemail":
                return contact_info_personal_email_get($this->getContactInfo());
            break;
            case "nickname":
                return contact_info_nick_name_get($this->getContactInfo());
            break;
            case "lastname":
                return contact_info_last_name_get($this->getContactInfo());
            break;
            case "firstname":
                return contact_info_first_name_get($this->getContactInfo());
            break;
            case "personalvoipaddress":
                return contact_info_personal_voip_address_get($this->getContactInfo());
            break;
            case "birthday":
                return contact_info_birthday_get($this->getContactInfo());
            break;
            case "spousename":
                return contact_info_spouse_name_get($this->getContactInfo());
            break;
            case "businessvoipaddress":
                return contact_info_business_voip_address_get($this->getContactInfo());
            break;
            case "company":
                return contact_info_company_get($this->getContactInfo());
            break;
            case "department":
                return contact_info_department_get($this->getContactInfo());
            break;
            case "office":
                return contact_info_office_get($this->getContactInfo());
            break;
            case "position":
                return contact_info_position_get($this->getContactInfo());
            break;
            case "profession":
                return contact_info_profession_get($this->getContactInfo());
            break;
            case "managername":
                return contact_info_manager_name_get($this->getContactInfo());
            break;
            case "assistantname":
                return contact_info_assistant_name_get($this->getContactInfo());
            break;
            case "website":
                return contact_info_website_get($this->getContactInfo());
            break;
            case "yahoomessengerid":
                return contact_info_yahoo_messenger_id_get($this->getContactInfo());
            break;
            case "googletalkid":
                return contact_info_google_talk_id_get($this->getContactInfo());
            break;
            case "livemessengeraddress":
                return contact_info_live_messenger_address_get($this->getContactInfo());
            break;
            case "icqnumber":
                return contact_info_icq_number_get($this->getContactInfo());
            break;
            case "aolscreenname":
                return contact_info_aol_screen_name_get($this->getContactInfo());
            break;
            case "skypeid":
                return contact_info_skype_id_get($this->getContactInfo());
            break;
            case "title":
                return contact_info_title_get($this->getContactInfo());
            break;
            case "middlename":
                return contact_info_middle_name_get($this->getContactInfo());
            break;
            case "suffix":
                return contact_info_suffix_get($this->getContactInfo());
            break;
            case "businessfax":
                return contact_info_business_fax_get($this->getContactInfo());
            break;
            case "contactnotes":
                return contact_info_contact_notes_get($this->getContactInfo());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETACCOUNTCONTACTINFOVARERROR);
        }
    }
}
/** @} */ // end of group
?>
