<?php
/** NoDoc */
/** New Doc 1 */
/** Last Update 0 */
// @cond DEV
defined('DEBUGPRINT') or define('DEBUGPRINT', false); // print the debug information on warn/error  (WARNING: this can print your cli or other passwords in backtraces)
defined('DEBUGPRINTONLYONERROR') or define('DEBUGPRINTONLYONERROR', true); // print the debug information only on error (DEBUGPRINT must be true)
defined('CUSTOMMESSAGE') or define('CUSTOMMESSAGE', false); // print custom message on warn/error
defined('CUSTOMMESSAGEONLYERROR') or define('CUSTOMMESSAGEONLYERROR', false); // print custom message only on error (CUSTOMMESSAGE must be true)
defined('SENDINCIDENTID') or define('SENDINCIDENTID', false); // print incident id on warn/error (only if DEBUGTOFILE is set to true)
defined('INCIDENTIDONLYTOERROR') or define('INCIDENTIDONLYTOERROR', true); // print incident id only on error (SENDINCIDENTID must be true)
defined('DEBUGTOFILE') or define('DEBUGTOFILE', false); // write the debug information to file on warn/error
defined('DEBUGTOFILEONLYERROR') or define('DEBUGTOFILEONLYERROR', true); //  write the debug information to file only on error (DEBUGTOFILE must be true)
defined('DEBUGFILE') or define('DEBUGFILE', "/tmp/axigenCliApi.log"); // the file where to write the debug info
defined('DIEONFATALERROR') or define('DIEONFATALERROR', false); // if a fatal error ocures the script should die or not (note: if you set to false check each object response)
// @endcond
class Debug {
    const FATALERROR = 1;
    const INFOERROR = 2;
    const DEPRECATED = 3;
    protected static $errno, $errtype, $deprecatedMethod;
    public static function getError() {
        if (!self::$errno) {
            return false;
        }
        $error['no'] = self::$errno;
        $error['txt'] = Message::$errtxt[self::$errno];
        if (self::$errtype == self::DEPRECATED) {
            $error['txt'].= " ( " . self::$deprecatedMethod . " ) ";
        }
        $error['type'] = self::$errtype;
        return $error;
    }
    public static function setError($errno, $errtype) {
        self::$errno = $errno;
        self::$errtype = $errtype;
    }
    public static function setDeprecated($method) {
        self::setError(Message::DEPRECATEDMETHOD, self::DEPRECATED);
        self::$deprecatedMethod = $method;
        self::makeError(self::DEPRECATED, Message::$errtxt[Message::DEPRECATEDMETHOD] . " ( " . self::$deprecatedMethod . " ) ");
    }
    /**
     * This function check a respons for error
     *
     * @param $varToCheck
     * @param $checkWith
     * @param $errorType
     * @param $errorMessage
     */
    public static function checkError($varToCheck, $checkWith, $errorType, $errorMessage) {
        if (is_resource($varToCheck)) $varToCheck = get_resource_type($varToCheck);
        if ($varToCheck != $checkWith) {
            self::makeError($errorType, Message::$errtxt[$errorMessage]);
            self::setError($errorMessage, $errorType);
            return false;
        }
        return true;
    }
    private static function makeError($errorType, $errorMessage) {
        $errorID = Debug::generateErrorID();
        $writeMessage = Debug::generateMessage($errorID);
        if (CUSTOMMESSAGE) {
            if (Debug::FATALERROR == $errorType) {
                print "ERROR: " . $errorMessage . "<br>";
            } elseif (!CUSTOMMESSAGEONLYERROR) {
                print "WARN: " . $errorMessage . "<br>";
            }
        }
        if (DEBUGPRINT) {
            $send = true;
            if ((DEBUGPRINTONLYONERROR) && ($errorType == Debug::INFOERROR)) {
                $send = false;
            }
            if ($send) {
                Debug::printError($writeMessage);
            }
        }
        if (DEBUGTOFILE) {
            $send = true;
            if ((DEBUGTOFILEONLYERROR) && ($errorType == Debug::INFOERROR)) {
                $send = false;
            }
            if ($send) {
                Debug::logError($writeMessage, $errorID . " >> " . $errorMessage);
            }
        }
        if (SENDINCIDENTID && DEBUGTOFILE) {
            $send = true;
            if ((INCIDENTIDONLYTOERROR) && ($errorType == Debug::INFOERROR)) $send = false;
            if ($send) {
                $dieMessage = Message::CLIENTERRORMESSAGE;
                $dieMessage.= " " . $errorID;
                print $dieMessage . "<br>";
            }
        }
        if ((Debug::FATALERROR == $errorType) && (DIEONFATALERROR)) {
            exit;
        }
    }
    private static function printError($writeMessage) {
        print "<pre>Backtrace:\r\n";
        print $writeMessage;
        print "</pre>";
    }
    private static function logError($writeMessage, $errorMessage) {
        $logFile = fopen(DEBUGFILE, "a");
        if ($logFile === FALSE) return false;
        if (fwrite($logFile, $errorMessage . "\r\n") === FALSE) return false;
        if (fwrite($logFile, $writeMessage . "\r\n") === FALSE) return false;
        fclose($logFile);
    }
    private static function generateMessage($errorID) {
        $backtrace = debug_backtrace();
        $btMessage = "";
        foreach($backtrace as $bt) {
            $btMessage.= $errorID . " >> ";
            if (!empty($bt['class'])) {
                $btMessage.= $bt['class'] . $bt['type'];
            }
            $args = "";
            foreach($bt['args'] as $arg) {
                if (is_object($arg)) {
                    $args.= "object(" . get_class($arg) . "),";
                } elseif (is_resource($arg)) {
                    $args.= "resource(" . get_resource_type($arg) . "),";
                } elseif (is_null($arg)) {
                    $args.= "null,";
                } else {
                    $args.= $arg . ",";
                }
            }
            $args = trim($args, ",");
            $btMessage.= $bt['function'] . "(" . $args . ") - ";
            $btMessage.= $bt['file'] . ":" . $bt['line'] . "\r\n";
        }
        return $btMessage;
    }
    private static function generateErrorID() {
        $string = "";
        for ($i = 0;$i <= 5;$i++) {
            $chr = '';
            switch (mt_rand(1, 3)) {
                case 1:
                    $chr = chr(mt_rand(48, 57));
                break;
                case 2:
                    $chr = chr(mt_rand(65, 90));
                break;
                case 3:
                    $chr = chr(mt_rand(97, 122));
            }
            $string.= $chr;
        }
        $date = date("Gzy");
        $errorID = $date . "/" . $string;
        return $errorID;
    }
}
?>
