<?php
/** 
 * \ingroup configServer
 * \defgroup configDnr configDnr
 * @{
*/
class Dnr {
    private $dnrObj, $parent;
    public function __construct($dnrObj, $parent) {
        $this->dnrObj = $dnrObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        dnr_destroy($this->getDnrObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getDnrObj() {
        return $this->dnrObj;
    }
    /**
    * Get member.
<table>
<tr><th>member</th><td>description</th>
<tr><td>timeout</td><td>the default timeout nameservers have</td>
<tr><td>retries</td><td>the default number of retries nameservers have</td>
<tr><td>cacheSize</td><td>the cache size in KB for the DNR service</td>
<tr><td>logLevel</td><td>the log level for the DNR service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the DNR service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'timeout':
                return $this->getTimeout();
            break;
            case 'retries':
                return $this->getRetries();
            break;
            case 'cacheSize':
                return $this->getCacheSize();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            default:;
            break;
        }
    }
    /**
    * Set member.
<table>
<tr><th>member</th><td>description</th>
<tr><td>timeout</td><td>the default timeout nameservers have</td>
<tr><td>retries</td><td>the default number of retries nameservers have</td>
<tr><td>cacheSize</td><td>the cache size in KB for the DNR service</td>
<tr><td>logLevel</td><td>the log level for the DNR service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the DNR service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'timeout':
                return $this->setTimeout($value);
            break;
            case 'retries':
                return $this->setRetries($value);
            break;
            case 'cacheSize':
                return $this->setCacheSize($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * This function gets the default timeout nameservers have
     *
     * @return int
     */
    public function getTimeout() {
        return dnr_timeout_get($this->getDnrObj());
    }
    /**
     * This function gets the default number of retries nameservers have
     *
     * @return int
     */
    public function getRetries() {
        return dnr_retries_get($this->getDnrObj());
    }
    /**
     * This function gets the cache size in KB for the DNR service
     *
     * @return int
     */
    public function getCacheSize() {
        return dnr_cache_size_get($this->getDnrObj());
    }
    /**
     * This function returns the log level for this service.
     *
     * @return int
     */
    public function getLogLevel() {
        return dnr_log_level_get($this->getDnrObj());
    }
    /**
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return string
     */
    public function getLogHost() {
        return dnr_log_host_get($this->getDnrObj());
    }
    /**
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return dnr_log_type_get($this->getDnrObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * This function sets the default timeout used at DNR requests
     * @return bool
     *
     * @param $value int the default timeout
     */
    public function setTimeout($value) {
        $set = dnr_timeout_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETTIMEOUT);
    }
    /**
     * This function sets the default number of retries used at DNR requests
     * @return bool
     *
     * @param $value int the default number of retries used at DNR requests
     */
    public function setRetries($value) {
        $set = dnr_retries_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETRETRIES);
    }
    /**
     * This function sets the maximum cache size for the DNR service
     * @return bool
     *
     * @param $value int the maximum cache size for the DNR service
     */
    public function setCacheSize($value) {
        $set = dnr_cache_size_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETCACHESIZE);
    }
    /**
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = dnr_log_level_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETLOGLEVEL);
    }
    /**
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = dnr_log_host_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETLOGHOST);
    }
    /**
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = dnr_log_type_set($this->getDnrObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRSETLOGTYPE);
    }
    /**
     * This function saves the DNR configuration on the Axigen server
     * @return bool
     */
    public function save() {
        $save = dnr_save($this->getDnrObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::DNRSAVE);
    }
    /**
     * This function resets the changes made but not yet saved
     * @return bool
     */
    public function reset() {
        $reset = dnr_reset($this->getDnrObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::DNRRESET);
    }
    //    /**
    //     * @method start
    //*ThisfunctionstartstheDNRservice
    //     *
    //     * @return bool
    //     */
    //    public function start()
    //    {
    //        $start = start_domain_name_resolver_service($this->getDnrObj(), $this->getSessionObj());
    //        return Debug::checkError($start, 0, Debug::INFOERROR, Message::DNRSTART);
    //    }
    //
    //    /**
    //     * @method stop
    //ThisfunctionstopstheDNRservice
    //     *
    //     * @return bool
    //     */
    //    public function stop()
    //    {
    //        $stop = stop_domain_name_resolver_service($this->getDnrObj(), $this->getSessionObj());
    //        return Debug::checkError($stop, 0, Debug::INFOERROR, Message::DNRSTOP);
    //    }
    /*
    * This function adds a nameserver to the DNR list
    * @return bool
    *
    * @param $address string the address of the nameserver
    * @param $priority int the priority of the nameserver
    * @param $timeout int the number of seconds a request answer is awaited
    * @param $retries int the number of nameserver retries
    */
    public function addNameserver($address, $priority, $timeout, $retries) {
        $nameserver = nameserver_add($this->getDnrObj() , $this->getSessionObj() , $priority);
        if (!Debug::checkError($nameserver, "_p_nameserver", Debug::INFOERROR, Message::DNRADDNAMESERVER)) return false;
        $set = nameserver_address_set($nameserver, $address);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRADDNAMESERVER)) return false;
        $set = nameserver_timeout_set($nameserver, $timeout);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRADDNAMESERVER)) return false;
        $set = nameserver_retries_set($nameserver, $retries);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRADDNAMESERVER)) return false;
        $save = nameserver_save($nameserver, $this->getSessionObj());
        if (!Debug::checkError($save, 0, Debug::INFOERROR, Message::DNRADDNAMESERVER)) return false;
        return $this->save();
    }
    /**
     * This function removes a nameserver from the DNR list
     * @return bool
     *
     * @param $priority int the priority of the nameserver
     */
    public function removeNameserver($priority) {
        $remove = nameserver_remove_by_priority($this->getDnrObj() , $priority);
        if (!Debug::checkError($remove, 0, Debug::INFOERROR, Message::DNRREMOVENAMESERVER)) return false;
        return $this->save();
    }
    /**
     * This function lists the nameservers from the DNR list
     * @return array
     */
    public function listNameservers() {
        $nameservers = array();
        $nameserversIterObj = nameserver_iterator_begin($this->getDnrObj());
        if (!Debug::checkError($nameserversIterObj, "_p_nameserver_iterator", Debug::INFOERROR, Message::DNRLISTNAMESERVERS)) return false;
        while (nameserver_iterator_has_value($nameserversIterObj)) {
            $nameserverTmp = array();
            $nameserverObj = nameserver_iterator_value($nameserversIterObj);
            $nameserverTmp['address'] = nameserver_address_get($nameserverObj);
            $nameserverTmp['retries'] = nameserver_retries_get($nameserverObj);
            $nameserverTmp['timeout'] = nameserver_timeout_get($nameserverObj);
            $nameserverTmp['priority'] = nameserver_priority_get($nameserverObj);
            array_push($nameservers, $nameserverTmp);
            nameserver_iterator_next($nameserversIterObj);
        }
        nameserver_iterator_destroy($nameserversIterObj);
        return $nameservers;
    }
    /**
     * This function updates a nameserver from the DNR list
     * @return bool
     *
     * @param $priority int the priority of the nameserver
     * @param $newAddress int the new value of the address
     * @param $newPriority int the new value of the priority
     * @param $newTimeout int the new value of the timeout
     * @param $newRetries int the new value of the number of retries
     */
    public function updateNameserver($priority, $newAddress = null, $newPriority = null, $newTimeout = null, $newRetries = null) {
        $nameserverObj = dnr_nameserver_get_by_priority($this->getDnrObj() , $priority);
        if (!Debug::checkError($nameserverObj, "_p_nameserver", Debug::INFOERROR, Message::DNRUPDATENAMESERVER)) return false;
        if (!is_null($newAddress)) {
            $set = nameserver_address_set($nameserverObj, $newAddress);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRUPDATENAMESERVER)) return false;
        }
        if (!is_null($newRetries)) {
            $set = nameserver_retries_set($nameserverObj, $newRetries);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRUPDATENAMESERVER)) return false;
        }
        if (!is_null($newTimeout)) {
            $set = nameserver_timeout_set($nameserverObj, $newTimeout);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRUPDATENAMESERVER)) return false;
        }
        if (!is_null($newPriority)) {
            $set = nameserver_priority_set($nameserverObj, $newPriority);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::DNRUPDATENAMESERVER)) return false;
        }
        return $this->save();
    }
}
/** @} */ // end of group
?>
