<?php
/**
 * \ingroup cliobject
 * \defgroup createDomain createDomain, createSubDomain, editDomainLocation, editDomainName
 * @{
*/
class DomainRegistration {
    private $domainRegistration, $parent;
    public $domaintype;
    public function __construct($domainRegistrationObj, $parentObj) {
        $this->domainRegistration = $domainRegistrationObj;
        $this->parent = $parentObj;
        $this->domaintype = "domaincreate";
    }
    public function __destruct() {
        domain_registration_destroy($this->getDomainRegistrationObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getDomainRegistrationObj() {
        return $this->domainRegistration;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = domain_registration_save($this->getDomainRegistrationObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEDOMAINREGISTRATION);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>domain name (available only on domain creation)</td>
<tr><td>domainLocation</td><td>the domain storage location</td>
<tr><td>domainObjectsLocation</td><td>the domain objects (eg: accounts, mail lists etc.) storage location</td>
<tr><td>maclSupport</td><td>enable/disable MACL support for this domain (deprecated)</td>
<tr><td>groupwareSupport</td><td>enable/disable groupware support for this domain</td>
<tr><td>prefix</td><td>sub-domain name (prefix for the domain) (available only on sub-domain creation)</td>
<tr><td>parentDomain</td><td>the parent domain for this sub-domain (available only on sub-domain creation)</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                if (!Debug::checkError($this->domaintype, "domaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONDOMVAR)) return false;
                return domain_registration_name_get($this->getDomainRegistrationObj());
                break;
            case "domainlocation":
                return domain_registration_location_get($this->getDomainRegistrationObj());
                break;
            case "domainobjectslocation":
                return domain_registration_objects_location_get($this->getDomainRegistrationObj());
                break;
            case "maclsupport":
                Debug::setDeprecated("DomainRegistration->maclSupport");
                return domain_registration_groupware_support_get($this->getDomainRegistrationObj());
                break;
            case "groupwaresupport":
                return domain_registration_groupware_support_get($this->getDomainRegistrationObj());
                break;
            case "prefix":
                if (!Debug::checkError($this->domaintype, "subdomaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONSUBDOMVAR)) return false;
                return domain_registration_prefix_get($this->getDomainRegistrationObj());
                break;
            case "parentdomain":
                if (!Debug::checkError($this->domaintype, "subdomaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONSUBDOMVAR)) return false;
                return domain_registration_parent_domain_get($this->getDomainRegistrationObj());
                break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETDOMAINREGISTRATIONVARERROR);
            }
        }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>domain name (available only on domain creation)</td>
<tr><td>domainLocation</td><td>the domain storage location</td>
<tr><td>domainObjectsLocation</td><td>the domain objects (eg: accounts, mail lists etc.) storage location</td>
<tr><td>maclSupport</td><td>enable/disable MACL support for this domain (deprecated)</td>
<tr><td>groupwareSupport</td><td>enable/disable groupware support for this domain</td>
<tr><td>prefix</td><td>sub-domain name (prefix for the domain) (available only on sub-domain creation)</td>
<tr><td>parentDomain</td><td>the parent domain for this sub-domain (available only on sub-domain creation)</td>
</table>
         */
        public function __set($varName, $varValue) {
            if (!$this) return false;
            switch (strtolower($varName)) {
                case "name":
                    if (!Debug::checkError($this->domaintype, "domaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONDOMVAR)) return false;
                    $resp = domain_registration_name_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "postmasterpassword":
                    if (($this->domaintype != "domaincreate") && ($this->domaintype != "subdomaincreate")) {
                        Debug::checkError(0, 1, Debug::INFOERROR, Message::DOMAINREGISTRATIONDOMAINSUBDOMAINVAR);
                        return false;
                    }
                    $resp = domain_registration_postmaster_passwd_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "domainlocation":
                    $resp = domain_registration_location_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "domainobjectslocation":
                    $resp = domain_registration_objects_location_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "maclsupport":
                    Debug::setDeprecated("DomainRegistration->maclSupport");
                    $resp = domain_registration_groupware_support_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "groupwaresupport":
                    $resp = domain_registration_groupware_support_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "prefix":
                    if (!Debug::checkError($this->domaintype, "subdomaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONSUBDOMVAR)) return false;
                    $resp = domain_registration_prefix_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                case "parentdomain":
                    if (!Debug::checkError($this->domaintype, "subdomaincreate", Debug::INFOERROR, Message::DOMAINREGISTRATIONSUBDOMVAR)) return false;
                    $resp = domain_registration_parent_domain_set($this->getDomainRegistrationObj() , $varValue);
                    break;
                default:
                    Debug::checkError("0", "1", Debug::INFOERROR, Message::SETDOMAINREGISTRATIONVARERROR);
                    return;
                }
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETDOMAINREGISTRATIONVARERROR);
            }
            /**
             * lists the domain messages storage location
             * @return array
             */
            public function listMessageStorageLocation() {
                if (!$this) return false;
                $list = array();
                $domLocationsObj = domain_registration_message_locations_get($this->getDomainRegistrationObj());
                if (!Debug::checkError($domLocationsObj, "_p_string_list_header", Debug::INFOERROR, Message::LISTDOMAINREGISTRATIONMESSAGES)) return false;
                $iterObj = string_list_iterator_begin($domLocationsObj);
                if (!Debug::checkError($iterObj, "_p_string_list", Debug::INFOERROR, Message::LISTDOMAINREGISTRATIONMESSAGES)) return false;
                $first = $iterObj;
                while (string_list_has_value($iterObj)) {
                    array_push($list, string_list_get_value($iterObj));
                    $iterObj = string_list_get_next($iterObj);
                    if (string_list_easy_call($first, $iterObj)) {
                        break;
                    }
                }
                string_list_header_destroy($domLocationsObj);
                return $list;
            }
            /**
             * adds a messages storage location
             * @return bool
             * @param $path string the path to the messages storage
             */
            public function addMessagesLocation($path) {
                if (!$this) return false;
                if (!is_string($path)) return false;
                $resp = domain_registration_message_location_add($this->getDomainRegistrationObj() , $path);
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDDOMAINREGISTRATIONMESSAGES);
            }
            /**
             * removes a messages storage location
             * @return bool
             * @param $path string the path to the messages storage
             */
            public function removeMessagesLocation($path) {
                if (!$this) return false;
                if (!is_string($path)) return false;
                $resp = domain_registration_message_location_remove($this->getDomainRegistrationObj() , $path);
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEDOMAINREGISTRATIONMESSAGES);
            }
        }
/** @} */ // end of group
?>
