<?php
/**
 * this object contains the Filters data
 * \ingroup configServer
 * \defgroup configFilters configFilters
 * @{
 */
class Filters {
    private $filters, $parent;
    private $scriptfilters, $socketfilters, $activefilters, $integratedfilters;
    public function __construct($filtersObj, $parent) {
        $this->filters = $filtersObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        filters_destroy($this->getFiltersObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getFiltersObj() {
        return $this->filters;
    }
    /**
     * returns an array with all the script filters
     * @return array
     */
    public function listScriptFilters() {
        $scriptFilter = array();
        $scriptFilterObj = script_filter_iterator_begin($this->getFiltersObj());
        if (!Debug::checkError($scriptFilterObj, "_p_filters_iterator", Debug::INFOERROR, Message::LISTSCRIPTFILTERS)) return false;
        while (filters_iterator_has_value($scriptFilterObj)) {
            $tmpFilter = array();
            $fObj = script_filter_iterator_value($scriptFilterObj);
            $tmpFilter['file'] = script_filter_file_get($fObj);
            $tmpFilter['name'] = script_filter_name_get($fObj);
            $tmpFilter['type'] = script_filter_type_get($fObj);
            array_push($scriptFilter, $tmpFilter);
            filters_iterator_next($scriptFilterObj);
        }
        filters_iterator_destroy($scriptFilterObj);
        return $scriptFilter;
    }
    /**
     * this method adds a script filter
     * @return bool
     * @param $name string the name of the filter
     * @param $file string the path to the file where the script is located
     */
    public function addScriptFilter($name, $file) {
        $resp = filters_add_script_filter($this->getFiltersObj() , $this->getSessionObj() , $name, "sieve", $file);
        if (!Debug::checkError($resp, "_p_script_filter", Debug::INFOERROR, Message::ADDSCRIPTFILTER)) return false;
        return $this->save();
    }
    /**
     * this method removes a script filter
     * @return bool
     * @param $name string the name of the filter
     */
    public function removeScriptFilter($name) {
        $resp = filters_remove_script_filter_by_name($this->getFiltersObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVESCRIPTFILTER)) return false;
        return $this->save();
    }
    /**
     * this method returns an object of ScriptFilters type for the selected filter
     * @return object ScriptFilters
     * @param $name string the name of the filter
     */
    public function updateScriptFilter($name) {
        if (!$this) return false;
        if (!is_object($this->scriptfilters[$name])) {
            $scriptfiltersObj = filters_script_filter_get_by_name($this->getFiltersObj() , $name);
            if (!Debug::checkError($scriptfiltersObj, "_p_script_filter", Debug::FATALERROR, Message::LOADSCRIPTFILTER)) return false;
            $this->scriptfilters[$name] = new ScriptFilters($scriptfiltersObj, $this);
        }
        return $this->scriptfilters[$name];
    }
    /**
     * returns an array with all the socket filters
     * @return array
     */
    public function listSocketFilters() {
        $socketFilter = array();
        $socketFilterObj = socket_filter_iterator_begin($this->getFiltersObj());
        if (!Debug::checkError($socketFilterObj, "_p_filters_iterator", Debug::INFOERROR, Message::LISTSOCKETFILTERS)) return false;
        while (filters_iterator_has_value($socketFilterObj)) {
            $tmpFilter = array();
            $fObj = socket_filter_iterator_value($socketFilterObj);
            $tmpFilter['idleTimeout'] = socket_filter_idle_timeout_get($fObj);
            $tmpFilter['maxConnections'] = socket_filter_max_connections_get($fObj);
            $tmpFilter['name'] = socket_filter_name_get($fObj);
            $tmpFilter['address'] = socket_filter_address_get($fObj);
            $tmpFilter['protocolFile'] = socket_filter_protocol_file_get($fObj);
            $tmpFilter['actionOnMatch'] = socket_filter_action_on_match_get($fObj);;
            array_push($socketFilter, $tmpFilter);
            filters_iterator_next($socketFilterObj);
        }
        filters_iterator_destroy($socketFilterObj);
        return $socketFilter;
    }
    /**
     * this method adds a socket filter
     * @return bool
     * @param $name string the name of the filter
     * @param $address string the address of the filter, used to communicate with the filter
     * @param $protocol_file string the path to the ASFL file that describes the communication protocol
     */
    public function addSocketFilter($name, $address, $protocol_file) {
        $resp = filters_add_socket_filter($this->getFiltersObj() , $this->getSessionObj() , $name, $address, $protocol_file);
        if (!Debug::checkError($resp, "_p_socket_filter", Debug::INFOERROR, Message::ADDSOCKETFILTER)) return false;
        return $this->save();
    }
    /**
     * this method removes a script filter
     * @return bool
     * @param $name string the name of the filter
     */
    public function removeSocketFilter($name) {
        $resp = filters_remove_socket_filter_by_name($this->getFiltersObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVESOCKETFILTER)) return false;
        return $this->save();
    }
    /**
     * this method returns an object of SocketFilters type for the selected filter
     * @return object SocketFilters
     * @param $name string the name of the filter
     */
    public function updateSocketFilter($name) {
        if (!$this) return false;
        if (!is_object($this->socketfilters[$name])) {
            $socketfiltersObj = filters_socket_filter_get_by_name($this->getFiltersObj() , $name);
            if (!Debug::checkError($socketfiltersObj, "_p_socket_filter", Debug::FATALERROR, Message::LOADSOCKETFILTER)) return false;
            $this->socketfilters[$name] = new SocketFilters($socketfiltersObj, $this);
        }
        return $this->socketfilters[$name];
    }
    /**
     * returns an array with all the active filters
     * @return array
     */
    public function listActiveFilters() {
        $activeFilter = array();
        $activeFilterObj = active_filter_iterator_begin($this->getFiltersObj());
        if (!Debug::checkError($activeFilterObj, "_p_filters_iterator", Debug::INFOERROR, Message::LISTACTIVEFILTERS)) return false;
        while (filters_iterator_has_value($activeFilterObj)) {
            $tmpFilter = array();
            $fObj = active_filter_iterator_value($activeFilterObj);
            $tmpFilter['priority'] = active_filter_priority_get($fObj);
            $tmpFilter['filter_name'] = active_filter_filter_name_get($fObj);
            $tmpFilter['filter_type'] = active_filter_filter_type_get($fObj);
            $tmpFilter['applyOn'] = active_filter_apply_on_get($fObj);
            array_push($activeFilter, $tmpFilter);
            filters_iterator_next($activeFilterObj);
        }
        filters_iterator_destroy($activeFilterObj);
        return $activeFilter;
    }
    /**
     * this method adds an active filter
     * @return bool
     * @param $priority int the priority of the filter
     * @param $name string the name of the filter as defined in the socket/script object sets
     * @param $type string type of the filter (to which object set belongs) (type: socket/script)
     */
    public function addActiveFilter($priority, $name, $type) {
        $resp = filters_add_active_filter($this->getFiltersObj() , $this->getSessionObj() , $priority, $name, $type);
        if (!Debug::checkError($resp, "_p_active_filter", Debug::INFOERROR, Message::ADDACTIVEFILTER)) return false;
        return $this->save();
    }
    /**
     * this method removes an active filter
     * @return bool
     * @param $priority int the priority of the filter
     */
    public function removeActiveFilter($priority) {
        $resp = filters_remove_active_filter_by_priority($this->getFiltersObj() , $priority);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEACTIVEFILTER)) return false;
        return $this->save();
    }
    /**
     * this method returns an object of ActiveFilters type for the selected filter
     * @return object ActiveFilters
     * @param $priority int the priority of the filter
     */
    public function updateActiveFilter($priority) {
        if (!$this) return false;
        if (!is_object($this->activefilters[$priority])) {
            $activefiltersObj = filters_active_filter_get_by_priority($this->getFiltersObj() , $priority);
            if (!Debug::checkError($activefiltersObj, "_p_active_filter", Debug::FATALERROR, Message::LOADACTIVEFILTER)) return false;
            $this->activefilters[$priority] = new ActiveFilters($activefiltersObj, $this);
        }
        return $this->activefilters[$priority];
    }
    /**
     * returns an array with all the integrated filters (only avaible on server context)
     * @return array
     */
    public function listIntegratedFilters() {
        $integratedFilter = array();
        $integratedFilterObj = integrated_filter_iterator_begin($this->getFiltersObj());
        if (!Debug::checkError($integratedFilterObj, "_p_filters_iterator", Debug::INFOERROR, Message::LISTINTEGRATEDFILTERS)) return false;
        while (filters_iterator_has_value($integratedFilterObj)) {
            $tmpFilter = array();
            $fObj = integrated_filter_iterator_value($integratedFilterObj);
            $tmpFilter['name'] = integrated_filter_name_get($fObj);
            $tmpFilter['type'] = integrated_filter_type_get($fObj);
            $tmpFilter['command'] = integrated_filter_command_get($fObj);
            $tmpFilter['enable'] = integrated_filter_enable_get($fObj);
            $tmpFilter['requestTimeout'] = integrated_filter_request_timeout_get($fObj);
            array_push($integratedFilter, $tmpFilter);
            filters_iterator_next($integratedFilterObj);
        }
        filters_iterator_destroy($integratedFilterObj);
        return $integratedFilter;
    }
    /**
     * this method adds an integrated filter
     * @return bool
     * @param $name string the name of the filter
     * @param $type string integrated filter type
     * @param $command string integrated filter command
     */
    public function addIntegratedFilter($name, $type, $command) {
        $resp = filters_add_integrated_filter($this->getFiltersObj() , $this->getSessionObj() , $name, $type, $command);
        if (!Debug::checkError($resp, "_p_integrated_filter", Debug::INFOERROR, Message::ADDINTEGRATEDFILTER)) return false;
        return $this->save();
    }
    /**
     * this method removes an integrated filter
     * @return bool
     * @param $name string the name of the filter
     */
    public function removeIntegratedFilter($name) {
        $resp = filters_remove_integrated_filter_by_name($this->getFiltersObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEINTEGRATEDFILTER)) return false;
        return $this->save();
    }
    /**
     * this method returns an object of IntegratedFilters type for the selected filter
     * @return object IntegratedFilters
     * @param $name string the name of the filter
     */
    public function updateIntegratedFilter($name) {
        if (!$this) return false;
        if (!is_object($this->integratedfilters[$name])) {
            $integratedfiltersObj = filters_integrated_filter_get_by_name($this->getFiltersObj() , $name);
            if (!Debug::checkError($integratedfiltersObj, "_p_integrated_filter", Debug::FATALERROR, Message::LOADINTEGRATEDFILTER)) return false;
            $this->integratedfilters[$name] = new IntegratedFilters($integratedfiltersObj, $this);
        }
        return $this->integratedfilters[$name];
    }
    /**
     * checks if the filters are inherited
     * @return int (1 if the value is inherited, 0 if not, or -1 if this does not apply to the current filters object)
     */
    public function isInherited() {
        $resp = filters_are_inherited($this->getFiltersObj());
        return $resp;
    }
    /**
     * set filters to be inherited from a selected source
     * @return bool
     */
    public function inherit() {
        $resp = filters_reset($this->getFiltersObj() , $this->getSessionObj());
        if ($resp == 0) return true;
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INHERITFILTERSVARERROR);
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = filters_save($this->getFiltersObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEFILTERDATA);
    }
/**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>logType</td><td>log type</td>
<tr><td>logLevel</td><td>log level</td>
<tr><td>logHost</td><td>log host</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "loglevel":
                $resp = filters_log_level_set($this->getFiltersObj() , $varValue);
                break;
            case "logtype":
                $resp = filters_log_type_set($this->getFiltersObj() , $varValue);
                break;
            case "loghost":
                $resp = filters_log_host_set($this->getFiltersObj() , $varValue);
                break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETFILTERSVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETFILTERSVARERROR);
    }
/**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>logType</td><td>log type</td>
<tr><td>logLevel</td><td>log level</td>
<tr><td>logHost</td><td>log host</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "loglevel":
                return filters_log_level_get($this->getFiltersObj());
                break;
            case "logtype":
                return filters_log_type_get($this->getFiltersObj());
                break;
            case "loghost":
                return filters_log_host_get($this->getFiltersObj());
                break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETFILTERSVARERROR);
                return;
        }
    }
}
/** @} */ // end of group
?>
