<?php
/**
 * this is the object containing the Folder Rcpt data for the selected domain
 * \ingroup updateDomain
 * \defgroup updateFolderRcpt updateFolderRcpt
 * @{
 */
class FolderRcpt {
    private $folderrcpt, $parent, $filters;
    public function __construct($folderrcptObj, $parentObj) {
        $this->folderrcpt = $folderrcptObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        folder_rcpt_destroy($this->getFolderRcptObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getFolderRcptObj() {
        return $this->folderrcpt;
    }
    /**
     * this method returns an array with folderrcpt Registry Information
     * @return array
     */
    public function registryInformation() {
        $regObj = folder_rcpt_registry_information_get($this->getFolderRcptObj() , $this->getSessionObj());
        if (!Debug::checkError($regObj, "_p_registry_information", Debug::INFOERROR, Message::FOLDERRCPTREGISTRYINFO)) return false;
        $reg['creationDate'] = registry_information_creation_date_get($regObj);
        $reg['modificationDate'] = registry_information_modification_date_get($regObj);
        $reg['messageCount'] = registry_information_messages_count_get($regObj);
        $reg['lastMessageDate'] = registry_information_last_message_date_get($regObj);
        $reg['failedMessagesCount'] = registry_information_failed_messages_count_get($regObj);
        $reg['lastFailedMessageDate'] = registry_information_last_failed_message_date_get($regObj);
        registry_information_destroy($regObj);
        return $reg;
    }
    /**
     * This function returns an object of Filters type for the selected folderrcpt
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = folder_rcpt_filters_get($this->getFolderRcptObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADFOLDERRCPTFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = folder_rcpt_save($this->getFolderRcptObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEFOLDERRCPTDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the folder recipient's name</td>
<tr><td>mboxName</td><td>the mbox name set for this folder recipient</td>
<tr><td>enable</td><td>the enabled/disabled status for the folder recipient</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = folder_rcpt_name_set($this->getFolderRcptObj() , $varValue);
            break;
            case "mboxname":
                $resp = folder_rcpt_mbox_name_set($this->getFolderRcptObj() , $varValue);
            break;
            case "enable":
                $resp = folder_rcpt_enable_set($this->getFolderRcptObj() , $varValue);
            break;
            case "publishcontactinfo":
                $resp = folder_rcpt_publish_contact_info_set($this->getFolderRcptObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETFOLDERRCPTVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETFOLDERRCPTVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the folder recipient's name</td>
<tr><td>mboxName</td><td>the mbox name set for this folder recipient</td>
<tr><td>enable</td><td>the enabled/disabled status for the folder recipient</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return folder_rcpt_name_get($this->getFolderRcptObj());
            break;
            case "mboxname":
                return folder_rcpt_mbox_name_get($this->getFolderRcptObj());
            break;
            case "enable":
                return folder_rcpt_enable_get($this->getFolderRcptObj());
            break;
            case "publishcontactinfo":
                return folder_rcpt_publish_contact_info_get($this->getFolderRcptObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETFOLDERRCPTVARERROR);
        }
    }
}
/** @} */ // end of group
?>
