<?php
/** 
 * \ingroup configServer
 * \defgroup configFtpBackup configFtpBackup
 * @{
*/
class FtpBackup {
    private $ftpBackupObj, $parent, $listener, $accesscontrol;
    public function __construct($ftpBackupObj, $parent) {
        $this->ftpBackupObj = $ftpBackupObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        ftp_backup_destroy($this->getFtpBackupObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getFtpBackupObj() {
        return $this->ftpBackupObj;
    }
/**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td><td>the maximum number of threads involved in I/O for the Ftp Backup&Restore service</td>
<tr><td>minConnThreads</td><td>the minimum number of threads involved in I/O for the Ftp Backup&Restore service</td>
<tr><td>maxErrors</td><td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td><td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>logLevel</td><td>the log level for the FTP Backup&Restore service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the FTP Backup&Restore service</td>
<tr><td>messagesTarEnabled</td><td>enabled/disabled tar archive on messages</td>
</table>
     */
    public function __get($name) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->getMaxConnThreads();
            break;
            case 'minconnthreads':
                return $this->getMinConnThreads();
            break;
            case 'maxerrors':
                return $this->getMaxErrors();
            break;
            case 'maxautherrors':
                return $this->getMaxAuthErrors();
            break;
            case 'loglevel':
                return $this->getLogLevel();
            break;
            case 'loghost':
                return $this->getLogHost();
            break;
            case 'logtype':
                return $this->getLogType();
            break;
            case 'messagestarenabled':
                return $this->getMessagesTarEnabled();
            default:;
            break;
        }
    }
/**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td><td>the maximum number of threads involved in I/O for the Ftp Backup&Restore service</td>
<tr><td>minConnThreads</td><td>the minimum number of threads involved in I/O for the Ftp Backup&Restore service</td>
<tr><td>maxErrors</td><td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td><td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>logLevel</td><td>the log level for the FTP Backup&Restore service</td>
<tr><td>logHost</td><td>the address of the host that offers log services</td>
<tr><td>logType</td><td>the log type for the FTP Backup&Restore service</td>
<tr><td>messagesTarEnabled</td><td>enabled/disabled tar archive on messages</td>
</table>
     */
    public function __set($name, $value) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minconnthreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxerrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxautherrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'loglevel':
                return $this->setLogLevel($value);
            break;
            case 'loghost':
                return $this->setLogHost($value);
            break;
            case 'logtype':
                return $this->setLogType($value);
            break;
            case 'messagestarenabled':
                return $this->setMessagesTarEnabled( $value );
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return ftp_backup_max_connection_threads_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return ftp_backup_min_connection_threads_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the maximum protocol errors number after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return ftp_backup_max_errors_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the maximum authentication errors number after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return ftp_backup_max_auth_errors_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return ftp_backup_log_level_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return ftp_backup_log_host_get($this->getFtpBackupObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return ftp_backup_log_type_get($this->getFtpBackupObj());
    }

    public function getMessagesTarEnabled() {
        return ftp_backup_messages_tar_enabled_get($this->getFtpBackupObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int max connection threads
     */
    public function setMaxConnThreads($value) {
        $set = ftp_backup_max_connection_threads_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = ftp_backup_min_connection_threads_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum protocol errors number after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = ftp_backup_max_errors_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum authentication errors number after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = ftp_backup_max_auth_errors_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = ftp_backup_log_level_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = ftp_backup_log_host_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = ftp_backup_log_type_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETLOGTYPE);
    }
    
    public function setMessagesTarEnabled($value) {
        $set = ftp_backup_messages_tar_enabled_set($this->getFtpBackupObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::FTPSETMESSAGESTARENABLED);
    }
    /**
     * @private
     * This function saves the Ftp Backup&Restore configuration on the Axigen server
     *
     * @return bool
     */
    public function save() {
        $save = ftp_backup_save($this->getFtpBackupObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::FTPSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = ftp_backup_reset($this->getFtpBackupObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::FTPRESET);
    }
    /**
     * This function starts the FTP Backup&Restore service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("ftpbackup");
    }
    /**
     * This function stops the FTP Backup&Restore service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("ftpbackup");
    }
    /**
     * This function returns an access control object for this service
     *
     * @return AccessControl
     */
    public function getAccessControl() {
        if (!is_resource($this->accesscontrol)) {
            $this->accesscontrol = ftp_backup_get_access_control($this->getFtpBackupObj() , $this->getSessionObj());
            if (!Debug::checkError($this->accesscontrol, "_p_access_control", Debug::FATALERROR, Message::FTPACCESSCONTROL)) return false;
        }
        return $this->accesscontrol;
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:21)
     */
    public function addListener($address) {
        $listeners = ftp_backup_listeners_get($this->getFtpBackupObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::FTPGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::FTPADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:21)
     */
    public function removeListener($address) {
        $listeners = ftp_backup_listeners_get($this->getFtpBackupObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::FTPGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FTPREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:21)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = ftp_backup_listeners_get($this->getFtpBackupObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::FTPGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::FTPUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = ftp_backup_listeners_get($this->getFtpBackupObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::FTPGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::FTPGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = ftp_backup_get_access_control($this->getFtpBackupObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::FTPACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
    /**
     * mount a backup mount point
     * @return bool
     * @param $mountPoint string mount point 
     * @param $domain string the domain to mount(optional)
     * @param $sinceLabel string since backup label(optional)
     * @param $backupLabel string backupLabel (optional)
     * @param $noremove bool don't show removed objects (optional, default: false)
     * @param $folderPath string folderPath - if objectName not set will mount the public folder, if set will mount the object folder (optional)
     * @param $objectName string object to mount (optional)
    */
    public function fileSystemMount( $mountPoint , $domain = null, $sinceLabel = null, $backupLabel = null, $noremove = false, $folderPath = null, $objectName = null) {
        $resp = ftp_backup_filesystem_mount($this->getFtpBackupObj(), $this->getSessionObj() , $mountPoint, $sinceLabel, $backupLabel, (int) $noremove, $domain, $objectName, $folderPath);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FILESYSTEMMOUNT);
    }

    /**
     * unmount a backup mount point
     * @return bool
     * @param $mountPoint string mount point 
    */
    public function fileSystemUnmount( $mountPoint ) {
        $resp = filesystem_unmount($this->getFtpBackupObj(), $this->getSessionObj() , $mountPoint);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FILESYSTEMUNMOUNT);
    }

    /**
     * remove a backup label 
     * @return bool
     * @param $backupLabel string the backup label to remove
     * @param $domain string the domain name where this backup label is created (optional)
    */
    public function removeBackupLabel( $backupLabel, $domain = null) {
        $resp = ftp_backup_remove_backup($this->getFtpBackupObj(), $this->getSessionObj() , $backupLabel, $domain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FTPBACKUPREMOVEBACKUPLABEL);
    }

    /**
     * purge backuplabels
     * @return bool
     * @param $domain string the domain name where backup label are created (optional)
    */
    public function purgeBackupLabels( $domain = null) {
        $resp = ftp_backup_purge_backups($this->getFtpBackupObj(), $this->getSessionObj() , $domain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FTPBACKUPPURGEBACKUPLABELS);
    }

}
/** @} */ // end of group
?>
