<?php
/**
 * this object contains the Group data for the selected group
 * \ingroup updateDomain
 * \defgroup updateGroup updateGroup
 * @{
 */
class Group {
    private $group, $parent, $filters;
    public function __construct($groupObj, $parentObj) {
        $this->group = $groupObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        group_destroy($this->getGroupObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getGroupObj() {
        return $this->group;
    }
    /**
     * returns an array with addresses for the current group
     * @return array
     */
    public function listAddresses() {
        $addresses = array();
        $groupIterObj = group_address_iterator_begin($this->getGroupObj());
        if (!Debug::checkError($groupIterObj, "_p_group_address_iterator", Debug::INFOERROR, Message::LISTGROUPADDRESSES)) return false;
        while (group_address_iterator_has_value($groupIterObj)) {
            $groupObj = group_address_iterator_value($groupIterObj);
            array_push($addresses, group_address_name_get($groupObj));
            group_address_iterator_next($groupIterObj);
        }
        group_address_iterator_destroy($groupIterObj);
        return $addresses;
    }
    /**
     * adds an address for the group
     * @return bool
     * @param $name string The new address
     */
    public function addAddress($name) {
        $resp = group_address_add($this->getGroupObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDGROUPADDRESS)) return false;
        return $this->save();
    }
    /**
     * removes an address from the group
     * @return bool
     * @param $name string The address to be removed from group
     */
    public function removeAddress($name) {
        $resp = group_address_remove_by_name($this->getGroupObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEGROUPADDRESS)) return false;
        return $this->save();
    }
    /**
     * returns an array with registry information
     * @return array
     */
    public function registryInformation() {
        $regObj = group_registry_information_get($this->getGroupObj() , $this->getSessionObj());
        if (!Debug::checkError($regObj, "_p_registry_information", Debug::INFOERROR, Message::GROUPREGISTRYINFO)) return false;
        $reg['creationDate'] = registry_information_creation_date_get($regObj);
        $reg['modificationDate'] = registry_information_modification_date_get($regObj);
        $reg['messagesCount'] = registry_information_messages_count_get($regObj);
        registry_information_destroy($regObj);
        return $reg;
    }
    /**
     * this method returns an object of Filters type for the selected group
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = group_filters_get($this->getGroupObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADGROUPFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = group_save($this->getGroupObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEGROUPDATA);
    }

    /**
     * resets the ldap associations
     * @return bool
     */
    public function resetLdapAssociation() {
        if (!$this) return false;
        $resp = group_reset_ldapassociation($this->getAccountObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::GROUPRESETLDAPASSOCIATION);
    }

    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the group's name - only usable in an UPDATE operation</td>
<tr><td>enable</td><td>enabled/disabled status for the group</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
<tr><td>distributeEmailTo</td><td>specify group's email distribution target</td>
<tr><td>membersSendEmailAsGroup</td><td>desc allow members to use group's email address as sender address</td>
<tr><td>receiveEmailFrom</td><td>specify who is allowed to send emails to this group</td>
</table>
     */
    public function __set($varName, $varValue) {
        switch (strtolower($varName)) {
            case "name":
                $resp = group_name_set($this->getGroupObj() , $varValue);
            break;
            case "enable":
                $resp = group_enabled_set($this->getGroupObj() , $varValue);
            break;
            case "publishcontactinfo":
                $resp = group_publish_contact_info_set($this->getGroupObj() , $varValue);
            break;
            case "distributeemailto":
                $resp = group_distribute_email_to_set($this->getGroupObj() , $varValue);
            break;
            case "memberssendemailasgroup":
                $resp = group_members_send_email_as_group_set($this->getGroupObj() , $varValue);
            break;
            case "receiveemailfrom":
                $resp = group_receive_email_from_set($this->getGroupObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETGROUPVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETGROUPVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the group's name - only usable in an UPDATE operation</td>
<tr><td>enable</td><td>enabled/disabled status for the group</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
<tr><td>distributeEmailTo</td><td>specify group's email distribution target</td>
<tr><td>membersSendEmailAsGroup</td><td>desc allow members to use group's email address as sender address</td>
<tr><td>receiveEmailFrom</td><td>specify who is allowed to send emails to this group</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return group_name_get($this->getGroupObj());
            break;
            case "enable":
                return group_enabled_get($this->getGroupObj());
            break;
            case "publishcontactinfo":
                return group_publish_contact_info_get($this->getGroupObj());
            break;
            case "distributeemailto":
                return group_distribute_email_to_get($this->getGroupObj());
            break;
            case "memberssendemailasgroup":
                return group_members_send_email_as_group_get($this->getGroupObj());
            break;
            case "receiveemailfrom":
                return group_receive_email_from_get($this->getGroupObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETGROUPVARERROR);
        }
    }
}
/** @} */ // end of group
?>
