<?php
/**
 * \ingroup configServer
 * \defgroup configImapProxy configImapProxy
 * @{
*/
class ImapProxy {
    private $imapProxyObj, $parent, $listener, $accesscontrol;
    public function __construct($imapProxyObj, $parent) {
        $this->imapProxyObj = $imapProxyObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        proxy_destroy($this->getImapProxyObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getImapProxyObj() {
        return $this->imapProxyObj;
    }
/**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the IMAP Proxy service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the IMAP Proxy service</td>
<tr><td>maxErrors</td>
<td>the maximum protocol errors number after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>allowStartTls</td>
<td>the secure connection (which start with STARTTLS)</td>
<tr><td>authenticateOnProxy</td>
<td>if the authentication should be also done on proxy</td>
<tr><td>mappingDataUsermapName</td>
<td>the mapping usermap name for the proxy</td>
<tr><td>mappingDataMappingHost</td>
<td>the mapping data host for the proxy</td>
<tr><td>mappingDataMappingPort</td>
<td>the mapping data port for the proxy</td>
<tr><td>connectionDataTimeout</td>
<td>the timeout for the read/write operation</td>
<tr><td>connectionDataMaxConnections</td>
<td>the maximum number of simultaneous connections</td>
<tr><td>connectionDataSslEnable</td>
<td>if the connection should be SSL</td>
<tr><td>connectionDataLocalInterface</td>
<td>the address of the interface used to make the connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the IMAP Proxy service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the IMAP Proxy service</td>
<tr><td>greetingsText</td>
<td>the greeting text for this service</td>
</table>
*/
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'maxErrors':
                return $this->getMaxErrors();
            break;
            case 'maxAuthErrors':
                return $this->getMaxAuthErrors();
            break;
            case 'allowStartTls':
                return $this->getAllowStartTls();
            break;
            case 'authenticateOnProxy':
                return $this->getAuthenticateOnProxy();
            break;
            case 'mappingDataUsermapName':
                return $this->getMappingDataUsermapName();
            break;
            case 'mappingDataMappingHost':
                return $this->getMappingDataMappingHost();
            break;
            case 'mappingDataMappingPort':
                return $this->getMappingDataMappingPort();
            break;
            case 'connectionDataTimeout':
                return $this->getConnectionDataTimeout();
            break;
            case 'connectionDataMaxConnections':
                return $this->getConnectionDataMaxConnections();
            break;
            case 'connectionDataSslEnable':
                return $this->getConnectionDataSslEnable();
            break;
            case 'connectionDataLocalInterface':
                return $this->getConnectionDataLocalInterface();
            break;
            case 'userdbConnectorType':
                return $this->getUserdbConnectorType();
            break;
            case 'userdbConnectorName':
                return $this->getUserdbConnectorName();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            case 'greetingsText':
                return $this->getGreetingsText();
            break;
            default:;
            break;
        }
    }
/**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the IMAP Proxy service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the IMAP Proxy service</td>
<tr><td>maxErrors</td>
<td>the maximum protocol errors number after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>allowStartTls</td>
<td>the secure connection (which start with STARTTLS)</td>
<tr><td>authenticateOnProxy</td>
<td>if the authentication should be also done on proxy</td>
<tr><td>mappingDataUsermapName</td>
<td>the mapping usermap name for the proxy</td>
<tr><td>mappingDataMappingHost</td>
<td>the mapping data host for the proxy</td>
<tr><td>mappingDataMappingPort</td>
<td>the mapping data port for the proxy</td>
<tr><td>connectionDataTimeout</td>
<td>the timeout for the read/write operation</td>
<tr><td>connectionDataMaxConnections</td>
<td>the maximum number of simultaneous connections</td>
<tr><td>connectionDataSslEnable</td>
<td>if the connection should be SSL</td>
<tr><td>connectionDataLocalInterface</td>
<td>the address of the interface used to make the connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the IMAP Proxy service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the IMAP Proxy service</td>
<tr><td>greetingsText</td>
<td>the greeting text for this service</td>
</table>
*/
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxErrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxAuthErrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'allowStartTls':
                return $this->setAllowStartTls($value);
            break;
            case 'authenticateOnProxy':
                return $this->setAuthenticateOnProxy($value);
            break;
            case 'mappingDataUsermapName':
                return $this->setMappingDataUsermapName($value);
            break;
            case 'mappingDataMappingHost':
                return $this->setMappingDataMappingHost($value);
            break;
            case 'mappingDataMappingPort':
                return $this->setMappingDataMappingPort($value);
            break;
            case 'connectionDataTimeout':
                return $this->setConnectionDataTimeout($value);
            break;
            case 'connectionDataMaxConnections':
                return $this->setConnectionDataMaxConnections($value);
            break;
            case 'connectionDataSslEnable':
                return $this->setConnectionDataSslEnable($value);
            break;
            case 'connectionDataLocalInterface':
                return $this->setConnectionDataLocalInterface($value);
            break;
            case 'userdbConnectorType':
                return $this->setUserdbConnectorType($value);
            break;
            case 'userdbConnectorName':
                return $this->setUserdbConnectorName($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            case 'greetingsText':
                return $this->setGreetingsText($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return proxy_max_connection_threads_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return proxy_min_connection_threads_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of protocol errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return proxy_max_errors_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of authentication errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return proxy_max_auth_errors_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if secure connections (which start with STARTTLS) are allowed for this service and 0 if otherwise
     *
     * @return int
     */
    public function getAllowStartTls() {
        return proxy_allow_start_tls_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if the proxy authentication is also done on proxy and 0 if otherwise
     *
     * @return int
     */
    public function getAuthenticateOnProxy() {
        return proxy_authenticate_on_proxy_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the mapping data usermap name
     *
     * @return String
     */
    public function getMappingDataUsermapName() {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            return mapping_data_usermap_name_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the mapping data host
     *
     * @return String
     */
    public function getMappingDataMappingHost() {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            return mapping_data_mapping_host_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the mapping data port
     *
     * @return String
     */
    public function getMappingDataMappingPort() {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            return mapping_data_mapping_port_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the read-write timeout in seconds
     *
     * @return int
     */
    public function getConnectionDataTimeout() {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            return connection_data_timeout_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the total number of connections allowed on the proxy to whom the connection data object belongs
     *
     * @return
     */
    public function getConnectionDataMaxConnections() {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            return connection_data_max_connections_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns 1 if the proxy is SSL-enabled and 0 if otherwise
     *
     * @return
     */
    public function getConnectionDataSslEnable() {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            return connection_data_is_ssl_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the local interface on which the proxy listens
     *
     * @return
     */
    public function getConnectionDataLocalInterface() {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            return connection_data_local_interface_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the userdb connector type
     *
     * @return String
     */
    public function getUserdbConnectorType() {
        return proxy_userdb_connector_type_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the userdb connector name
     *
     * @return String
     */
    public function getUserdbConnectorName() {
        return proxy_userdb_connector_name_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service.
     *
     * @return int
     */
    public function getLogLevel() {
        return proxy_log_level_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return proxy_log_host_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return proxy_log_type_get($this->getImapProxyObj());
    }
    /**
     * @ignore
     */
    public function getGreetingsText() {
        return proxy_greetings_text_get($this->getImapProxyObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = proxy_max_connection_threads_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = proxy_min_connection_threads_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum number of protocol errors after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = proxy_max_errors_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum number of authentication errors after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = proxy_max_auth_errors_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets if secure connections (which start with STARTTLS) are allowed for this service
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, secure connections (which start with STARTTLS) are allowed for this service, if it is 0 then secure connections are not allowed
     */
    public function setAllowStartTls($value) {
        $set = proxy_allow_start_tls_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETALLOWSTARTTLS);
    }
    /**
     * @ignore
     * This function sets if the user's authentication is also done through proxy
     * @return bool
     *
     * @param $value int if the 'value' parameter is 1, the user's authentication is also done through proxy, if it is 0 the authentication is not done on proxy
     */
    public function setAuthenticateOnProxy($value) {
        $set = proxy_authenticate_on_proxy_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETAUTHONPROXY);
    }
    /**
     * @ignore
     * This function sets the mapping usermap name for the proxy
     * @return bool
     *
     * @param $value string the mapping data name
     */
    public function setMappingDataUsermapName($value) {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            $set = mapping_data_usermap_name_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATANAME);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATANAME);
        }
    }
    /**
     * @ignore
     * This function sets the mapping host for the proxy
     * @return bool
     *
     * @param $value string the mapping host
     */
    public function setMappingDataMappingHost($value) {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            $set = mapping_data_mapping_host_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATAHOST);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATAHOST);
        }
    }
    /**
     * @ignore
     * This function sets the mapping port for the proxy
     * @return bool
     *
     * @param $value int the mapping port
     */
    public function setMappingDataMappingPort($value) {
        $mappingData = proxy_mapping_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::IMAPPROXYGETMAPPINGDATA)) {
            $set = mapping_data_mapping_port_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATAPORT);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETMAPPINGDATAPORT);
        }
    }
    /**
     * @ignore
     * This function sets the timeout for the read/write operation
     * @return bool
     *
     * @param $value int the timeout for the read/write operation
     */
    public function setConnectionDataTimeout($value) {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            $set = connection_data_timeout_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATATIMEOUT);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATATIMEOUT);
        }
    }
    /**
     * @ignore
     * This function sets the maximum number of simultaneous connections
     * @return bool
     *
     * @param $value int the maximum number of simultaneous connections
     */
    public function setConnectionDataMaxConnections($value) {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            $set = connection_data_max_connections_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATAMAXCON);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATAMAXCON);
        }
    }
    /**
     * @ignore
     * This function sets if the connection should be SSL
     * @return bool
     *
     * @param $value int If the value parameter is 1, this function enables SSL on the proxy, if it is 0, it disables it
     */
    public function setConnectionDataSslEnable($value) {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            $set = connection_data_is_ssl_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATASSLENABLE);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATASSLENABLE);
        }
    }
    /**
     * @ignore
     * This function sets the address of the interface used to make the connections
     * @return bool
     *
     * @param $value string the address of the interface used to make the connections
     */
    public function setConnectionDataLocalInterface($value) {
        $connectionData = proxy_connection_data_get($this->getImapProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::IMAPPROXYGETCONNDATA)) {
            $set = connection_data_local_interface_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATALOCALI);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSETCONNDATALOCALI);
        }
    }
    /**
     * @ignore
     * This function sets the userdb connector type
     * @return bool
     *
     * @param $value string Valid string values for the 'value' parameter are: "local", "ldap" or "ldapBind"
     */
    public function setUserdbConnectorType($value) {
        $set = proxy_userdb_connector_type_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYUSERDBCONNTYPE);
    }
    /**
     * @ignore
     * This function sets the name of the userdb connector
     * @return bool
     *
     * @param $value string userdb connector name
     */
    public function setUserdbConnectorName($value) {
        $set = proxy_userdb_connector_name_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYUSERDBCONNNAME);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = proxy_log_level_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = proxy_log_host_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = proxy_log_type_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETLOGTYPE);
    }
    /**
     * @ignore
     */
    public function setGreetingsText($value) {
        $set = proxy_greetings_text_set($this->getImapProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::IMAPPROXYSETGREETING);
    }
    /**
     * @private
     * This function saves the IMAP Proxy configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = proxy_save($this->getImapProxyObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::IMAPPROXYSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = proxy_reset($this->getImapProxyObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::IMAPPROXYRESET);
    }
    /**
     * This function starts the IMAP service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("imapproxy");
    }
    /**
     * This function stops the IMAP service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("imapproxy");
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = proxy_listeners_get($this->getImapProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::IMAPPROXYGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::IMAPPROXYADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = proxy_listeners_get($this->getImapProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::IMAPPROXYGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::IMAPPROXYREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = proxy_listeners_get($this->getImapProxyObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::IMAPPROXYGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::IMAPPROXYUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = proxy_listeners_get($this->getImapProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::IMAPPROXYGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::IMAPPROXYGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = imap_proxy_get_access_control($this->getImapProxyObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::IMAPPROXYACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
}
/** @} */ // end of group
?>
