<?php
/**
 * \ingroup configFilters
 * \defgroup listIntegratedFilters listIntegratedFilters
 * @{
 */
class IntegratedFilters {
    private $integratedfilter, $parent;
    public function __construct($integratedfilterObj, $parentObj) {
        $this->integratedfilter = $integratedfilterObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getIntegratedFilterObj() {
        return $this->integratedfilter;
    }
    /**
     * This method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = filters_save($this->parent->getFiltersObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEINTEGRATEDFILTERDATA);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the name of the filter </td>
<tr><td>type</td>
<td>the type of the filter </td>
<tr><td>command</td>
<td>the command to start the filter </td>
<tr><td>enable</td>
<td>enabled/disabled</td>
<tr><td>requestTimeout</td>
<td>the request time out</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = integrated_filter_name_set($this->getIntegratedFilterObj() , $varValue);
            break;
            case "type":
                $resp = integrated_filter_type_set($this->getIntegratedFilterObj() , $varValue);
            break;
            case "command":
                $resp = integrated_filter_command_set($this->getIntegratedFilterObj() , $varValue);
            break;
            case "enable":
                $resp = integrated_filter_enable_set($this->getIntegratedFilterObj() , $varValue);
            break;
            case "requesttimeout":
                $resp = integrated_filter_request_timeout_set($this->getIntegratedFilterObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETINTEGRATEDFILTERVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETINTEGRATEDFILTERVARERROR);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the name of the filter </td>
<tr><td>type</td>
<td>the type of the filter </td>
<tr><td>command</td>
<td>the command to start the filter </td>
<tr><td>enable</td>
<td>enabled/disabled</td>
<tr><td>requestTimeout</td>
<td>the request time out</td>
</table>
     */
   public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return integrated_filter_name_get($this->getIntegratedFilterObj());
            break;
            case "type":
                return integrated_filter_type_get($this->getIntegratedFilterObj());
            break;
            case "command":
                return integrated_filter_command_get($this->getIntegratedFilterObj());
            break;
            case "enable":
                return integrated_filter_enable_get($this->getIntegratedFilterObj());
            break;
            case "requesttimeout":
                return integrated_filter_request_timeout_get($this->getIntegratedFilterObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETINTEGRATEDFILTERVARERROR);
        }
    }

    /**
     * Start the integrated filter database update
     * @return bool
     */
    public function updateDatabase()
    {
        $resp = filters_update_database_integrated_filter($this->getIntegratedFilterObj(), $this->getSessionObj() );
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INTEGRATEDFILTERSUPDATEDB);
    }

    /**
     * Check the integrated filter database status
     * @return string
     */
    public function databaseUpdateStatus()
    {
        $obj = filters_database_update_status_integrated_filter($this->getIntegratedFilterObj(), $this->getSessionObj() );
        if (!Debug::checkError($obj, "_p_update_status", Debug::INFOERROR, Message::INTEGRATEDFILTERUPDATESTATUS)) return false;

        $data['update_status'] = update_status_update_s_get($obj);
        $data['last_update'] = update_status_last_update_get($obj);
        $data['percent'] = update_status_percent_get($obj);
        $data['error'] = update_status_error_get($obj);

        return $data;
    }
    public function getConfigParams()
    {
        $obj = load_integrated_filter_params($this->getIntegratedFilterObj(), $this->getSessionObj());
        if (!Debug::checkError($obj, "_p_if_config_params", Debug::INFOERROR, Message::INTEGRATEDFILTERPARAMS)) return false;
        do {
            $tmp['name'] = integrated_filter_params_name($obj);
            $tmp['value'] = integrated_filter_params_value($obj);

            $resp[] = $tmp;

        }while($obj = integrated_filter_params_next( $obj ));

        return $resp;
    }

    public function addConfigParam($var, $value) 
    {
        $resp =filters_integrated_filter_add_param($this->getIntegratedFilterObj(), $this->getSessionObj(), $var, $value);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INTEGRATEDFILTERPARAMADD);
    }

    public function updateConfigParam($var, $newValue)
    {
        $resp = filters_integrated_filter_update_param($this->getIntegratedFilterObj(), $this->getSessionObj(), $var, $newValue);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INTEGRATEDFILTERPARAMUPDATE);
    }

    public function removeConfigParam($var)
    {
        $resp = filters_integrated_filter_remove_param($this->getIntegratedFilterObj(), $this->getSessionObj(), $var);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INTEGRATEDFILTERPARAMREMOVE);
    }

}
/** @} */ // end of group
?>
