<?php
/**
 * \ingroup configUserDb
 * \defgroup configLdapConnector configLdapConnector
 * @{
*/
class LdapConnector {
    private $ldap, $parent;
    public function __construct($ldapObj, $parentObj) {
        $this->ldap = $ldapObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getLdapConnectorObj() {
        return $this->ldap;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = ldap_connector_save($this->getLdapConnectorObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVELDAPCONNECTORDATA);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the Ldap connector name</td>
<tr><td>hostUrl</td>
<td>the Ldap host URL (deprecated)</td>
<tr><td>bindDN</td>
<td>the distinguished name for binding</td>
<tr><td>bindPass</td>
<td>the password for binding</td>
<tr><td>searchBase</td>
<td>the formatted string with the base where to search for the user (deprecated)</td>
<tr><td>searchPattern</td>
<td>the formatted string with the user search pattern (deprecated)</td>
<tr><td>passwordField</td>
<td>the name of the field containing the password (deprecated)</td>
<tr><td>axigenHostField</td>
<td>the name of the field containing the Axigen server hostname</td>
<tr><td>useFirst</td>
<td>the first returned field to be used if more are found (deprecated)</td>
<tr><td>ldapURI1</td>
<td>the first URI to use</td>
<tr><td>ldapURI2</td>
<td>the second URI to use</td>
<tr><td>ldapURI3</td>
<td>the third URI to use</td>
<tr><td>ldapURI4</td>
<td>the fourth URI to use</td>
<tr><td>ldapURI5</td>
<td>the fifth URI to use</td>
<tr><td>synchronizationDirection</td>
<td>possible values: axigenToLdap | ldapToAxigen | bothWays</td>
<tr><td>synchronizationConflictResolution</td>
<td>possible values: axigenWins | ldapWins | noChange</td>
<tr><td>serverType</td>
<td>possible values:  OpenLdap | ActiveDirectory</td>
<tr><td>timeout</td>
<td>the connection timeout</td>
<tr><td>accountBaseDN</td>
<td>the account base DN</td>
<tr><td>groupBaseDN</td>
<td>the group base DN</td>
<tr><td>useCustomSchema</td>
<td>the enable/disable usage of a custom schema</td>
<tr><td>customSchemaFile</td>
<td>path to the custom schema file</td>
<tr><td>pollingInterval</td>
<td>the interval to check for changes in Ldap</td>
<tr><td>transientErrorRetryInterval</td>
<td>retry interval for temporary errors</td>
<tr><td>ignoreLDAPDeletes</td>
<td>enabled/disabled the LDAP deletes to be synchronized in axigen</td>
<tr><td>clusteredSetup</td>
<td>enabled/disabled clustered setup</td>
<tr><td>searchDomainAliases </td>
<td>enabled/disabled domain aliases ldap search </td>
<tr><td>replicaID </td>
<td>id of replica (0-999); must be unique between axigen servers</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = ldap_connector_name_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "hosturl":
                Debug::setDeprecated("LdapConnector->hostUrl");
                return false;
            break;
            case "binddn":
                $resp = ldap_connector_bind_dn_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "bindpass":
                $resp = ldap_connector_bind_pass_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "searchbase":
                Debug::setDeprecated("LdapConnector->searchBase");
                return false;
            break;
            case "searchpattern":
                Debug::setDeprecated("LdapConnector->searchPattern");
                return false;
            break;
            case "passwordfield":
                Debug::setDeprecated("LdapConnector->passwordField");
                return false;
            break;
            case "axigenhostfield":
                $resp = ldap_connector_axigen_host_field_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "usefirst":
                Debug::setDeprecated("LdapConnector->useFirst");
                return false;
            break;
            case "ldapuri1":
                $resp = ldap_connector_ldap_uri_1_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "ldapuri2":
                $resp = ldap_connector_ldap_uri_2_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "ldapuri3":
                $resp = ldap_connector_ldap_uri_3_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "ldapuri4":
                $resp = ldap_connector_ldap_uri_4_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "ldapuri5":
                $resp = ldap_connector_ldap_uri_5_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "servertype":
                $resp = ldap_connector_server_type_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "timeout":
                $resp = ldap_connector_timeout_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "pollinginterval":
                $resp = ldap_connector_polling_interval_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "transienterrorretryinterval":
                $resp = ldap_connector_transient_error_retry_interval_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "synchronizationdirection":
                $resp = ldap_connector_synchronization_direction_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "synchronizationconflictresolution":
                $resp = ldap_connector_synchronization_conflict_resolution_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "accountbasedn":
                $resp = ldap_connector_account_base_dn_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "groupbasedn":
                $resp = ldap_connector_group_base_dn_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "usecustomschema":
                $resp = ldap_connector_use_custom_schema_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "customschemafile":
                $resp = ldap_connector_custom_schema_file_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "clusteredsetup":
                $resp = ldap_connector_clustered_setup_set($this->getLdapConnectorObj() , $varValue);
            break;
            case "ignoreldapdeletes":
                $resp = ldap_connector_ignore_ldap_deletes_set($this->getLdapConnectorObj(), $varValue);
            break;
            case "searchdomainaliases":
                $resp = ldap_connector_search_domain_aliases_set($this->getLdapConnectorObj(), $varValue);
            break;
            case "replicaid":
                $resp = ldap_connector_replica_id_set($this->getLdapConnectorObj(), $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETLDAPCONNECTORVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETLDAPCONNECTORVARERROR);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the Ldap connector name</td>
<tr><td>hostUrl</td>
<td>the Ldap host URL (deprecated)</td>
<tr><td>bindDN</td>
<td>the distinguished name for binding</td>
<tr><td>bindPass</td>
<td>the password for binding</td>
<tr><td>searchBase</td>
<td>the formatted string with the base where to search for the user (deprecated)</td>
<tr><td>searchPattern</td>
<td>the formatted string with the user search pattern (deprecated)</td>
<tr><td>passwordField</td>
<td>the name of the field containing the password (deprecated)</td>
<tr><td>axigenHostField</td>
<td>the name of the field containing the Axigen server hostname</td>
<tr><td>useFirst</td>
<td>the first returned field to be used if more are found (deprecated)</td>
<tr><td>ldapURI1</td>
<td>the first URI to use</td>
<tr><td>ldapURI2</td>
<td>the second URI to use</td>
<tr><td>ldapURI3</td>
<td>the third URI to use</td>
<tr><td>ldapURI4</td>
<td>the fourth URI to use</td>
<tr><td>ldapURI5</td>
<td>the fifth URI to use</td>
<tr><td>synchronizationDirection</td>
<td>possible values: axigenToLdap | ldapToAxigen | bothWays</td>
<tr><td>synchronizationConflictResolution</td>
<td>possible values: axigenWins | ldapWins | noChange</td>
<tr><td>serverType</td>
<td>possible values:  OpenLdap | ActiveDirectory</td>
<tr><td>timeout</td>
<td>the connection timeout</td>
<tr><td>accountBaseDN</td>
<td>the account base DN</td>
<tr><td>groupBaseDN</td>
<td>the group base DN</td>
<tr><td>useCustomSchema</td>
<td>the enable/disable usage of a custom schema</td>
<tr><td>customSchemaFile</td>
<td>path to the custom schema file</td>
<tr><td>pollingInterval</td>
<td>the interval to check for changes in Ldap</td>
<tr><td>transientErrorRetryInterval</td>
<td>retry interval for temporary errors</td>
<tr><td>ignoreLDAPDeletes</td>
<td>enabled/disabled the LDAP deletes to be synchronized in axigen</td>
<tr><td>clusteredSetup</td>
<td>enabled/disabled clustered setup</td>
<tr><td>searchDomainAliases </td>
<td>enabled/disabled domain aliases ldap search </td>
<tr><td>replicaID </td>
<td>id of replica (0-999); must be unique between axigen servers</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return ldap_connector_name_get($this->getLdapConnectorObj());
            break;
            case "hosturl":
                Debug::setDeprecated("LdapConnector->hostUrl");
                return false;
            break;
            case "binddn":
                return ldap_connector_bind_dn_get($this->getLdapConnectorObj());
            break;
            case "bindpass":
                return ldap_connector_bind_pass_get($this->getLdapConnectorObj());
            break;
            case "searchbase":
                Debug::setDeprecated("LdapConnector->searchBase");
                return false;
            break;
            case "searchpattern":
                Debug::setDeprecated("LdapConnector->searchPattern");
                return false;
            break;
            case "passwordfield":
                Debug::setDeprecated("LdapConnector->passwordField");
                return false;
            break;
            case "axigenhostfield":
                return ldap_connector_axigen_host_field_get($this->getLdapConnectorObj());
            break;
            case "usefirst":
                Debug::setDeprecated("LdapConnector->useFirst");
                return false;
            break;
            case "ldapuri1":
                return ldap_connector_ldap_uri_1_get($this->getLdapConnectorObj());
            break;
            case "ldapuri2":
                return ldap_connector_ldap_uri_2_get($this->getLdapConnectorObj());
            break;
            case "ldapuri3":
                return ldap_connector_ldap_uri_3_get($this->getLdapConnectorObj());
            break;
            case "ldapuri4":
                return ldap_connector_ldap_uri_4_get($this->getLdapConnectorObj());
            break;
            case "ldapuri5":
                return ldap_connector_ldap_uri_5_get($this->getLdapConnectorObj());
            break;
            case "servertype":
                return ldap_connector_server_type_get($this->getLdapConnectorObj());
            break;
            case "timeout":
                return ldap_connector_timeout_get($this->getLdapConnectorObj());
            break;
            case "pollinginterval":
                return ldap_connector_polling_interval_get($this->getLdapConnectorObj());
            break;
            case "transienterrorretryinterval":
                return ldap_connector_transient_error_retry_interval_get($this->getLdapConnectorObj());
            break;
            case "synchronizationdirection":
                return ldap_connector_synchronization_direction_get($this->getLdapConnectorObj());
            break;
            case "synchronizationconflictresolution":
                return ldap_connector_synchronization_conflict_resolution_get($this->getLdapConnectorObj());
            break;
            case "accountbasedn":
                return ldap_connector_account_base_dn_get($this->getLdapConnectorObj());
            break;
            case "groupbasedn":
                return ldap_connector_group_base_dn_get($this->getLdapConnectorObj());
            break;
            case "usecustomschema":
                return ldap_connector_use_custom_schema_get($this->getLdapConnectorObj());
            break;
            case "customschemafile":
                return ldap_connector_custom_schema_file_get($this->getLdapConnectorObj());
            break;
            case "clusteredsetup":
                return ldap_connector_clustered_setup_get($this->getLdapConnectorObj());
            break;
            case "ignoreldapdeletes":
                return ldap_connector_ignore_ldap_deletes_get($this->getLdapConnectorObj());
            break;
            case "searchdomainaliases":
                return ldap_connector_search_domain_aliases_get($this->getLdapConnectorObj());
            break;
            case "replicaid":
                return ldap_connector_replica_id_get($this->getLdapConnectorObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETLDAPCONNECTORVARERROR);
        }
    }
}
/** @} */ // end of group
?>
