<?php
/**
 * This object contains the Limits data
 * \ingroup updateAccount
 * \defgroup configLimits configLimits
 * @{
 */
class Limits {
    private $limit, $parent, $services;
    public function __construct($limitObj, $parentObj) {
        $this->limit = $limitObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        limits_destroy($this->getLimitObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getLimitObj() {
        return $this->limit;
    }
    public function getLimitServicesObj() {
        if (!is_resource($this->services)) {
            $this->services = limits_services_get($this->getLimitObj());
            if (!Debug::checkError($this->services, "_p_services", Debug::FATALERROR, Message::GETLIMITSSSERVICES)) return false;
        }
        return $this->services;
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>sentMessagesCount</td>
<td> the maximum number of mails a user can send in a specified interval</td>
<tr><td>sentRecipientsCount</td>
<td> the maximum number of recipients of emails in a specified interval</td>
<tr><td>sentOverquotaFileName</td>
<td> the name of the eml template used in case of overquota</td>
<tr><td>sentOverquotaEmailAddress</td>
<td> the email address used for sending overquota notifications</td>
<tr><td>sentMessagesSize</td>
<td> the maximum size of mails a user can send in a specified interval</td>
<tr><td>sentMessagesInterval</td>
<td> the specified interval in seconds</td>
<tr><td>pop3ConnectionCount</td>
<td> the number of simultaneous POP3 connections</td>
<tr><td>imapConnectionCount</td>
<td> the number of simultaneous IMAP connections</td>
<tr><td>webmailRcptCount</td>
<td> the maximum number of recipients for an email composed using Webmail</td>
<tr><td>webmailSessionCount</td>
<td> the maximum simultaneous Webmail sessions</td>
<tr><td>webmailAttSize</td>
<td> the size limit of an attachment that can be uploaded using Webmail</td>
<tr><td>webmailAttCount</td>
<td> the maximum number of attachments for a mail composed in Webmail</td>
<tr><td>webmailMessageSize</td>
<td> the size limit for a mail (body + attachments) composed in Webmail</td>
<tr><td>rpopConnectionCount</td>
<td> the maximum number of RPOP connections a user is allowed to define</td>
<tr><td>rpopRetrievalInterval</td>
<td> the minimum time interval (in minutes) between two RPOP retrievals on the same connection</td>
<tr><td>maillistUserCount</td>
<td> mail list user count</td>
<tr><td>passwordEnforcementEnabled</td>
<td> the enabled/disabled status for the Password Enforcement policy</td>
<tr><td>passwordRecoveryMethods</td>
<td> the methods for password recovery feature (valid methods: secretQuestion, peaBased)</td>
<tr><td>usernameRecoveryMethods</td>
<td> the methods for username recovery feature (valid methods: peaBased)</td>
<tr><td>passwordRecoveryFileName</td>
<td> the eml file for password recovery feature</td>
<tr><td>usernameRecoveryFileName</td>
<td> the eml file for username recovery feature</td>
<tr><td>minimumPasswordLength</td>
<td> the minimum size of the password</td>
<tr><td>maximumPasswordLength</td>
<td> the maximum size of the password</td>
<tr><td>requiredPasswordCharacters</td>
<td> the required characters for setting a password</td>
<tr><td>htmlFilterLevel</td>
<td> the security level for a HTML mail body (0-3)</td>
<tr><td>temporaryAliasesCount</td>
<td> the temporary email address count limit</td>
<tr><td>temporaryAliasesInterval</td>
<td> the temporary email address duration limit</td>
<tr><td>enableProcessing</td>
<td> the enabled/disabled status for Processing</td>
<tr><td>enableSmtpIncoming</td>
<td> the enabled/disabled status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td> the enabled/disabled status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td> the enabled/disabled status for POP3</td>
<tr><td>enablePop3Proxy</td>
<td> the enabled/disabled status for POP3 Proxy</td>
<tr><td>enableRpop</td>
<td> the enabled/disabled status for RPOP</td>
<tr><td>enableImap</td>
<td> the enabled/disabled status for IMAP</td>
<tr><td>enableImapProxy</td>
<td> the enabled/disabled status for IMAP Proxy</td>
<tr><td>enableWebmail</td>
<td> the enabled/disabled status for Webmail</td>
<tr><td>enableWebmailProxy</td>
<td> the enabled/disabled status for Webmail Proxy</td>
<tr><td>enableCli</td>
<td> the enabled/disabled status for CLI</td>
<tr><td>enableLog</td>
<td> the enabled/disabled status for Log</td>
<tr><td>enableReporting</td>
<td> the enabled/disabled status for Reporting</td>
<tr><td>enableFtpBackup</td>
<td> the enabled/disabled status for Ftp Backup</td>
<tr><td>enableActiveSync</td>
<td> enable/disable ActiveSync</td>
<tr><td>activeSyncOptions</td>
<td> ActiveSync options. Values: email contact pim (separated by space)</td>
<tr><td>enableOutlookConnector</td>
<td> enabled/disabled Outlook Connector</td>
<tr><td>enablePersonalOrganizer</td>
<td> enabled/disabled Personal Organizer</td>
<tr><td>quotaSendMessageThreshold</td>
<td> the percent of used quota which blocks user from sending messages (avaible only for maillist)</td>
<tr><td>passExpirationEnabled</td>
<td> enabled/disabled password expiration</td>
<tr><td>passExpirationInterval</td>
<td> the interval of time in days that may pass from the moment the password was changed until the moment it expires and can not be used</td>
<tr><td>passRenewalInterval</td>
<td> the interval of time that must pass from the moment of the last change of the password until a new change can be performed</td>
<tr><td>passExpirationWarningEnabled</td>
<td> enabled/disabled sending of a warning message in case of password expiration</td>
<tr><td>passExpirationWarningInterval</td>
<td> the interval of time in days after which warning message is send</td>
<tr><td>passExpirationWarningSubject</td>
<td> the subject template of the email message sent as warning for password expiration</td>
<tr><td>passExpirationWarningSentDaily</td>
<td> enabled/disabled the password expiration warning to be sent every day during the expiration warning interval</td>
<tr><td>passHistorySize</td>
<td> the number of consecutive changed passwords that can not be used as new password when a change of password is performed</td>
<tr><td>passUnchangeable</td>
<td> enabled/disabled the capability for an user to change his/her password</td>
<tr><td>welcomeMessageEnabled</td>
<td> enabled/disabled the post of a welcome message in an account's mailbox</td>
<tr><td>welcomeMessageSubject</td>
<td> the subject template of the email message sent as welcome message</td>
<tr><td>passExpirationWarningBody</td>
<td> the body template of the email message sent as warning for password expiration</td>
<tr><td>welcomeMessageBody</td>
<td> the body template of the email message sent as welcome message</td>
<tr><td>allowIdentityConfirmation</td>
<td> enabled/disabled the use of Identity Confirmation</td>
<tr><td>editableContactInfo</td>
<td> enabled/disabled contact info being editable</td>
<tr><td>enableAutoMigration </td>
<td> enabled/disabled account's auto migration</td>
<tr><td>enableSharing</td>
<td> enabled/disabled sharing</td>
<tr><td>enableKAS</td>
<td> enabled/disabled KAS</td>
<tr><td>enableKAV</td>
<td> enabled/disabled KAV</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "sentmessagescount":
                $resp = limits_sent_messages_count_set($this->getLimitObj() , $varValue);
            break;
            case "sentrecipientscount":
                $resp = limits_sent_recipients_count_set($this->getLimitObj() , $varValue);
            break;
            case "sentoverquotafilename":
                $resp = limits_sent_overquota_file_name_set($this->getLimitObj() , $varValue);
            break;
            case "sentoverquotaemailaddress":
                $resp = limits_sent_overquota_email_address_set($this->getLimitObj() , $varValue);
            break;
            case "sentmessagessize":
                $resp = limits_sent_messages_size_set($this->getLimitObj() , $varValue);
            break;
            case "sentmessagesinterval":
                $resp = limits_sent_messages_interval_set($this->getLimitObj() , $varValue);
            break;
            case "pop3connectioncount":
                $resp = limits_pop3_connection_count_set($this->getLimitObj() , $varValue);
            break;
            case "imapconnectioncount":
                $resp = limits_imap_connection_count_set($this->getLimitObj() , $varValue);
            break;
            case "webmailrcptcount":
                $resp = limits_webmail_rcpt_count_set($this->getLimitObj() , $varValue);
            break;
            case "webmailsessioncount":
                $resp = limits_webmail_session_count_set($this->getLimitObj() , $varValue);
            break;
            case "webmailattsize":
                $resp = limits_webmail_att_size_set($this->getLimitObj() , $varValue);
            break;
            case "webmailattcount":
                $resp = limits_webmail_att_count_set($this->getLimitObj() , $varValue);
            break;
            case "webmailmessagesize":
                $resp = limits_webmail_message_size_set($this->getLimitObj() , $varValue);
            break;
            case "rpopconnectioncount":
                $resp = limits_rpop_connection_count_set($this->getLimitObj() , $varValue);
            break;
            case "rpopretrievalinterval":
                $resp = limits_rpop_retrieval_interval_set($this->getLimitObj() , $varValue);
            break;
            case "maillistusercount":
                $resp = limits_maillist_user_count_set($this->getLimitObj() , $varValue);
            break;
            case "passwordenforcementenabled":
                $resp = limits_password_enforcement_enabled_set($this->getLimitObj() , $varValue);
            break;
            case "passwordrecoverymethods":
                $resp = limits_password_recovery_methods_set($this->getLimitObj() , $varValue);
            break;
            case "usernamerecoverymethods":
                $resp = limits_username_recovery_methods_set($this->getLimitObj() , $varValue);
            break;
            case "passwordrecoveryfilename":
                $resp = limits_password_recovery_file_name_set($this->getLimitObj() , $varValue);
            break;
            case "usernamerecoveryfilename":
                $resp = limits_username_recovery_file_name_set($this->getLimitObj() , $varValue);
            break;
            case "minimumpasswordlength":
                $resp = limits_minimum_password_length_set($this->getLimitObj() , $varValue);
            break;
            case "maximumpasswordlength":
                $resp = limits_maximum_password_length_set($this->getLimitObj() , $varValue);
            break;
            case "requiredpasswordcharacters":
                $resp = limits_required_password_characters_set($this->getLimitObj() , $varValue);
            break;
            case "htmlfilterlevel":
                $resp = limits_html_filter_level_set($this->getLimitObj() , $varValue);
            break;
            case "temporaryaliasescount":
                $resp = limits_temporary_aliases_count_set($this->getLimitObj() , $varValue);
            break;
            case "temporaryaliasesinterval":
                $resp = limits_temporary_aliases_interval_set($this->getLimitObj() , $varValue);
            break;
            case "enableprocessing":
                $resp = services_processing_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablesmtpincoming":
                $resp = services_smtp_incoming_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablesmtpoutgoing":
                $resp = services_smtp_outgoing_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablepop3":
                $resp = services_pop3_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablepop3proxy":
                $resp = services_pop3_proxy_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablerpop":
                $resp = services_rpop_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enableimap":
                $resp = services_imap_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enableimapproxy":
                $resp = services_imap_proxy_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablewebmail":
                $resp = services_webmail_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablewebmailproxy":
                $resp = services_webmail_proxy_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablecli":
                $resp = services_cli_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablelog":
                $resp = services_log_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enablereporting":
                $resp = services_reporting_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enableftpbackup":
                $resp = services_ftp_backup_set_enable($this->getLimitServicesObj() , $varValue);
            break;
            case "enableactivesync":
                $resp = limits_enable_active_sync_set($this->getLimitObj() , $varValue);
            break;
            case "activesyncoptions":
                $resp = limits_active_sync_options_set($this->getLimitObj() , "({$varValue})");
            break;
            case "enableoutlookconnector":
                $resp = limits_enable_outlook_connector_set($this->getLimitObj() , $varValue);
            break;
            case "enablepersonalorganizer":
                $resp = limits_enable_personal_organizer_set($this->getLimitObj() , $varValue);
            break;
            case "quotasendmessagethreshold":
                $resp = limits_quota_send_message_threshold_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationenabled":
                $resp = limits_pass_expiration_enabled_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationinterval":
                $resp = limits_pass_expiration_interval_set( $this->getLimitObj(), $varValue);
            break;
            case "passrenewalinterval":
                $resp = limits_pass_renewal_interval_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationwarningenabled":
                $resp = limits_pass_expiration_warning_enabled_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationwarninginterval":
                $resp = limits_pass_expiration_warning_interval_set($this->getLimitObj(), $varValue);
            break;
            case "passexpirationwarningsubject":
                $resp = limits_pass_expiration_warning_subject_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationwarningsentdaily":
                $resp = limits_pass_expiration_warning_sent_daily_set( $this->getLimitObj(), $varValue);
            break;
            case "passhistorysize":
                $resp = limits_pass_history_size_set( $this->getLimitObj(), $varValue);
            break;
            case "passunchangeable":
                $resp = limits_pass_unchangeable_set( $this->getLimitObj(), $varValue);
            break;
            case "welcomemessageenabled":
                $resp = limits_welcome_message_enabled_set( $this->getLimitObj(), $varValue);
            break;
            case "welcomemessagesubject":
                $resp = limits_welcome_message_subject_set( $this->getLimitObj(), $varValue);
            break;
            case "passexpirationwarningbody":
                $resp = limits_pass_expiration_warning_body_set( $this->getLimitObj(), $varValue);
            break;
            case "welcomemessagebody":
                $resp = limits_welcome_message_body_set( $this->getLimitObj(), $varValue);
            break;
            case "allowidentityconfirmation":
                $resp = limits_allow_identity_confirmation_set( $this->getLimitObj(), $varValue);
            break;
            case "editablecontactinfo":
                $resp = limits_editable_contact_info_set( $this->getLimitObj(), $varValue);
            break;
            case "enableautomigration":
                $resp = limits_enable_auto_migration_set( $this->getLimitObj(), $varValue);
            break;
            case "enablesharing":
                $resp = limits_enable_sharing_set( $this->getLimitObj(), $varValue);
            break;
            case "enablekas":
                $resp = limits_enable_kas_set( $this->getLimitObj(), $varValue);
            break;
            case "enablekav":
                $resp = limits_enable_kav_set( $this->getLimitObj(), $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETLIMITSVARERROR);
                return;
        }
        
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETLIMITSVARERROR);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>sentMessagesCount</td>
<td> the maximum number of mails a user can send in a specified interval</td>
<tr><td>sentRecipientsCount</td>
<td> the maximum number of recipients of emails in a specified interval</td>
<tr><td>sentOverquotaFileName</td>
<td> the name of the eml template used in case of overquota</td>
<tr><td>sentOverquotaEmailAddress</td>
<td> the email address used for sending overquota notifications</td>
<tr><td>sentMessagesSize</td>
<td> the maximum size of mails a user can send in a specified interval</td>
<tr><td>sentMessagesInterval</td>
<td> the specified interval in seconds</td>
<tr><td>pop3ConnectionCount</td>
<td> the number of simultaneous POP3 connections</td>
<tr><td>imapConnectionCount</td>
<td> the number of simultaneous IMAP connections</td>
<tr><td>webmailRcptCount</td>
<td> the maximum number of recipients for an email composed using Webmail</td>
<tr><td>webmailSessionCount</td>
<td> the maximum simultaneous Webmail sessions</td>
<tr><td>webmailAttSize</td>
<td> the size limit of an attachment that can be uploaded using Webmail</td>
<tr><td>webmailAttCount</td>
<td> the maximum number of attachments for a mail composed in Webmail</td>
<tr><td>webmailMessageSize</td>
<td> the size limit for a mail (body + attachments) composed in Webmail</td>
<tr><td>rpopConnectionCount</td>
<td> the maximum number of RPOP connections a user is allowed to define</td>
<tr><td>rpopRetrievalInterval</td>
<td> the minimum time interval (in minutes) between two RPOP retrievals on the same connection</td>
<tr><td>maillistUserCount</td>
<td> mail list user count</td>
<tr><td>passwordEnforcementEnabled</td>
<td> the enabled/disabled status for the Password Enforcement policy</td>
<tr><td>passwordRecoveryMethods</td>
<td> the methods for password recovery feature (valid methods: secretQuestion, peaBased)</td>
<tr><td>usernameRecoveryMethods</td>
<td> the methods for username recovery feature (valid methods: peaBased)</td>
<tr><td>passwordRecoveryFileName</td>
<td> the eml file for password recovery feature</td>
<tr><td>usernameRecoveryFileName</td>
<td> the eml file for username recovery feature</td>
<tr><td>minimumPasswordLength</td>
<td> the minimum size of the password</td>
<tr><td>maximumPasswordLength</td>
<td> the maximum size of the password</td>
<tr><td>requiredPasswordCharacters</td>
<td> the required characters for setting a password</td>
<tr><td>htmlFilterLevel</td>
<td> the security level for a HTML mail body (0-3)</td>
<tr><td>temporaryAliasesCount</td>
<td> the temporary email address count limit</td>
<tr><td>temporaryAliasesInterval</td>
<td> the temporary email address duration limit</td>
<tr><td>enableProcessing</td>
<td> the enabled/disabled status for Processing</td>
<tr><td>enableSmtpIncoming</td>
<td> the enabled/disabled status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td> the enabled/disabled status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td> the enabled/disabled status for POP3</td>
<tr><td>enablePop3Proxy</td>
<td> the enabled/disabled status for POP3 Proxy</td>
<tr><td>enableRpop</td>
<td> the enabled/disabled status for RPOP</td>
<tr><td>enableImap</td>
<td> the enabled/disabled status for IMAP</td>
<tr><td>enableImapProxy</td>
<td> the enabled/disabled status for IMAP Proxy</td>
<tr><td>enableWebmail</td>
<td> the enabled/disabled status for Webmail</td>
<tr><td>enableWebmailProxy</td>
<td> the enabled/disabled status for Webmail Proxy</td>
<tr><td>enableCli</td>
<td> the enabled/disabled status for CLI</td>
<tr><td>enableLog</td>
<td> the enabled/disabled status for Log</td>
<tr><td>enableReporting</td>
<td> the enabled/disabled status for Reporting</td>
<tr><td>enableFtpBackup</td>
<td> the enabled/disabled status for Ftp Backup</td>
<tr><td>enableActiveSync</td>
<td> enable/disable ActiveSync</td>
<tr><td>activeSyncOptions</td>
<td> ActiveSync options. Values: email contact pim (separated by space)</td>
<tr><td>enableOutlookConnector</td>
<td> enabled/disabled Outlook Connector</td>
<tr><td>enablePersonalOrganizer</td>
<td> enabled/disabled Personal Organizer</td>
<tr><td>quotaSendMessageThreshold</td>
<td> the percent of used quota which blocks user from sending messages (avaible only for maillist)</td>
<tr><td>passExpirationEnabled</td>
<td> enabled/disabled password expiration</td>
<tr><td>passExpirationInterval</td>
<td> the interval of time in days that may pass from the moment the password was changed until the moment it expires and can not be used</td>
<tr><td>passRenewalInterval</td>
<td> the interval of time that must pass from the moment of the last change of the password until a new change can be performed</td>
<tr><td>passExpirationWarningEnabled</td>
<td> enabled/disabled sending of a warning message in case of password expiration</td>
<tr><td>passExpirationWarningInterval</td>
<td> the interval of time in days after which warning message is send</td>
<tr><td>passExpirationWarningSubject</td>
<td> the subject template of the email message sent as warning for password expiration</td>
<tr><td>passExpirationWarningSentDaily</td>
<td> enabled/disabled the password expiration warning to be sent every day during the expiration warning interval</td>
<tr><td>passHistorySize</td>
<td> the number of consecutive changed passwords that can not be used as new password when a change of password is performed</td>
<tr><td>passUnchangeable</td>
<td> enabled/disabled the capability for an user to change his/her password</td>
<tr><td>welcomeMessageEnabled</td>
<td> enabled/disabled the post of a welcome message in an account's mailbox</td>
<tr><td>welcomeMessageSubject</td>
<td> the subject template of the email message sent as welcome message</td>
<tr><td>passExpirationWarningBody</td>
<td> the body template of the email message sent as warning for password expiration</td>
<tr><td>welcomeMessageBody</td>
<td> the body template of the email message sent as welcome message</td>
<tr><td>allowIdentityConfirmation</td>
<td> enabled/disabled the use of Identity Confirmation</td>
<tr><td>editableContactInfo</td>
<td> enabled/disabled contact info being editable</td>
<tr><td>enableAutoMigration </td>
<td> enabled/disabled account's auto migration</td>
<tr><td>enableSharing</td>
<td> enabled/disabled sharing</td>
<tr><td>enableKAS</td>
<td> enabled/disabled KAS</td>
<tr><td>enableKAV</td>
<td> enabled/disabled KAV</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "sentmessagescount":
                return limits_sent_messages_count_get($this->getLimitObj());
            break;
            case "sentrecipientscount":
                return limits_sent_recipients_count_get($this->getLimitObj());
            break;
            case "sentoverquotafilename":
                return limits_sent_overquota_file_name_get($this->getLimitObj());
            break;
            case "sentoverquotaemailaddress":
                return limits_sent_overquota_email_address_get($this->getLimitObj());
            break;
            case "sentmessagessize":
                return limits_sent_messages_size_get($this->getLimitObj());
            break;
            case "sentmessagesinterval":
                return limits_sent_messages_interval_get($this->getLimitObj());
            break;
            case "pop3connectioncount":
                return limits_pop3_connection_count_get($this->getLimitObj());
            break;
            case "imapconnectioncount":
                return limits_imap_connection_count_get($this->getLimitObj());
            break;
            case "webmailrcptcount":
                return limits_webmail_rcpt_count_get($this->getLimitObj());
            break;
            case "webmailsessioncount":
                return limits_webmail_session_count_get($this->getLimitObj());
            break;
            case "webmailattsize":
                return limits_webmail_att_size_get($this->getLimitObj());
            break;
            case "webmailattcount":
                return limits_webmail_att_count_get($this->getLimitObj());
            break;
            case "webmailmessagesize":
                return limits_webmail_message_size_get($this->getLimitObj());
            break;
            case "rpopconnectioncount":
                return limits_rpop_connection_count_get($this->getLimitObj());
            break;
            case "rpopretrievalinterval":
                return limits_rpop_retrieval_interval_get($this->getLimitObj());
            break;
            case "maillistusercount":
                return limits_maillist_user_count_get($this->getLimitObj());
            break;
            case "passwordenforcementenabled":
                return limits_password_enforcement_enabled_get($this->getLimitObj());
            break;
            case "passwordrecoverymethods":
                return limits_password_recovery_methods_get($this->getLimitObj());
            break;
            case "usernamerecoverymethods":
                return limits_username_recovery_methods_get($this->getLimitObj());
            break;
            case "passwordrecoveryfilename":
                return limits_password_recovery_file_name_get($this->getLimitObj());
            break;
            case "usernamerecoveryfilename":
                return limits_username_recovery_file_name_get($this->getLimitObj());
            break;
            case "minimumpasswordlength":
                return limits_minimum_password_length_get($this->getLimitObj());
            break;
            case "maximumpasswordlength":
                return limits_maximum_password_length_get($this->getLimitObj());
            break;
            case "requiredpasswordcharacters":
                return limits_required_password_characters_get($this->getLimitObj());
            break;
            case "htmlfilterlevel":
                return limits_html_filter_level_get($this->getLimitObj());
            break;
            case "temporaryaliasescount":
                return limits_temporary_aliases_count_get($this->getLimitObj());
            break;
            case "temporaryaliasesinterval":
                return limits_temporary_aliases_interval_get($this->getLimitObj());
            break;
            case "enableprocessing":
                return services_processing_is_enable($this->getLimitServicesObj());
            break;
            case "enablesmtpincoming":
                return services_smtp_incoming_is_enable($this->getLimitServicesObj());
            break;
            case "enablesmtpoutgoing":
                return services_smtp_outgoing_is_enable($this->getLimitServicesObj());
            break;
            case "enablepop3":
                return services_pop3_is_enable($this->getLimitServicesObj());
            break;
            case "enablepop3proxy":
                return services_pop3_proxy_is_enable($this->getLimitServicesObj());
            break;
            case "enablerpop":
                return services_rpop_is_enable($this->getLimitServicesObj());
            break;
            case "enableimap":
                return services_imap_is_enable($this->getLimitServicesObj());
            break;
            case "enableimapproxy":
                return services_imap_proxy_is_enable($this->getLimitServicesObj());
            break;
            case "enablewebmail":
                return services_webmail_is_enable($this->getLimitServicesObj());
            break;
            case "enablewebmailproxy":
                return services_webmail_proxy_is_enable($this->getLimitServicesObj());
            break;
            case "enablecli":
                return services_cli_is_enable($this->getLimitServicesObj());
            break;
            case "enablelog":
                return services_log_is_enable($this->getLimitServicesObj());
            break;
            case "enablereporting":
                return services_reporting_is_enable($this->getLimitServicesObj());
            break;
            case "enableftpbackup":
                return services_ftp_backup_is_enable($this->getLimitServicesObj());
            break;
            case "enableactivesync":
                return limits_enable_active_sync_get($this->getLimitObj());
            break;
            case "activesyncoptions":
                return limits_active_sync_options_get($this->getLimitObj());
            break;
            case "enableoutlookconnector":
                return limits_enable_outlook_connector_get($this->getLimitObj());
            break;
            case "enablepersonalorganizer":
                return limits_enable_personal_organizer_get($this->getLimitObj());
            break;
            case "quotasendmessagethreshold":
                return limits_quota_send_message_threshold_get( $this->getLimitObj());
            break;
            case "passexpirationenabled":
                return limits_pass_expiration_enabled_get( $this->getLimitObj());
            break;
            case "passexpirationinterval":
                return limits_pass_expiration_interval_get( $this->getLimitObj());
            break;
            case "passrenewalinterval":
                return limits_pass_renewal_interval_get( $this->getLimitObj());
            break;
            case "passexpirationwarningenabled":
                return limits_pass_expiration_warning_enabled_get( $this->getLimitObj());
            break;
            case "passexpirationwarninginterval":
                return limits_pass_expiration_warning_interval_get( $this->getLimitObj());
            break;
            case "passexpirationwarningsubject":
                return limits_pass_expiration_warning_subject_get( $this->getLimitObj());
            break;
            case "passexpirationwarningsentdaily":
                return limits_pass_expiration_warning_sent_daily_get( $this->getLimitObj());
            break;
            case "passhistorysize":
                return limits_pass_history_size_get( $this->getLimitObj());
            break;
            case "passunchangeable":
                return limits_pass_unchangeable_get( $this->getLimitObj());
            break;
            case "welcomemessageenabled":
                return limits_welcome_message_enabled_get( $this->getLimitObj());
            break;
            case "welcomemessagesubject":
                return limits_welcome_message_subject_get( $this->getLimitObj());
            break;
            case "passexpirationwarningbody":
                return limits_pass_expiration_warning_body_get( $this->getLimitObj());
            break;
            case "welcomemessagebody":
                return limits_welcome_message_body_get( $this->getLimitObj());
            break;
            case "allowidentityconfirmation":
                return limits_allow_identity_confirmation_get( $this->getLimitObj() );
            break;
            case "editablecontactinfo":
                return limits_editable_contact_info_get( $this->getLimitObj() );
            break;
            case "enableautomigration":
                return limits_enable_auto_migration_get( $this->getLimitObj() );
            break;
            case "enablesharing":
                return limits_enable_sharing_get( $this->getLimitObj() );
            break;
            case "enablekas":
                return limits_enable_kas_get( $this->getLimitObj() );
            break;
            case "enablekav":
                return limits_enable_kav_get( $this->getLimitObj() );
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETLIMITSVARERROR);
                return;
        }
    }
    /**
     * checks if the variable is inherited
     * @note returns (1 if the value is inherited, 0 if not, or -1 if this does not apply to the current limits object)
     * @return int
     * @param $varName string the variable
     */
    public function isInherited($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "sentmessagescount":
                $resp = limits_sent_messages_count_is_inherited($this->getLimitObj());
            break;
            case "sentrecipientscount":
                $resp = limits_sent_recipients_count_is_inherited($this->getLimitObj());
            break;
            case "sentoverquotafilename":
                $resp = limits_sent_overquota_file_name_is_inherited($this->getLimitObj());
            break;
            case "sentoverquotaemailaddress":
                $resp = limits_sent_overquota_email_address_is_inherited($this->getLimitObj());
            break;
            case "sentmessagessize":
                $resp = limits_sent_messages_size_is_inherited($this->getLimitObj());
            break;
            case "sentmessagesinterval":
                $resp = limits_sent_messages_interval_is_inherited($this->getLimitObj());
            break;
            case "pop3connectioncount":
                $resp = limits_pop3_connection_count_is_inherited($this->getLimitObj());
            break;
            case "imapconnectioncount":
                $resp = limits_imap_connection_count_is_inherited($this->getLimitObj());
            break;
            case "webmailrcptcount":
                $resp = limits_webmail_rcpt_count_is_inherited($this->getLimitObj());
            break;
            case "webmailsessioncount":
                $resp = limits_webmail_session_count_is_inherited($this->getLimitObj());
            break;
            case "webmailattsize":
                $resp = limits_webmail_att_size_is_inherited($this->getLimitObj());
            break;
            case "webmailattcount":
                $resp = limits_webmail_att_count_is_inherited($this->getLimitObj());
            break;
            case "webmailmessagesize":
                $resp = limits_webmail_message_size_is_inherited($this->getLimitObj());
            break;
            case "rpopconnectioncount":
                $resp = limits_rpop_connection_count_is_inherited($this->getLimitObj());
            break;
            case "rpopretrievalinterval":
                $resp = limits_rpop_retrieval_interval_is_inherited($this->getLimitObj());
            break;
            case "maillistusercount":
                $resp = limits_maillist_user_count_is_inherited($this->getLimitObj());
            break;
            case "passwordenforcementenabled":
                $resp = limits_password_enforcement_enabled_is_inherited($this->getLimitObj());
            break;
            case "passwordrecoverymethods":
                $resp = limits_password_recovery_methods_is_inherited($this->getLimitObj());
            break;
            case "usernamerecoverymethods":
                $resp = limits_username_recovery_methods_is_inherited($this->getLimitObj());
            break;
            case "passwordrecoveryfilename":
                $resp = limits_password_recovery_file_name_is_inherited($this->getLimitObj());
            break;
            case "usernamerecoveryfilename":
                $resp = limits_username_recovery_file_name_is_inherited($this->getLimitObj());
            break;
            case "minimumpasswordlength":
                $resp = limits_minimum_password_length_is_inherited($this->getLimitObj());
            break;
            case "maximumpasswordlength":
                $resp = limits_maximum_password_length_is_inherited($this->getLimitObj());
            break;
            case "requiredpasswordcharacters":
                $resp = limits_required_password_characters_is_inherited($this->getLimitObj());
            break;
            case "htmlfilterlevel":
                $resp = limits_html_filter_level_is_inherited($this->getLimitObj());
            break;
            case "temporaryaliasescount":
                $resp = limits_temporary_aliases_count_is_inherited($this->getLimitObj());
            break;
            case "temporaryaliasesinterval":
                $resp = limits_temporary_aliases_interval_is_inherited($this->getLimitObj());
            break;
            case "services":
                $resp = limits_services_is_inherited($this->getLimitObj());
            break;
            case "enableactivesync":
                $resp = limits_enable_active_sync_is_inherited($this->getLimitObj());
            break;
            case "activesyncoptions":
                $resp = limits_active_sync_options_is_inherited($this->getLimitObj());
            break;
            case "enableoutlookconnector":
                $resp = limits_enable_outlook_connector_is_inherited($this->getLimitObj());
            break;
            case "enablepersonalorganizer":
                $resp = limits_enable_personal_organizer_is_inherited($this->getLimitObj());
            break;
            case "quotasendmessagethreshold":
                $resp = limits_quota_send_message_threshold_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationenabled":
                $resp = limits_pass_expiration_enabled_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationinterval":
                $resp = limits_pass_expiration_interval_is_inherited( $this->getLimitObj());
            break;
            case "passrenewalinterval":
                $resp = limits_pass_renewal_interval_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationwarningenabled":
                $resp = limits_pass_expiration_warning_enabled_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationwarninginterval":
                $resp = limits_pass_expiration_warning_interval_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationwarningsubject":
                $resp = limits_pass_expiration_warning_subject_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationwarningsentdaily":
                $resp = limits_pass_expiration_warning_sent_daily_is_inherited( $this->getLimitObj());
            break;
            case "passhistorysize":
                $resp = limits_pass_history_size_is_inherited( $this->getLimitObj());
            break;
            case "passunchangeable":
                $resp = limits_pass_unchangeable_is_inherited( $this->getLimitObj());
            break;
            case "welcomemessageenabled":
                $resp = limits_welcome_message_enabled_is_inherited( $this->getLimitObj());
            break;
            case "welcomemessagesubject":
                $resp = limits_welcome_message_subject_is_inherited( $this->getLimitObj());
            break;
            case "passexpirationwarningbody":
                $resp = limits_pass_expiration_warning_body_is_inherited( $this->getLimitObj());
            break;
            case "welcomemessagebody":
                $resp = limits_welcome_message_body_is_inherited( $this->getLimitObj());
            break;
            case "allowidentityconfirmation":
                $resp = limits_allow_identity_confirmation_is_inherited( $this->getLimitObj());
            break;
            case "editablecontactinfo":
                $resp = limits_editable_contact_info_is_inherited ($this->getLimitObj());
            break;
            case "enableautomigration":
                $resp = limits_enable_auto_migration_is_inherited($this->getLimitObj());
            break;
            case "enablesharing":
                $resp = limits_enable_sharing_is_inherited($this->getLimitObj());
            break;
            case "enablekav":
                $resp = limits_enable_kav_is_inherited($this->getLimitObj());
            break;
            case "enablekas":
                $resp = limits_enable_kas_is_inherited($this->getLimitObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::ISINHERITEDLIMITSVARERROR);
                return -1;
        }
        return $resp;
    }
    /**
     * the variable to inherit from selected source
     * @return bool
     * @param $varName string the variable
     */
    public function inherit($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "sentmessagescount":
                $resp = limits_sent_messages_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "sentrecipientscount":
                $resp = limits_sent_recipients_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "sentoverquotafilename":
                $resp = limits_sent_overquota_file_name_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "sentoverquotaemailaddress":
                $resp = limits_sent_overquota_email_address_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "sentmessagessize":
                $resp = limits_sent_messages_size_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "sentmessagesinterval":
                $resp = limits_sent_messages_interval_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "pop3connectioncount":
                $resp = limits_pop3_connection_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "imapconnectioncount":
                $resp = limits_imap_connection_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailrcptcount":
                $resp = limits_webmail_rcpt_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailsessioncount":
                $resp = limits_webmail_session_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailattsize":
                $resp = limits_webmail_att_size_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailattcount":
                $resp = limits_webmail_att_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailmessagesize":
                $resp = limits_webmail_message_size_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "rpopconnectioncount":
                $resp = limits_rpop_connection_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "rpopretrievalinterval":
                $resp = limits_rpop_retrieval_interval_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "maillistusercount":
                $resp = limits_maillist_user_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "passwordenforcementenabled":
                $resp = limits_password_enforcement_enabled_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "minimumpasswordlength":
                $resp = limits_minimum_password_length_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "maximumpasswordlength":
                $resp = limits_maximum_password_length_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "requiredpasswordcharacters":
                $resp = limits_required_password_characters_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "htmlfilterlevel":
                $resp = limits_html_filter_level_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "temporaryaliasescount":
                $resp = limits_temporary_aliases_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "temporaryaliasesinterval":
                $resp = limits_temporary_aliases_interval_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "services":
                $resp = limits_services_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "webmailrcptcount":
                $resp = limits_webmail_rcpt_count_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "enableactivesync":
                $resp = limits_enable_active_sync_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "activesyncoptions":
                $resp = limits_active_sync_options_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "enableoutlookconnector":
                $resp = limits_enable_outlook_connector_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "enablepersonalorganizer":
                $resp = limits_enable_personal_organizer_inherit($this->getLimitObj() , $this->getSessionObj());
            break;
            case "quotasendmessagethreshold":
                $resp = limits_quota_send_message_threshold_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationenabled":
                $resp = limits_pass_expiration_enabled_inherit($this->getLimitObj(), $this->getSessionObj());
            break;
            case "passwordrecoverymethods":
                $resp = limits_password_recovery_methods_inherit($this->getLimitObj(), $this->getSessionObj());
            break;
            case "usernamerecoverymethods":
                $resp = limits_username_recovery_methods_inherit($this->getLimitObj(), $this->getSessionObj());
            break;
            case "passwordrecoveryfilename":
                $resp = limits_password_recovery_file_name_inherit($this->getLimitObj(), $this->getSessionObj());
            break;
            case "usernamerecoveryfilename":
                $resp = limits_username_recovery_file_name_inherit($this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationinterval":
                $resp = limits_pass_expiration_interval_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passrenewalinterval":
                $resp = limits_pass_renewal_interval_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationwarningenabled":
                $resp = limits_pass_expiration_warning_enabled_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationwarninginterval":
                $resp = limits_pass_expiration_warning_interval_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationwarningsubject":
                $resp = limits_pass_expiration_warning_subject_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationwarningsentdaily":
                $resp = limits_pass_expiration_warning_sent_daily_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passhistorysize":
                $resp = limits_pass_history_size_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passunchangeable":
                $resp = limits_pass_unchangeable_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "welcomemessageenabled":
                $resp = limits_welcome_message_enabled_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "welcomemessagesubject":
                $resp = limits_welcome_message_subject_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "passexpirationwarningbody":
                $resp = limits_pass_expiration_warning_body_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "welcomemessagebody":
                $resp = limits_welcome_message_body_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "allowidentityconfirmation":
                $resp = limits_allow_identity_confirmation_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "editablecontactinfo":
                $resp = limits_editable_contact_info_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "enableautomigration":
                $resp = limits_enable_auto_migration_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "enablesharing":
                $resp = limits_enable_sharing_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "enablekas":
                $resp = limits_enable_kas_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            case "enablekav":
                $resp = limits_enable_kav_inherit( $this->getLimitObj(), $this->getSessionObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::INHERITLIMITSVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INHERITLIMITSVARERROR);
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = limits_save($this->getLimitObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVELIMITSDATA);
    }
}
/** @} */ // end of group
?>
