<?php
/**
 * \ingroup configCli configFtpBackup configImap configImapProxy configLog configPop3 configPop3Proxy configSmtpIn configWebmail configWebmailProxy
 * \defgroup updateListener updateListener
 * @{
 */
class Listener {
    private $listener, $parent, $rules, $sslcontrol, $allowrule;
    public function __construct($listenerObj, $parent) {
        $this->listener = $listenerObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        listener_destroy($this->getListenerObj());
        if (!is_resource($this->rules)) {
            rules_destroy($this->rules);
        }
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getListenerObj() {
        return $this->listener;
    }
    public function getRulesObj() {
        if (!is_resource($this->rules)) {
            $this->rules = listener_get_rules($this->getListenerObj() , $this->getSessionObj());
            if (!Debug::checkError($this->rules, "_p_rules", Debug::FATALERROR, Message::LISTENERGETRULES)) return false;
        }
        return $this->rules;
    }
    public function saveRules() {
        $resp = rules_save($this->getRulesObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSAVERULES);
    }
    /**
     * returns an array with all the allow rules
     * @return array
     */
    public function listAllowRules() {
        $list = array();
        $rulesIterObj = allow_rule_iterator_begin($this->getRulesObj());
        if (!Debug::checkError($rulesIterObj, "_p_allow_rule_iterator", Debug::INFOERROR, Message::LISTENERSLISTALLOWRULES)) return false;
        while (allow_rule_iterator_has_value($rulesIterObj)) {
            $ruleObj = allow_rule_iterator_value($rulesIterObj);
            unset($tmp);
            if (allow_rule_is_ip_set_form($ruleObj)) {
                $tmp['ipStart'] = allow_rule_start_ip_get($ruleObj);
                $tmp['ipEnd'] = allow_rule_end_ip_get($ruleObj);
            } else {
                $tmp['network'] = allow_rule_network_get($ruleObj);
                $tmp['netmask'] = allow_rule_netmask_get($ruleObj);
            }
            if (allow_rule_enable_get($ruleObj) == 1) $tmp['enable'] = true;
            else $tmp['enable'] = false;
            $tmp['priority'] = allow_rule_priority_get($ruleObj);
            $tmp['maxConnections'] = allow_rule_maxConnections_get($ruleObj);
            $tmp['maxIntervalConnections'] = allow_rule_maxIntervalConnections_get($ruleObj);
            $tmp['timeInterval'] = allow_rule_timeInterval_get($ruleObj);
            $tmp['peerMaxConnections'] = allow_rule_peerMaxConnections_get($ruleObj);
            $tmp['peerMaxIntervalConnections'] = allow_rule_peerMaxIntervalConnections_get($ruleObj);
            $tmp['peerTimeInterval'] = allow_rule_peerTimeInterval_get($ruleObj);
            array_push($list, $tmp);
            allow_rule_iterator_next($rulesIterObj);
        }
        allow_rule_iterator_destroy($rulesIterObj);
        return $list;
    }
    /**
     * returns an array with all the deny rules
     * @return array
     */
    public function listDenyRules() {
        $list = array();
        $rulesIterObj = deny_rule_iterator_begin($this->getRulesObj());
        if (!Debug::checkError($rulesIterObj, "_p_deny_rule_iterator", Debug::INFOERROR, Message::LISTENERSLISTDENYRULES)) return false;
        while (deny_rule_iterator_has_value($rulesIterObj)) {
            $ruleObj = deny_rule_iterator_value($rulesIterObj);
            unset($tmp);
            if (deny_rule_is_ip_set_form($ruleObj)) {
                $tmp['ipStart'] = deny_rule_start_ip_get($ruleObj);
                $tmp['ipEnd'] = deny_rule_end_ip_get($ruleObj);
            } else {
                $tmp['network'] = deny_rule_network_get($ruleObj);
                $tmp['netmask'] = deny_rule_netmask_get($ruleObj);
            }
            if (deny_rule_enable_get($ruleObj) == 1) $tmp['enable'] = true;
            else $tmp['enable'] = false;
            $tmp['priority'] = deny_rule_priority_get($ruleObj);
            array_push($list, $tmp);
            deny_rule_iterator_next($rulesIterObj);
        }
        deny_rule_iterator_destroy($rulesIterObj);
        return $list;
    }
    /**
     * this method returns an object to configure SSL control for the listener
     * @return object SslControl
     */
    public function configSslControl() {
        if (!$this) return false;
        if (!is_object($this->sslcontrol)) {
            $sslObj = listener_get_ssl_control($this->getListenerObj() , $this->getSessionObj());
            Debug::checkError($sslObj, "_p_ssl_control", Debug::INFOERROR, Message::LISTENERSGETSSLCONTROL);
            $this->sslcontrol = new SslControl($sslObj, $this);
        }
        return $this->sslcontrol;
    }
    /**
     * Adds a deny rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string (optional default: yes)
     * @param $priority int rule priority (optional default: auto)
     */
    public function addDenyRule($ipRangeNetwork, $enable = "yes", $priority = null) {
        if (strstr($ipRangeNetwork, '-')) {
            $tmp = explode("-", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 0;
        } elseif (strstr($ipRangeNetwork, '/')) {
            $tmp = explode("/", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 1;
        } else return false;
        $deny = deny_rule_add($this->getRulesObj() , $start_ip, $end_ip_mask, $is_subnet);
        if (!Debug::checkError($deny, "_p_deny_rule", Debug::INFOERROR, Message::LISTENERSADDDENYRULE)) return false;
        if (strtolower($enable) == "yes") {
            $resp = deny_rule_enable_set($deny, 1);
        } else {
            $resp = deny_rule_enable_set($deny, 0);
        }
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSDENYRULESETENABLE);
        if (is_int($priority)) {
            $resp = deny_rule_priority_set($deny, $priority);
            Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSDENYRULESETPRIORITY);
        }
        return $this->saveRules();
    }
    /**
     * Removes a deny rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function removeDenyRule($ipRangeNetwork) {
        $resp = rules_deny_rule_remove_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSREMOVEDENYRULE)) return false;
        return $this->saveRules();
    }
    /**
     * This method updates a deny rule
     * @return
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string sets the enable/disabled status of the rule
     * @param $priority int sets the rule priority
     */
    public function updateDenyRule($ipRangeNetwork, $enable = null, $priority = null) {
        $deny = rules_deny_rule_get_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($deny, "_p_deny_rule", Debug::INFOERROR, Message::LISTENERSUPDATEDENYRULE)) return false;
        if (!is_null($enable)) {
            if (strtolower($enable) == "yes") {
                $resp = deny_rule_enable_set($deny, 1);
            } else {
                $resp = deny_rule_enable_set($deny, 0);
            }
            if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSDENYRULESETENABLE)) return false;
        }
        if (is_int($priority)) {
            $resp = deny_rule_priority_set($deny, $priority);
            if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSDENYRULESETPRIORITY)) return false;
        }
        return $this->saveRules();
    }
    /**
     * Adds an allow rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     * @param $enable string enables rule (optional default: yes)
     * @param $priority int rule priority (optional default: auto)
     */
    public function addAllowRule($ipRangeNetwork, $enable = "yes", $priority = null) {
        if (strstr($ipRangeNetwork, '-')) {
            $tmp = explode("-", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 0;
        } elseif (strstr($ipRangeNetwork, '/')) {
            $tmp = explode("/", $ipRangeNetwork);
            $start_ip = $tmp[0];
            $end_ip_mask = $tmp[1];
            $is_subnet = 1;
        } else return false;
        $allow = allow_rule_add($this->getRulesObj() , $this->getSessionObj() , $start_ip, $end_ip_mask, $is_subnet);
        if (!Debug::checkError($allow, 0, Debug::INFOERROR, Message::LISTENERSADDALLOWRULE)) return false;
        if ($enable == "yes") {
            $resp = allow_rule_enable_set($allow, 1);
        } else {
            $resp = allow_rule_enable_set($allow, 0);
        }
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSALLOWRULESETENABLE);
        if (is_int($priority)) {
            $resp = allow_rule_priority_set($allow, $priority);
            Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSALLOWRULESETPRIORITY);
        }
        return $this->saveRules();
    }
    /**
     * Removes an allow rule
     * @return bool
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function removeAllowRule($ipRangeNetwork) {
        $resp = rules_allow_rule_remove_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LISTENERSREMOVEALLOWRULE)) return false;
        return $this->saveRules();
    }
    /**
     * This method returns an object with allow rule loaded
     * @return object AllowRule
     * @param $ipRangeNetwork string IP range or network/mask (ex: 1.2.3.4-1.2.3.5 or 1.2.3.0/255.255.255.0)
     */
    public function updateAllowRule($ipRangeNetwork) {
        if (!is_object($this->allowrule)) {
            $allow = rules_allow_rule_get_by_ip_range($this->getRulesObj() , $ipRangeNetwork);
            if (!Debug::checkError($allow, "_p_allow_rule", Debug::FATALERROR, Message::LISTENERSUPDATEALLOWRULE)) return false;
            $this->allowrule = new AllowRule($allow, $this);
        }
        return $this->allowrule;
    }
    /**
     * This method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = listener_save($this->getListenerObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVELISTENERDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>address</td>
<td>the listener's address</td>
<tr><td>enable</td>
<td>the enabled/disabled status of the listener</td>
<tr><td>maxConnections</td>
<td>the maximum number of connections</td>
<tr><td>timeInterval</td>
<td>the time interval</td>
<tr><td>maxIntervalConnections</td>
<td>the maximum number of connections in a time interval</td>
<tr><td>peerMaxConnections</td>
<td>the maximum number of connections from a single host</td>
<tr><td>peerTimeInterval</td>
<td>the time interval - single host</td>
<tr><td>peerMaxIntervalConnections</td>
<td>the maximum number of connections in a time interval - single host</td>
<tr><td>idleTimeout</td>
<td>the inactivity timeout</td>
<tr><td>sslEnable</td>
<td>SSL as enabled/disabled on the listener</td>
<tr><td>listenerDomain</td>
<td>the domain of the listener</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch ($varName) {
            case "address":
                $resp = listener_address_set($this->getListenerObj() , $varValue);
            break;
            case "enable":
                switch (strtolower($varValue)) {
                    case 1:
                        $val = 1;
                    break;
                    case "yes":
                        $val = 1;
                    break;
                    default:
                        $val = 0;
                }
                $resp = listener_enable_set($this->getListenerObj() , $val);
            break;
            case "maxConnections":
                $resp = listener_maxConnections_set($this->getListenerObj() , $varValue);
            break;
            case "timeInterval":
                $resp = listener_timeInterval_set($this->getListenerObj() , $varValue);
            break;
            case "maxIntervalConnections":
                $resp = listener_maxIntervalConnections_set($this->getListenerObj() , $varValue);
            break;
            case "peerMaxConnections":
                $resp = listener_peerMaxConnections_set($this->getListenerObj() , $varValue);
            break;
            case "peerTimeInterval":
                $resp = listener_peerTimeInterval_set($this->getListenerObj() , $varValue);
            break;
            case "peerMaxIntervalConnections":
                $resp = listener_peerMaxIntervalConnections_set($this->getListenerObj() , $varValue);
            break;
            case "idleTimeout":
                $resp = listener_idleTimeout_set($this->getListenerObj() , $varValue);
            break;
            case "sslEnable":
                $resp = listener_sslEnable_set($this->getListenerObj() , $varValue);
            break;
            case "listenerDomain":
                $resp = listener_listenerDomain_set($this->getListenerObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETLISTENRVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETLISTENRVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>address</td>
<td>the listener's address</td>
<tr><td>enable</td>
<td>the enabled/disabled status of the listener</td>
<tr><td>maxConnections</td>
<td>the maximum number of connections</td>
<tr><td>timeInterval</td>
<td>the time interval</td>
<tr><td>maxIntervalConnections</td>
<td>the maximum number of connections in a time interval</td>
<tr><td>peerMaxConnections</td>
<td>the maximum number of connections from a single host</td>
<tr><td>peerTimeInterval</td>
<td>the time interval - single host</td>
<tr><td>peerMaxIntervalConnections</td>
<td>the maximum number of connections in a time interval - single host</td>
<tr><td>idleTimeout</td>
<td>the inactivity timeout</td>
<tr><td>sslEnable</td>
<td>SSL as enabled/disabled on the listener</td>
<tr><td>listenerDomain</td>
<td>the domain of the listener</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch ($varName) {
            case "address":
                return listener_address_get($this->getListenerObj());
            break;
            case "enable":
                return listener_enable_get($this->getListenerObj());
            break;
            case "maxConnections":
                return listener_maxConnections_get($this->getListenerObj());
            break;
            case "timeInterval":
                return listener_timeInterval_get($this->getListenerObj());
            break;
            case "maxIntervalConnections":
                return listener_maxIntervalConnections_get($this->getListenerObj());
            break;
            case "peerMaxConnections":
                return listener_peerMaxConnections_get($this->getListenerObj());
            break;
            case "peerTimeInterval":
                return listener_peerTimeInterval_get($this->getListenerObj());
            break;
            case "peerMaxIntervalConnections":
                return listener_peerMaxIntervalConnections_get($this->getListenerObj());
            break;
            case "idleTimeout":
                return listener_idleTimeout_get($this->getListenerObj());
            break;
            case "sslEnable":
                return listener_sslEnable_get($this->getListenerObj());
            break;
            case "listenerDomain":
                return listener_listenerDomain_get($this->getListenerObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETLISTENRVARERROR);
        }
    }
}
/** @} */ // end of group
?>
