<?php
/**
 * \ingroup configServer
 * \defgroup configLog configLog
 * @{
*/
class Log {
    private $logObj, $parent, $listener;
    public function __construct($logObj, $parent) {
        $this->logObj = $logObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        log_destroy($this->getLogObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getLogObj() {
        return $this->logObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>logLevel</td>
<td>the log level for the Log service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Log service</td>
<tr><td>path</td>
<td>the path for log service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            case 'path':
                return $this->getPath();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>logLevel</td>
<td>the log level for the Log service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Log service</td>
<tr><td>path</td>
<td>the path for log service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            case 'path':
                return $this->setPath($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return log_log_level_get($this->getLogObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return log_log_host_get($this->getLogObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return log_log_type_get($this->getLogObj());
    }
    /**
     * @ignore
     * This function returns the log path.
     *
     *@return String
     */
    public function getPath() {
        return log_path_get($this->getLogObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = log_log_level_set($this->getLogObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = log_log_host_set($this->getLogObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = log_log_type_set($this->getLogObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGSETLOGTYPE);
    }
    /**
     * @ignore
     * This function sets the path for log service
     * @return bool
     *
     * @param $value string the path to log directory
     */
    public function setPath($value) {
        /* log_path_set function not implemented in cliclient */
        $set = log_path_set($this->getLogObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGSETPATH);
    }
    /**
     * @private
     * This function saves the Log configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = log_save($this->getLogObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::LOGSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = report_reset($this->getLogObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::LOGRESET);
    }
    /**
     * This function starts the Log service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("log");
    }
    /**
     * This function stops the Log service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("log");
    }
    /**
     * This method lists the log rules
     *
     * @return array
     */
    public function listRules() {
        $logRules = array();
        $logRulesIterObj = log_rule_iterator_begin($this->getLogObj());
        if (!Debug::checkError($logRulesIterObj, "_p_log_rule_iterator", Debug::INFOERROR, Message::LOGLISTRULES)) return false;
        while (log_rule_iterator_has_value($logRulesIterObj)) {
            $logRule = array();
            $logRuleObj = log_rule_iterator_value($logRulesIterObj);
            $logRule['priority'] = log_rule_priority_get($logRuleObj);
            $logRule['hostname'] = log_rule_hostname_get($logRuleObj);
            $logRule['module'] = log_rule_module_get($logRuleObj);
            $logRule['level'] = log_rule_log_level_get($logRuleObj);
            $logRule['fileName'] = log_rule_file_name_get($logRuleObj);
            $logRule['fileSize'] = log_rule_file_size_get($logRuleObj);
            $logRule['fileTime'] = log_rule_file_time_get($logRuleObj);
            $logRule['fileCount'] = log_rule_file_count_get($logRuleObj);
            $logRule['rotatePeriod'] = log_rule_rotate_period_get($logRuleObj);
            $logRule['type'] = log_rule_type_get($logRuleObj);
            array_push($logRules, $logRule);
            log_rule_iterator_next($logRulesIterObj);
        }
        log_rule_iterator_destroy($logRulesIterObj);
        return $logRules;
    }
    /**
     * This function adds a log rule to the log service
     *
     * @param $priority int the priority of the log rule
     * @param $hostname string the logging host address for this log rule. It will be used if the log type is remote
     * @param $module string The 'value' parameter can be "*" meaning every module or "pop3" for the pop3 module or "pop3 imap" for the POP3&IMAP modules
     * @param $level int the log level for this rule
     * @param $fileName string the file path for the logging file
     * @param $fileSize int the maximum file size for the log file
     * @param $fileTime int the maximum duration for the log file
     * @param $fileCount int the maximum number of old log files that will be kept
     * @param $rotatePeriod string the log rotate period. This will be override the log file file_time. Accepted values for the 'value' parameters are: "none", "day", "week" or "month"
     * @param $type string the type of the rule (choice: local|remote)
     * @return bool
     */
    public function addLogRule($priority, $hostname, $module, $level, $fileName, $fileSize, $fileTime, $fileCount, $rotatePeriod, $type) {
        $logRule = log_rule_add($this->getLogObj() , $this->getSessionObj() , $priority);
        if (!Debug::checkError($logRule, "_p_log_rule", Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_hostname_set($logRule, $hostname);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_module_set($logRule, $module);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_log_level_set($logRule, $level);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_file_name_set($logRule, $fileName);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_file_size_set($logRule, $fileSize);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_file_time_set($logRule, $fileTime);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_file_count_set($logRule, $fileCount);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_rotate_period_set($logRule, $rotatePeriod);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        $set = log_rule_type_set($logRule, $type);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGADDRULE)) return false;
        return $this->save();
    }
    /**
     * This function adds a log rule to the log service
     * @param $oldpriority int the priority of the log rule that you want to change
     * @param $priority int the priority of the log rule
     * @param $hostname string the logging host address for this log rule. It will be used if the log type is remote
     * @param $module string The 'value' parameter can be "*" meaning every module or "pop3" for the pop3 module or "pop3 imap" for the POP3&IMAPp modules
     * @param $level int the log level for this rule
     * @param $fileName string the file path for the logging file
     * @param $fileSize int the maximum file size for the log file
     * @param $fileTime int the maximum duration for the log file
     * @param $fileCount int the maximum number of old log files that will be kept
     * @param $rotatePeriod string the log rotate period. This will be override the log file file_time. Accepted values for the 'value' parameters are: "none", "day", "week" or "month"
     * @param $type string the type of the rule (choice: local|remote)
     * @return bool
     */
    public function updateRule($oldpriority, $priority = null, $hostname = null, $module = null, $level = null, $fileName = null, $fileSize = null, $fileTime = null, $fileCount = null, $rotatePeriod = null, $type = null) {
        $logRule = log_rule_get_by_priority($this->getLogObj() , $oldpriority);
        if (!Debug::checkError($logRule, "_p_log_rule", Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        if (!is_null($priority)) {
            $set = log_rule_priority_set($logRule, $priority);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($hostname)) {
            $set = log_rule_hostname_set($logRule, $hostname);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($module)) {
            $set = log_rule_module_set($logRule, $module);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($level)) {
            $set = log_rule_log_level_set($logRule, $level);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($fileName)) {
            $set = log_rule_file_name_set($logRule, $fileName);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($fileSize)) {
            $set = log_rule_file_size_set($logRule, $fileSize);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($fileTime)) {
            $set = log_rule_file_time_set($logRule, $fileTime);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($fileCount)) {
            $set = log_rule_file_count_set($logRule, $fileCount);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($rotatePeriod)) {
            $set = log_rule_rotate_period_set($logRule, $rotatePeriod);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        if (!is_null($type)) {
            $set = log_rule_type_set($logRule, $type);
            if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::LOGUPDATERULE)) return false;
        }
        return $this->save();
    }
    /**
     * Removes a log rule
     * @param $priority int the rule priority
     * @return bool
     */
    public function removeRule($priority) {
        $resp = log_rule_remove_by_priority($this->getLogObj() , $priority);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOGREMOVERULE)) return false;
        return $this->save();
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:2001)
     */
    public function addListener($address) {
        $listeners = log_udplisteners_get($this->getLogObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_udplisteners", Debug::INFOERROR, Message::LOGADDLISTENER)) return false;
        $listenerObj = udplisteners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_udplistener", Debug::INFOERROR, Message::LOGADDLISTENER)) return false;
        udplisteners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = log_udplisteners_get($this->getLogObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_udplisteners", Debug::INFOERROR, Message::LOGGETLISTENERS)) return false;
        $resp = udplisteners_remove_by_address($listeners, $this->getSessionObj() , $address);
        udplisteners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOGREMOVELISTENER);
    }
    /**
     * This function updates a listener from this service
     * @return object UdpListener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = log_udplisteners_get($this->getLogObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_udplisteners", Debug::FATALERROR, Message::LOGGETLISTENERS)) return false;
            $listenerObj = udplisteners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_udplistener", Debug::FATALERROR, Message::LOGUPDATELISTENER)) return false;
            $this->listener[$address] = new UdpListener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = log_udplisteners_get($this->getLogObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_udplisteners", Debug::INFOERROR, Message::LOGGETLISTENERS)) return false;
        $listenersIterObj = udplistener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_udplistener_iterator", Debug::INFOERROR, Message::LOGGETLISTENERS)) return false;
        while (udplistener_iterator_has_value($listenersIterObj)) {
            $listenerObj = udplistener_iterator_value($listenersIterObj);
            unset($tmp);
            if (udplistener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = udplistener_address_get($listenerObj);
            array_push($listeners, $tmp);
            udplistener_iterator_next($listenersIterObj);
        }
        udplistener_iterator_destroy($listenersIterObj);
        udplisteners_destroy($listenersObj);
        return $listeners;
    }
}
/** @} */ // end of group
?>
