<?php
/**
 * \ingroup updateDomain
 * \defgroup configMigrationData configMigrationData
 * @{
 * this is the object containing the Migration Data for the selected domain
 */
class MigrationData {
    private $migrationdata, $parent;
    public function __construct($migrationdataObj, $parentObj) {
        $this->migrationdata = $migrationdataObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        migration_data_destroy($this->getMigrationDataObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getMigrationDataObj() {
        return $this->migrationdata;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = migration_data_save($this->getMigrationDataObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEDOMAINMIGRATIONDATA);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enable</td>
<td>the enabled status for the migration of accounts from this domain</td>
<tr><td>remoteImapHost</td>
<td>the name of the remote IMAP machine from which the domain's accounts are migrated</td>
<tr><td>remoteImapPort</td>
<td>the IMAP server's port on the remote machine</td>
<tr><td>remoteSmtpHost</td>
<td>the name of the remote SMTP machine from which the domain's accounts are migrated</td>
<tr><td>remoteSmtpPort</td>
<td>the SMTP server's port on the remote machine</td>
<tr><td>defaultAccountClassName</td>
<td>the default account class name</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "enable":
                $resp = migration_data_enable_set($this->getMigrationDataObj() , $varValue);
            break;
            case "remoteimapport":
                $resp = migration_data_remote_imap_port_set($this->getMigrationDataObj() , $varValue);
            break;
            case "remotesmtpport":
                $resp = migration_data_remote_smtp_port_set($this->getMigrationDataObj() , $varValue);
            break;
            case "remoteimaphost":
                $resp = migration_data_remote_imap_host_set($this->getMigrationDataObj() , $varValue);
            break;
            case "remotesmtphost":
                $resp = migration_data_remote_smtp_host_set($this->getMigrationDataObj() , $varValue);
            break;
            case "defaultaccountclassname":
                $resp = migration_data_default_account_class_name_set($this->getMigrationDataObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETMIGRATIONDATAVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETMIGRATIONDATAVARERROR);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enable</td>
<td>the enabled status for the migration of accounts from this domain</td>
<tr><td>remoteImapHost</td>
<td>the name of the remote IMAP machine from which the domain's accounts are migrated</td>
<tr><td>remoteImapPort</td>
<td>the IMAP server's port on the remote machine</td>
<tr><td>remoteSmtpHost</td>
<td>the name of the remote SMTP machine from which the domain's accounts are migrated</td>
<tr><td>remoteSmtpPort</td>
<td>the SMTP server's port on the remote machine</td>
<tr><td>defaultAccountClassName</td>
<td>the default account class name</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "enable":
                return migration_data_enable_get($this->getMigrationDataObj());
            break;
            case "remoteimapport":
                return migration_data_remote_imap_port_get($this->getMigrationDataObj());
            break;
            case "remotesmtpport":
                return migration_data_remote_smtp_port_get($this->getMigrationDataObj());
            break;
            case "remoteimaphost":
                return migration_data_remote_imap_host_get($this->getMigrationDataObj());
            break;
            case "remotesmtphost":
                return migration_data_remote_smtp_host_get($this->getMigrationDataObj());
            break;
            case "defaultaccountclassname":
                return migration_data_default_account_class_name_get($this->getMigrationDataObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETMIGRATIONDATAVARERROR);
        }
    }
}
/** @} */ // end of group
?>
