<?php
/**
 * \ingroup configServer
 * \defgroup configMobility configMobility
 * @{
 */
class Mobility {
    private $mobilityObj, $parent;
    public function __construct($mobilityObj, $parent) {
        $this->mobilityObj = $mobilityObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        mobility_destroy($this->getMobilityObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getMobilityObj() {
        return $this->mobilityObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enableMobileWebmail</td>
<td>enable/disable Mobile Webmail</td>
<tr><td>enableActiveSync</td>
<td>enable/disable ActiveSync</td>
</table>
     */
    public function __get($name) {
        switch (strtolower($name)) {
            case "enablemobilewebmail":
                return mobility_enable_mobile_webmail_get($this->getMobilityObj());
            break;
            case "enableactivesync":
                return mobility_enable_active_sync_get($this->getMobilityObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETMOBILITYVARERROR);
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enableMobileWebmail</td>
<td>enable/disable Mobile Webmail</td>
<tr><td>enableActiveSync</td>
<td>enable/disable ActiveSync</td>
</table>
     */
    public function __set($name, $var) {
        switch (strtolower($name)) {
            case "enablemobilewebmail":
                $resp = mobility_enable_mobile_webmail_set($this->getMobilityObj() , $var);
            break;
            case "enableactivesync":
                $resp = mobility_enable_active_sync_set($this->getMobilityObj() , $var);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETMOBILITYVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETMOBILITYVARERROR);
    }
    /**
     * This function saves the Mobility configuration back to Axigen
     * @return bool
     */
    public function save() {
        $save = mobility_save($this->getMobilityObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::MOBILITYSAVE);
    }
 
//    /**
//     * this method removes an ActiveSync Account from the server
//     * @return bool
//     * @param AccountName
//     * @paramdesc this is the account name that will have its ActiveSync removed
//     * @paramtype string
//     */
//    public function removeActiveSyncAccount($name) {
//        if (!$this) return false;
//        if (!is_string($name)) return false;
//        $resp = mobility_remove_active_sync_account($this->getMobilityObj() , $this->getSessionObj() , $name);
//        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEACTIVESYNCACCOUNT);
//    }
//     /**
//     * this method returns an array with ActiveSync Accounts list filtered by a certain parameter
//     * @return array
//     * @param ActiveSyncAccountFilter
//     * @paramdesc the ActiveSync account filter (ex: account*: will list all the accounts that start with account) (this parameter is optional)
//     * @paramtype string
//     * @parm DomainFilter
//     * @paramdesc the domain filter (optional)
//     * @paramtype string
//     */
//    public function listActiveSyncAccounts($filter = "", $domain = "") {
//        if (!$this) return false;
//        is_null($filter) ? $filter = "" : 0;
//        is_null($domain) ? $domain = "" : 0;
//        $accounts = array();
//        if ( $domain != "" ) {
//            $domain = "domain {$domain}";
//        }   
//        $accountsObj = mobility_active_sync_accounts_get($this->getMobilityObj() , $this->getSessionObj() , $domain, $filter);
//        if (!Debug::checkError($accountsObj, "_p_active_sync_accounts_list", Debug::INFOERROR, Message::LISTACTIVESYNCACCOUNTS)) return false;
//        $accountsIterObj = active_sync_accounts_iterator_begin($accountsObj);
//        if (!Debug::checkError($accountsIterObj, "_p_active_sync_accounts_iterator", Debug::INFOERROR, Message::LISTACTIVESYNCACCOUNTS)) return false;
//        while (active_sync_accounts_iterator_has_value($accountsIterObj)) {
//            array_push($accounts, active_sync_accounts_iterator_value($accountsIterObj));
//            active_sync_accounts_iterator_next($accountsIterObj);
//        }
//        active_sync_accounts_iterator_destroy($accountsIterObj);
//        active_sync_accounts_list_destroy($accountsObj);
//        return $accounts;
//    }
}
/** @} */ // end of group
?>
