<?php
/**
 * \ingroup configServer
 * \defgroup configPop3 configPop3
 * @{
*/
class Pop3 {
    private $pop3Obj, $parent, $listener, $accesscontrol;
    public function __construct($pop3Obj, $parent) {
        $this->pop3Obj = $pop3Obj;
        $this->parent = $parent;
    }
    public function __destruct() {
        pop3_destroy($this->getPop3Obj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getPop3Obj() {
        return $this->pop3Obj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the POP3 service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the POP3 service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>allowStartTls</td>
<td>the secure connection (which starts with STARTTLS)</td>
<tr><td>secureConnectionAllowLogin</td>
<td>if plain text authentication is allowed on secure connections</td>
<tr><td>secureConnectionAuthTypes</td>
<td>the allowed authentication methods on a secure connection</td>
<tr><td>plainConnectionAuthTypes</td>
<td>the allowed authentication methods on a plain connection</td>
<tr><td>plainConnectionAllowLogin</td>
<td>if plain text authentication is allowed on plain connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the POP3 service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the POP3 service</td>
<tr><td>greetingsText</td>
<td>the greeting text for this service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'maxErrors':
                return $this->getMaxErrors();
            break;
            case 'maxAuthErrors':
                return $this->getMaxAuthErrors();
            break;
            case 'allowStartTls':
                return $this->getAllowStartTls();
            break;
            case 'secureConnectionAllowLogin':
                return $this->getSecureConnectionAllowLogin();
            break;
            case 'secureConnectionAuthTypes':
                return $this->getSecureConnectionAuthTypes();
            break;
            case 'plainConnectionAuthTypes':
                return $this->getPlainConnectionAuthTypes();
            break;
            case 'plainConnectionAllowLogin':
                return $this->getPlainConnectionAllowLogin();
            break;
            case 'userdbConnectorType':
                return $this->getUserdbConnectorType();
            break;
            case 'userdbConnectorName':
                return $this->getUserdbConnectorName();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            case 'greetingsText':
                return $this->getGreetingsText();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the POP3 service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the POP3 service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>allowStartTls</td>
<td>the secure connection (which starts with STARTTLS)</td>
<tr><td>secureConnectionAllowLogin</td>
<td>if plain text authentication is allowed on secure connections</td>
<tr><td>secureConnectionAuthTypes</td>
<td>the allowed authentication methods on a secure connection</td>
<tr><td>plainConnectionAuthTypes</td>
<td>the allowed authentication methods on a plain connection</td>
<tr><td>plainConnectionAllowLogin</td>
<td>if plain text authentication is allowed on plain connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the POP3 service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the POP3 service</td>
<tr><td>greetingsText</td>
<td>the greeting text for this service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxErrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxAuthErrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'allowStartTls':
                return $this->setAllowStartTls($value);
            break;
            case 'secureConnectionAllowLogin':
                return $this->setSecureConnectionAllowLogin($value);
            break;
            case 'secureConnectionAuthTypes':
                return $this->setSecureConnectionAuthTypes($value);
            break;
            case 'plainConnectionAuthTypes':
                return $this->setPlainConnectionAuthTypes($value);
            break;
            case 'plainConnectionAllowLogin':
                return $this->setPlainConnectionAllowLogin($value);
            break;
            case 'userdbConnectorType':
                return $this->setUserdbConnectorType($value);
            break;
            case 'userdbConnectorName':
                return $this->setUserdbConnectorName($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            case 'greetingsText':
                return $this->setGreetingsText($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return pop3_max_connection_threads_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return pop3_min_connection_threads_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the maximum protocol errors number after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return pop3_max_errors_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the maximum authentication errors number after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return pop3_max_auth_errors_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns 1 if secure connections (which start with STARTTLS) are allowed for this service and 0 if otherwise
     *
     * @return int
     */
    public function getAllowStartTls() {
        return pop3_allow_start_tls_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns 1 if plain text authentication is allowed on secure connections and 0 if otherwise
     *
     * @return int
     */
    public function getSecureConnectionAllowLogin() {
        return pop3_secure_connection_allow_login_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function gets a list of the allowed authentication methods on a secure connection.
     * The returned string can look like this: "(plain login cram-md5 digest-md5 gssapi)"
     *
     * @return string
     */
    public function getSecureConnectionAuthTypes() {
        return pop3_secure_connection_auth_types_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function gets a list of the allowed authentication methods on a plain connection.
     * The returned string can look like this: "(plain login cram-md5 digest-md5 gssapi)"
     *
     * @return string
     */
    public function getPlainConnectionAuthTypes() {
        return pop3_plain_connection_auth_types_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns 1 if plain text authentication is allowed on plain connections and 0 if otherwise
     *
     * @return int
     */
    public function getPlainConnectionAllowLogin() {
        return pop3_plain_connection_allow_login_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the userdb connector type
     *
     * @return string
     */
    public function getUserdbConnectorType() {
        return pop3_userdb_connector_type_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the userdb connector name
     *
     * @return string
     */
    public function getUserdbConnectorName() {
        return pop3_userdb_connector_name_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the log level for this service.
     *
     * @return int
     */
    public function getLogLevel() {
        return pop3_log_level_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return string
     */
    public function getLogHost() {
        return pop3_log_host_get($this->getPop3Obj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return string Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return pop3_log_type_get($this->getPop3Obj());
    }
    /**
     * @ignore
     */
    public function getGreetingsText() {
        return pop3_greetings_text_get($this->getPop3Obj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = pop3_max_connection_threads_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = pop3_min_connection_threads_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum number of protocol errors after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = pop3_max_errors_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum authentication errors number after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authenticated errors
     */
    public function setMaxAuthErrors($value) {
        $set = pop3_max_auth_errors_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets if secure connections (which start with STARTTLS) are allowed for this service
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, secure connections (which start with STARTTLS) are allowed for this service, if it is 0 then secure connection are not allowed
     */
    public function setAllowStartTls($value) {
        $set = pop3_allow_start_tls_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETALLOWSTARTTLS);
    }
    /**
     * @ignore
     * This function sets if the plain authentication of secure connections is allowed for this service
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1 plain authentication of secure connections is allowed for this service, if it is 0 then plain authentication is not allowed for secure connections.
     */
    public function setSecureConnectionAllowLogin($value) {
        $set = pop3_secure_connection_allow_login_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETSECUREALLOWLOGIN);
    }
    /**
     * @ignore
     * This function sets the list of the allowed authentication methods on a secure connection.
     * @return bool
     *
     * @param $value string The supplied string parameter must look like this: "(plain login cram-md5 digest-md5 gssapi)"
     */
    public function setSecureConnectionAuthTypes($value) {
        $set = pop3_secure_connection_auth_types_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETSECUREAUTHTYPES);
    }
    /**
     * @ignore
     * This function sets the list of the allowed authentication methods on a plain connection.
     * @return bool
     *
     * @param $value string The supplied string parameter must look like this: "(plain login cram-md5 digest-md5 gssapi)"
     */
    public function setPlainConnectionAuthTypes($value) {
        $set = pop3_plain_connection_auth_types_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETPLAINAUTHTYPES);
    }
    /**
     * @ignore
     * This function sets the list of the allowed authentication methods on a plain connection.
     * @return bool
     *
     * @param $value string The supplied string parameter must look like this: "(plain login cram-md5 digest-md5 gssapi)"
     */
    public function setPlainConnectionAllowLogin($value) {
        $set = pop3_plain_connection_allow_login_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETPLAINCONNALLOWLOGIN);
    }
    /**
     * @ignore
     * This function sets the userdb connector type
     * @return bool
     *
     * @param $value string Valid string values for the 'value' parameter are: "local", "ldap" or "ldapBind"
     */
    public function setUserdbConnectorType($value) {
        $set = pop3_userdb_connector_type_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3USERDBCONNTYPE);
    }
    /**
     * @ignore
     * This function sets the name of the userdb connector
     * @return bool
     *
     * @param $value string userdb connector name
     */
    public function setUserdbConnectorName($value) {
        $set = pop3_userdb_connector_name_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3USERDBCONNNAME);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = pop3_log_level_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = pop3_log_host_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = pop3_log_type_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETLOGTYPE);
    }
    /**
     * @ignore
     * set pop3 greeting
     */
    public function setGreetingsText($value) {
        $set = pop3_greetings_text_set($this->getPop3Obj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::POP3SETGREETING);
    }
    /**
     * @private
     * This function saves the POP3 configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = pop3_save($this->getPop3Obj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::POP3SAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = pop3_reset($this->getPop3Obj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::POP3RESET);
    }
    /**
     * This function starts the POP3 service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("pop3");
    }
    /**
     * This function stops the POP3 service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("pop3");
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = pop3_listeners_get($this->getPop3Obj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::POP3GETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::POP3ADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = pop3_listeners_get($this->getPop3Obj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::POP3GETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::POP3REMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = pop3_listeners_get($this->getPop3Obj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::POP3GETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::POP3UPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = pop3_listeners_get($this->getPop3Obj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::POP3GETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::POP3GETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = pop3_get_access_control($this->getPop3Obj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::POP3ACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
}
/** @} */ // end of group
?>
