<?php
/**
 * \ingroup configServer
 * \defgroup configProcessing configProcessing
 * @{
*/
class Processing {
    private $processingObj, $parent;
    public function __construct($processingObj, $parent) {
        $this->processingObj = $processingObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        processing_destroy($this->getProcessingObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getProcessingObj() {
        return $this->processingObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxMailScheduleInterval</td>
<td>the maximum interval for email rescheduling in case of a delivery error (in seconds)</td>
<tr><td>queueScheduleInterval</td>
<td>the interval for queue checking</td>
<tr><td>maxRetryCount</td>
<td>the maximum number of retries to deliver an email</td>
<tr><td>deliveryThreads</td>
<td>the number of email delivery threads</td>
<tr><td>internalQueueSize</td>
<td>the internal processing queue size (in number of messages)</td>
<tr><td>messagesPerSecond</td>
<td>the maximum number of emails that a mailbox (folder) is allowed to receive in one second</td>
<tr><td>mailboxDisableInterval</td>
<td>the number of seconds a mailbox (folder) is disabled if the "messages per second" limit is disabled</td>
<tr><td>maxDirectoryCount</td>
<td>the maximum number of directories in the queue directory</td>
<tr><td>queuePath</td>
<td>the path of the queue directory</td>
<tr><td>logLevel</td>
<td>the log level for the processing service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the processing service</td>
<tr><td>filteringThreads</td>
<td>number of threads handling the message filtering</td>
<tr><td>greylistingCache </td>
<td>number of seconds a greylisted entry is kept in cache</td>
</table>
     */
    public function __get($name) {
        switch (strtolower($name)) {
            case 'maxmailscheduleinterval':
                return $this->getMaxMailScheduleInterval();
            break;
            case 'queuescheduleinterval':
                return $this->getQueueScheduleInterval();
            break;
            case 'maxretrycount':
                return $this->getMaxRetryCount();
            break;
            case 'deliverythreads':
                return $this->getDeliveryThreads();
            break;
            case 'internalqueuesize':
                return $this->getInternalQueueSize();
            break;
            case 'messagespersecond':
                return $this->getMessagesPerSecond();
            break;
            case 'mailboxdisableinterval':
                return $this->getMailboxDisableInterval();
            break;
            case 'maxdirectorycount':
                return $this->getMaxDirectoryCount();
            break;
            case 'queuepath':
                return $this->getQueuePath();
            break;
            case 'loglevel':
                return $this->getLogLevel();
            break;
            case 'loghost':
                return $this->getLogHost();
            break;
            case 'logtype':
                return $this->getLogType();
            break;
            case 'filteringthreads':
                return $this->getFilteringThreads();
            break;
            case 'greylistingcache':
                return $this->getGreylistingCache();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxMailScheduleInterval</td>
<td>the maximum interval for email rescheduling in case of a delivery error (in seconds)</td>
<tr><td>queueScheduleInterval</td>
<td>the interval for queue checking</td>
<tr><td>maxRetryCount</td>
<td>the maximum number of retries to deliver an email</td>
<tr><td>deliveryThreads</td>
<td>the number of email delivery threads</td>
<tr><td>internalQueueSize</td>
<td>the internal processing queue size (in number of messages)</td>
<tr><td>messagesPerSecond</td>
<td>the maximum number of emails that a mailbox (folder) is allowed to receive in one second</td>
<tr><td>mailboxDisableInterval</td>
<td>the number of seconds a mailbox (folder) is disabled if the "messages per second" limit is disabled</td>
<tr><td>maxDirectoryCount</td>
<td>the maximum number of directories in the queue directory</td>
<tr><td>queuePath</td>
<td>the path of the queue directory</td>
<tr><td>logLevel</td>
<td>the log level for the processing service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the processing service</td>
<tr><td>filteringThreads</td>
<td>number of threads handling the message filtering</td>
<tr><td>greylistingCache </td>
<td>number of seconds a greylisted entry is kept in cache</td>
</table>
     */
    public function __set($name, $value) {
        switch (strtolower($name)) {
            case 'maxmailscheduleinterval':
                return $this->setMaxMailScheduleInterval($value);
            break;
            case 'queuescheduleinterval':
                return $this->setQueueScheduleInterval($value);
            break;
            case 'maxretrycount':
                return $this->setMaxRetryCount($value);
            break;
            case 'deliverythreads':
                return $this->setDeliveryThreads($value);
            break;
            case 'internalqueuesize':
                return $this->setInternalQueueSize($value);
            break;
            case 'messagespersecond':
                return $this->setMessagesPerSecond($value);
            break;
            case 'mailboxdisableinterval':
                return $this->setMailboxDisableInterval($value);
            break;
            case 'maxdirectorycount':
                return $this->setMaxDirectoryCount($value);
            break;
            case 'queuepath':
                return $this->setQueuePath($value);
            break;
            case 'loglevel':
                return $this->setLogLevel($value);
            break;
            case 'loghost':
                return $this->setLogHost($value);
            break;
            case 'logtype':
                return $this->setLogType($value);
            break;
            case 'filteringthreads':
                return $this->setFilteringThreads($value);
            break;
            case 'greylistingcache':
                return $this->setGreylistingCache($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function obtains the number of greylistingCache
     *
     * @return int
     */
    public function getGreylistingCache() {
        return processing_greylisting_cache_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function obtains the number of filtering threads
     *
     * @return int
     */
    public function getFilteringThreads() {
        return processing_filtering_threads_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function obtains the maximum interval for email rescheduling in case of a delivery error (in seconds)
     *
     * @return int
     */
    public function getMaxMailScheduleInterval() {
        return processing_max_mail_schedule_interval_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function obtains the interval for queue checking
     *
     * @return int
     */
    public function getQueueScheduleInterval() {
        return processing_queue_schedule_interval_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of retries to deliver an email
     *
     * @return int
     */
    public function getMaxRetryCount() {
        return processing_max_retry_count_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the number of email delivery threads
     *
     * @return int
     */
    public function getDeliveryThreads() {
        return processing_delivery_threads_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the internal processing queue size (in number of messages)
     *
     * @return int
     */
    public function getInternalQueueSize() {
        return processing_internal_queue_size_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of emails that a mailbox (folder) is allowed to receive in one second
     *
     * @return int
     */
    public function getMessagesPerSecond() {
        return processing_messages_per_second_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the number of seconds a mailbox (folder) is disabled if the "messages per second" limit is disabled
     *
     * @return int
     */
    public function getMailboxDisableInterval() {
        return processing_mailbox_disable_interval_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of directories in the queue directory
     *
     * @return int
     */
    public function getMaxDirectoryCount() {
        return processing_max_directory_count_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the path of the queue directory
     *
     * @return int
     */
    public function getQueuePath() {
        return processing_queue_path_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return processing_log_level_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return processing_log_host_get($this->getProcessingObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return processing_log_type_get($this->getProcessingObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the number of greylistingCache
     * @return bool
     *
     * @param $value int the number of greylistingCache
     */
    public function setGreylistingCache($value) {
        $set = processing_greylisting_cache_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETGREYLISTCACHE);
    }
    /**
     * @ignore
     * This function sets the number of filtering threads
     * @return bool
     *
     * @param $value int the number of filtering threads
     */
    public function setFilteringThreads($value) {
        $set = processing_filtering_threads_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETFILTERINGTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum interval for email rescheduling in case of a delivery error (in seconds).
     * @return bool
     *
     * @param $value int the maximum interval for email rescheduling in case of a delivery error (in seconds)
     */
    public function setMaxMailScheduleInterval($value) {
        $set = processing_max_mail_schedule_interval_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETMAILSCHEDULEINT);
    }
    /**
     * @ignore
     * This function sets the interval for queue checking
     * @return bool
     *
     * @param $value int The interval for queue checking
     */
    public function setQueueScheduleInterval($value) {
        $set = processing_queue_schedule_interval_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETQSCHEDULEINT);
    }
    /**
     * @ignore
     * This function sets the maximum number of retries to deliver an email
     * @return bool
     *
     * @param $value int the maximum number of retries to deliver an email
     */
    public function setMaxRetryCount($value) {
        $set = processing_max_retry_count_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETMAXRETRYCOUNT);
    }
    /**
     * @ignore
     * This function sets the number of email delivery threads
     * @return bool
     *
     * @param $value int the number of email delivery threads
     */
    public function setDeliveryThreads($value) {
        $set = processing_delivery_threads_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETDELIVERYTHREADS);
    }
    /**
     * @ignore
     * This function sets the internal processing queue size (in number of messages).
     * @return bool
     *
     * @param $value int the internal processing queue size (in number of messages)
     */
    public function setInternalQueueSize($value) {
        $set = processing_internal_queue_size_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETINTERNALQSIZE);
    }
    /**
     * @ignore
     * This function sets the maximum number of emails that a mailbox (folder) is allowed to receive in one second
     * @return bool
     *
     * @param $value int the maximum number of emails that a mailbox (folder) is allowed to receive in one second
     */
    public function setMessagesPerSecond($value) {
        $set = processing_messages_per_second_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETMESGSPERSEC);
    }
    /**
     * @ignore
     * This function sets the number of seconds a mailbox (folder) is disabled if the "messages per second" limit is disabled
     * @return bool
     *
     * @param $value int the number of seconds a mailbox (folder) is disabled if the "messages per second" limit is disabled
     */
    public function setMailboxDisableInterval($value) {
        $set = processing_mailbox_disable_interval_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETMBOXDISABLEINT);
    }
    /**
     * @ignore
     * This function sets the maximum number of directories in the queue directory
     * @return bool
     *
     * @param $value int the maximum number of directories in the queue directory
     */
    public function setMaxDirectoryCount($value) {
        $set = processing_max_directory_count_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETMAXDIRECTORYCOUNT);
    }
    /**
     * @ignore
     * This function sets the path of the queue directory
     * @return bool
     *
     * @param $value string the path of the queue directory
     */
    public function setQueuePath($value) {
        $set = processing_queue_path_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETQPATH);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = processing_log_level_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = processing_log_host_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = processing_log_type_set($this->getProcessingObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::PROCESSINGSETLOGTYPE);
    }
    /**
     * @private
     * This function saves the processing configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = processing_save($this->getProcessingObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::PROCESSINGSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = processing_reset($this->getProcessingObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::PROCESSINGRESET);
    }
}
/** @} */ // end of group
?>
