<?php
/**
 * \ingroup updateDomain
 * \defgroup configPublicFolder configPublicFolder
 * @{
 * this object contains the Public Folder data
 */
class PublicFolder {
    private $publicFolder, $parent, $quotas;
    public function __construct($publicFolterObj, $parentObj) {
        $this->publicFolder = $publicFolterObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        public_folders_destroy($this->getPublicFolderObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getPublicFolderObj() {
        return $this->publicFolder;
    }
    /**
     * this method returns an array with all the mboxes
     * @return array
     */
    public function listMboxes() {
        if (!$this) return false;
        $mboxes = array();
        $pfIterObj = mbox_iterator_begin($this->getPublicFolderObj());
        if (!Debug::checkError($pfIterObj, "_p_mbox_iterator", Debug::INFOERROR, Message::LISTPUBLICFOLDERMBOXS)) return false;
        while (mbox_iterator_has_value($pfIterObj)) {
            $pfObj = mbox_iterator_value($pfIterObj);
            array_push($mboxes, mbox_get_name($pfObj));
            mbox_iterator_next($pfIterObj);
        }
        mbox_iterator_destroy($pfIterObj);
        return $mboxes;
    }
    /**
     * this method adds a new Mbox
     * @return bool
     * @param $name string the new mbox name
     */
    public function addMbox($name) {
        if (!$this) return false;
        $resp = mbox_add($this->getPublicFolderObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDPUBLICFOLDERMBOX)) return false;
        return $this->save();
    }
    /**
     * this method removes a mbox
     * @return bool
     * @param $name string mbox name to be removed
     */
    public function removeMbox($name) {
        if (!$this) return false;
        $resp = mbox_remove($this->getPublicFolderObj() , $name);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEPUBLICFOLDERMBOX)) return false;
        return $this->save();
    }
    /**
     * this method returns quotas object
     * @return object Quotas
     */
    public function configQuotas() {
        if (!$this) return false;
        if (!is_object($this->quotas)) {
            $quotasObj = public_folders_quotas_get($this->getPublicFolderObj() , $this->getSessionObj());
            if (!Debug::checkError($quotasObj, "_p_quotas", Debug::FATALERROR, Message::LOADPFOLDERDEFAULTQUOTAS)) return false;
            $this->quotas = new Quotas($quotasObj, $this);
        }
        return $this->quotas;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = public_folders_save($this->getPublicFolderObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEPUBLICFOLDER);
    }
    /**
     * You can set member 'name' (the name of the public folder).
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                $resp = public_folders_name_set($this->getPublicFolderObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETPUBLICFOLDERVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETPUBLICFOLDERVARERROR);
    }
    /**
     * Get 'name', the name of the public folder.
     */
    public function __get($varName) {
        if (!$this) return false;
        switch ($varName) {
            case "name":
                return public_folders_name_get($this->getPublicFolderObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETPUBLICFOLDERVARERROR);
                return;
        }
    }
}
/** @} */ // end of group
?>
