<?php
/**
 * \ingroup cliobject
 * \defgroup viewQueue viewQueue
 * @{
*/
class Queue {
    private $queue, $parent, $filterObj, $quarantine;
    public function __construct($queueObj, $parentObj) {
        $this->queue = $queueObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        queue_destroy($this->getQueueObj());
        if (is_resource($this->getFilterObj())) {
            queue_filter_destroy($this->getFilterObj());
        }
    }
    public function getQueueObj() {
        return $this->queue;
    }
    public function getFilterObj() {
        return $this->filterObj;
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    /**
     * returns an array with all the emails from the queue
     * @return array
     */
    public function listQueueEMails() {
        if (!$this) return false;
        $queue = array();
        $resp = queue_load_items($this->getQueueObj() , $this->getSessionObj());
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOADQUEUEITEMS)) return false;
        $queueIterObj = queue_item_iterator_begin($this->getQueueObj());
        if (!Debug::checkError($queueIterObj, "_p_queue_item_iterator", Debug::INFOERROR, Message::LISTQUEUEEMAILS)) return false;
        while (queue_item_iterator_has_value($queueIterObj)) {
            $queueObj = queue_item_iterator_value($queueIterObj);
            unset($tmp);
            $tmp['id'] = queue_item_id_get($queueObj);
            $tmp['sender'] = queue_item_sender_get($queueObj);
            $tmp['recipients'] = queue_item_recipients_get($queueObj);
            $tmp['status'] = queue_item_status_get($queueObj);
            $tmp['size'] = queue_item_size_get($queueObj);
            $tmp['nextSchedule'] = queue_item_next_schedule_get($queueObj);
            array_push($queue, $tmp);
            queue_item_iterator_next($queueIterObj);
        }
        queue_item_iterator_destroy($queueIterObj);
        return $queue;
    }
    private function startFilter() {
        $resp = queue_create_filter($this->getQueueObj());
        Debug::checkError($resp, "_p_queue_filter", Debug::INFOERROR, Message::QUEUEFILTER);
        $this->filterObj = $resp;
    }
    /**
     * clears the already set filters
     * @return bool
     */
    public function clearFilters() {
        if (!$this) return false;
        if (is_resource($this->getFilterObj())) {
            queue_filter_destroy($this->getFilterObj());
            $this->filterObj = null;
        }
        $this->startFilter();
        return is_resource($this->getFilterObj());
    }
    /**
     * sets the filter size restriction
     * @return bool
     * @param $size int the message size
     * @param $compareType string type of comparison (equal , less, more)
     * @param $sizeType string type of size (B - bytes, KB - kilobytes, MB - megabytes)
     */
    public function imposeSizeRestriction($size, $compareType = "equal", $sizeType = "kb") {
        if (!$this) return false;
        switch (strtolower($sizeType)) {
            case "b":
                $b = $size;
                $kb = $mb = 0;
            break;
            case "kb":
                $kb = $size;
                $b = $mb = 0;
            break;
            case "mb":
                $mb = $size;
                $kb = $b = 0;
            break;
            default:
                return false;
        }
        switch (strtolower($compareType)) {
            case "equal":
                $how = 0;
            break;
            case "less":
                $how = -1;
            break;
            case "more";
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = impose_size_restriction($this->getFilterObj() , $mb, $kb, $b, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter status restriction
 * @return bool
 * @param $status string the email status ("SEND FAILURE", "PROCESSING ERROR", "RELAY ERROR", "LOCAL ERROR", "FILTER REJECT", "FILTER DISCARD")
 */
public function imposeStatusRestriction($status) {
    if (!$this) return false;
    switch (strtolower($status)) {
        case "send failure":
            $stat = 1;
        break;
        case "processing error":
            $stat = 2;
        break;
        case "relay error":
            $stat = 3;
        break;
        case "local error":
            $stat = 4;
        break;
        case "filter reject":
            $stat = 5;
        break;
        case "filter discard":
            $stat = 6;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = impose_status_restriction($this->getFilterObj() , $stat);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter age restriction
 * @return bool
 * @param $day int number of days
 * @param $hours int number of hours
 * @param $min int number of minutes
 * @param $sec int number of seconds
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeAgeRestriction($day = 0, $hours = 0, $min = 0, $sec = 0, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = impose_age_restriction($this->getFilterObj() , $day, $hours, $min, $sec, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter retries restriction
 * @return bool
 * @param $nrOfRetries int number of retries
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeRetriesRestriction($nrOfRetries, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = impose_retries_restriction($this->getFilterObj() , $nrOfRetries, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter next schedule restriction
 * @return bool
 * @param $date string next schedule date (ex: 2 Jan 2007 17:34)
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeNextScheduleRestriction($date, $compareType) {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = impose_next_schedule_restriction($this->getFilterObj() , $date, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter sender restriction
 * @return bool
 * @param $sender string the Sender to filter
 * @param $compareType string type of comparison (equal , not equal)
 */
public function imposeSenderRestriction($sender, $compareType) {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "notequal":
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = impose_sender_restriction($this->getFilterObj() , $sender, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * sets the filter recipient restriction
 * @return bool
 * @param $recipient string the Recipient to filter
 * @param $compareType string type of comparison (equal , not equal)
 */
public function imposeRecipientRestriction($recipient, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "notequal":
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = impose_recipient_restriction($this->getFilterObj() , $recipient, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUEUEFILTERS);
}
/**
 * applies a delete action to filtered emails
 * @return bool
 */
public function deleteFilteredEmails() {
    $resp = apply_filter($this->getFilterObj() , $this->getQueueObj() , $this->getSessionObj() , 3);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::QUEUEDELETEFILTERED);
}
/**
 * applies a NDR action to filtered emails
 * @return bool
 */
public function sendNDRFilteredEmails() {
    $resp = apply_filter($this->getFilterObj() , $this->getQueueObj() , $this->getSessionObj() , 2);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::QUEUESENDNDRFILTERED);
}
/**
 * applies a retry action to filtered emails
 * @return bool
 */
public function retryFilteredEmails() {
    $resp = apply_filter($this->getFilterObj() , $this->getQueueObj() , $this->getSessionObj() , 1);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::QUEUERETRYFILTERED);
}
/**
 * returns an array with emails filtered by already set filters
 * @return array
 */
public function listFilteredEMails($action = "no action") {
    if (!$this) return false;
    if (!is_resource($this->getFilterObj())) return false;
    $list = array();
    $resp = apply_filter($this->getFilterObj() , $this->getQueueObj() , $this->getSessionObj() , 0);
    if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::APPLYQUEUEFILTERS)) return false;
    $listObj = queue_filter_item_iterator_begin($this->getFilterObj());
    if (!Debug::checkError($listObj, "_p_queue_filter_item_iterator", Debug::INFOERROR, Message::LISTQUEUEFILTERS)) return false;
    while (queue_filter_item_iterator_has_value($listObj)) {
        $queueObj = queue_filter_item_iterator_value($listObj);
        unset($tmp);
        $tmp['id'] = queue_item_id_get($queueObj);
        $tmp['sender'] = queue_item_sender_get($queueObj);
        $tmp['recipients'] = queue_item_recipients_get($queueObj);
        $tmp['status'] = queue_item_status_get($queueObj);
        $tmp['size'] = queue_item_size_get($queueObj);
        $tmp['nextSchedule'] = queue_item_next_schedule_get($queueObj);
        array_push($list, $tmp);
        queue_filter_item_iterator_next($listObj);
    }
    queue_filter_item_iterator_destroy($listObj);
    return $list;
}
/**
 * this method forces the emails queue delivery
 * @return bool
 */
public function forceQueueDelivery() {
    if (!$this) return false;
    $resp = queue_force_delivery($this->getQueueObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FORCEQUEUE);
}
/**
 * this method tells Axigen to retry sending the mailId
 * @return bool
 * @param $mailID int the mail it to retry
 */
public function retryQueueEMail($mailID) {
    if (!$this) return false;
    $resp = queue_retry_message_by_id($mailID, $this->getQueueObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::RETRYQUEUE);
}
/**
 * this method tells Axigen to send NDR to the mailId
 * @return bool
 * @param $mailID int the mail it to send NDR
 */
public function sendNDRQueueEMail($mailID) {
    if (!$this) return false;
    $resp = queue_send_ndr_for_message_by_id($mailID, $this->getQueueObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SENDNDRQUEUE);
}
/**
 * this method tells Axigen to delete the mailId
 * @return bool
 * @param $mailID int the mailId to delete
 */
public function deleteQueueEMail($mailID) {
    if (!$this) return false;
    $resp = queue_delete_message_by_id($mailID, $this->getQueueObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DELETEQUEUE);
}
    /**
     * this method returns an object with the qurantine 
     * @return object Quarantine
     */
    public function enterQuarantine() {
        if (!$this) return false;
        if (!is_object($this->quarantine)) {
            $quarantineObj = queue_quarantine_get($this->getQueueObj() , $this->getSessionObj());
            if (!Debug::checkError($quarantineObj, "_p_quarantine", Debug::FATALERROR, Message::QUARANTINE)) return false;
            $this->quarantine = new Quarantine($quarantineObj, $this);
        }
        return $this->quarantine;
    }
}
/** @} */ // end of group
?>
