<?php
/**
 * \ingroup updateAccount
 * \defgroup configQuotas configQuotas
 * @{
 * This object contains the Quotas data
 */
class Quotas {
    private $quotas, $parent;
    public function __construct($quotasObj, $parentObj) {
        $this->quotas = $quotasObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        quotas_destroy($this->getQuotasObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getQuotasObj() {
        return $this->quotas;
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>mboxCount</td>
<td>the maximum number of folders</td>
<tr><td>totalMessageCount</td>
<td>the maximum number of messages in all folders</td>
<tr><td>totalMessageSize</td>
<td>the maximum size (in KB) of all messages in all folders</td>
<tr><td>messageCount</td>
<td>the default maximum number of messages in a folder</td>
<tr><td>messageSize</td>
<td>the default maximum size (in KB) of messages in a folder</td>
<tr><td>limitThreshold</td>
<td>percent of quota which triggers an alert</td>
<tr><td>limitNotificationInterval</td>
<td>the minimum interval (in minutes) between two quota limit notifications</td>
<tr><td>limitNotificationEnabled</td>
<td>the quota limit notification as enabled/disabled</td>
<tr><td>limitNotificationSubject</td>
<td>email subject of quota limit notification message</td>
<tr><td>limitNotificationBody</td>
<td>email body of quota limit notification message</td>
<tr><td>quotaSendMessageThreshold</td>
<td>percent of quota which blocks user from message sending</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "mboxcount":
                $resp = quotas_mbox_count_set($this->getQuotasObj() , $varValue);
            break;
            case "totalmessagecount":
                $resp = quotas_total_message_count_set($this->getQuotasObj() , $varValue);
            break;
            case "totalmessagesize":
                $resp = quotas_total_message_size_set($this->getQuotasObj() , $varValue);
            break;
            case "messagecount":
                $resp = quotas_message_count_set($this->getQuotasObj() , $varValue);
            break;
            case "messagesize":
                $resp = quotas_message_size_set($this->getQuotasObj() , $varValue);
            break;
            case "limitthreshold":
                $resp = quotas_limit_threshold_set($this->getQuotasObj() , $varValue);
            break;
            case "limitnotificationinterval":
                $resp = quotas_limit_notification_interval_set($this->getQuotasObj() , $varValue);
            break;
            case "limitnotificationenabled":
                $resp = quotas_limit_notification_enabled_set($this->getQuotasObj() , $varValue);
            break;
            case "limitnotificationsubject":
                $resp = quotas_limit_notification_subject_set($this->getQuotasObj() , $varValue);
            break;
            case "limitnotificationbody":
                $resp = quotas_limit_notification_body_set($this->getQuotasObj() , $varValue);
            break;
            case "quotasendmessagethreshold":
                $resp = quotas_quota_send_message_threshold_set($this->getQuotasObj(), $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETQUOTASVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUOTASVARERROR);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>mboxCount</td>
<td>the maximum number of folders</td>
<tr><td>totalMessageCount</td>
<td>the maximum number of messages in all folders</td>
<tr><td>totalMessageSize</td>
<td>the maximum size (in KB) of all messages in all folders</td>
<tr><td>messageCount</td>
<td>the default maximum number of messages in a folder</td>
<tr><td>messageSize</td>
<td>the default maximum size (in KB) of messages in a folder</td>
<tr><td>limitThreshold</td>
<td>percent of quota which triggers an alert</td>
<tr><td>limitNotificationInterval</td>
<td>the minimum interval (in minutes) between two quota limit notifications</td>
<tr><td>limitNotificationEnabled</td>
<td>the quota limit notification as enabled/disabled</td>
<tr><td>limitNotificationSubject</td>
<td>email subject of quota limit notification message</td>
<tr><td>limitNotificationBody</td>
<td>email body of quota limit notification message</td>
<tr><td>quotaSendMessageThreshold</td>
<td>percent of quota which blocks user from message sending</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "mboxcount":
                return quotas_mbox_count_get($this->getQuotasObj());
            break;
            case "totalmessagecount":
                return quotas_total_message_count_get($this->getQuotasObj());
            break;
            case "totalmessagesize":
                return quotas_total_message_size_get($this->getQuotasObj());
            break;
            case "messagecount":
                return quotas_message_count_get($this->getQuotasObj());
            break;
            case "messagesize":
                return quotas_message_size_get($this->getQuotasObj());
            break;
            case "limitthreshold":
                return quotas_limit_threshold_get($this->getQuotasObj());
            break;
            case "limitnotificationinterval":
                return quotas_limit_notification_interval_get($this->getQuotasObj());
            break;
            case "limitnotificationenabled":
                return quotas_limit_notification_enabled_get($this->getQuotasObj());
            break;
            case "limitnotificationsubject":
                return quotas_limit_notification_subject_get($this->getQuotasObj());
            break;
            case "limitnotificationbody":
                return quotas_limit_notification_body_get($this->getQuotasObj());
            break;
            case "quotasendmessagethreshold":
                return quotas_quota_send_message_threshold_get($this->getQuotasObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETQUOTASVARERROR);
                return;
        }
    }
    /**
     * check if the variable is inherited
     * @return int (1 if the value is inherited, 0 if not, or -1 if this does not apply to the current quota object)
     * @param $varName string the variable
     */
    public function isInherited($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "mboxcount":
                $resp = quotas_mbox_count_is_inherited($this->getQuotasObj());
            break;
            case "totalmessagecount":
                $resp = quotas_total_message_count_is_inherited($this->getQuotasObj());
            break;
            case "totalmessagesize":
                $resp = quotas_total_message_size_is_inherited($this->getQuotasObj());
            break;
            case "messagecount":
                $resp = quotas_message_count_is_inherited($this->getQuotasObj());
            break;
            case "messagesize":
                $resp = quotas_message_size_is_inherited($this->getQuotasObj());
            break;
            case "limitthreshold":
                $resp = quotas_limit_threshold_is_inherited($this->getQuotasObj());
            break;
            case "limitnotificationinterval":
                $resp = quotas_limit_notification_interval_is_inherited($this->getQuotasObj());
            break;
            case "limitnotificationenabled":
                $resp = quotas_limit_notification_enabled_is_inherited($this->getQuotasObj());
            break;
            case "limitnotificationsubject":
                $resp = quotas_limit_notification_subject_is_inherited($this->getQuotasObj());
            break;
            case "limitnotificationbody":
                $resp = quotas_limit_notification_body_is_inherited($this->getQuotasObj());
            break;
            case "quotasendmessagethreshold":
                $resp = quotas_quota_send_message_threshold_is_inherited($this->getQuotasObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::ISINHERITEDQUOTASVARERROR);
                return -1;
        }
        return $resp;
    }
    /**
     * sets the variable to inherit from the selected source
     * @return bool
     * @param $varName string the variable
     */
    public function inherit($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "mboxcount":
                $resp = quotas_mbox_count_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "totalmessagecount":
                $resp = quotas_total_message_count_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "totalmessagesize":
                $resp = quotas_total_message_size_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "messagecount":
                $resp = quotas_message_count_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "messagesize":
                $resp = quotas_message_size_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "limitthreshold":
                $resp = quotas_limit_threshold_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "limitnotificationinterval":
                $resp = quotas_limit_notification_interval_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "limitnotificationenabled":
                $resp = quotas_limit_notification_enabled_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "limitnotificationsubject":
                $resp = quotas_limit_notification_subject_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "limitnotificationbody":
                $resp = quotas_limit_notification_body_inherit($this->getQuotasObj() , $this->getSessionObj());
            break;
            case "quotasendmessagethreshold":
                $resp = quotas_quota_send_message_threshold_inherit($this->getQuotasObj(), $this->getSessionObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::INHERITQUOTASVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::INHERITQUOTASVARERROR);
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = quotas_save($this->getQuotasObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEQUOTASDATA);
    }
    /**
     * this method returns an array with all the mboxes and their quotas
     * @return array
     */
    public function listMboxes() {
        $mboxes = array();
        $mboxIterObj = mbox_quota_iterator_begin($this->getQuotasObj());
        if (!Debug::checkError($mboxIterObj, "_p_mbox_quota_iterator", Debug::INFOERROR, Message::LISTMBOXES)) return false;
        while (mbox_quota_iterator_has_value($mboxIterObj)) {
            $tmpMbox = array();
            $mboxObj = mbox_quota_iterator_value($mboxIterObj);
            $tmpMbox['name'] = mbox_quota_name_get($mboxObj);
            $tmpMbox['messageCount'] = mbox_quota_message_count_get($mboxObj);
            $tmpMbox['messageSize'] = mbox_quota_message_size_get($mboxObj);
            array_push($mboxes, $tmpMbox);
            mbox_quota_iterator_next($mboxIterObj);
        }
        mbox_quota_iterator_destroy($mboxIterObj);
        return $mboxes;
    }
    /**
     * this method sets quota on a mbox
     * @return bool
     * @param $name string the mbox name where you want to change quotas
     * @param $messageCount double the new message count quota
     * @param $messageSize double the new message size quota
     */
    public function setMboxQuota($name, $messageCount, $messageSize) {
        $mboxObj = quotas_mbox_quota_get_by_name($this->getQuotasObj() , $name);
        if (!Debug::checkError($mboxObj, "_p_mbox_quota", Debug::INFOERROR, Message::SETMBOXQUOTA)) return false;
        mbox_quota_message_count_set($mboxObj, $messageCount);
        mbox_quota_message_size_set($mboxObj, $messageSize);
        #$resp = quotas_save($this->getQuotasObj(),$this->getSessionObj());
        #mbox_quota_destroy($mboxObj);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETMBOXQUOTA);
    }
    /**
     * this method returns an array with selected mbox quota
     * @return array
     * @param $name string the mbox name from where you want to retrieve quotas
     */
    public function showMboxQuota($name) {
        $mboxObj = quotas_mbox_quota_get_by_name($this->getQuotasObj() , $name);
        if (!Debug::checkError($mboxObj, "_p_mbox_quota", Debug::INFOERROR, Message::GETMBOXQUOTA)) return false;
        $mbox['messageCount'] = mbox_quota_message_count_get($mboxObj);
        $mbox['messageSize'] = mbox_quota_message_size_get($mboxObj);
        $mbox['name'] = mbox_quota_name_get($mboxObj);
        #mbox_quota_destroy($mboxObj);
        return $mbox;
    }
}
/** @} */ // end of group
?>
