<?php
/**
 * \ingroup configServer
 * \defgroup configReport configReport
 * @{
*/
class Report {
    private $reportObj, $parent, $listener, $accesscontrol;
    public function __construct($reportObj, $parent) {
        $this->reportObj = $reportObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        report_destroy($this->getReportObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getReportObj() {
        return $this->reportObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>DomainEnable</td>
<td>Enabled/Disabled Domain Collecting</td>
<tr><td>DomainObjectEnable</td>
<td>Enabled/Disabled Domain Objects Collecting</td>
<tr><td>reportingInterval</td>
<td>Collect samples every (values: 0-5844 days)</td>
<tr><td>logLevel</td>
<td>the log level for the Reporting service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Reporting service</td>
<tr><td>SNMPEnable</td>
<td>the SNMP service as enabled</td>
<tr><td>SNMPSentTrapsToAllManagers</td>
<td> </td>
<tr><td>SNMPCommunity</td>
</table>
     */
    public function __get($name) {
        switch (strtolower($name)) {
            case 'domainenable':
                return $this->getDomainEnable();
            break;
            case 'domainobjectenable':
                return $this->getDomainObjectEnable();
            break;
            case 'reportinginterval':
                return $this->getReportingInterval();
            break;
            case 'loglevel':
                return $this->getLogLevel();
            break;
            case 'loghost':
                return $this->getLogHost();
            break;
            case 'logtype':
                return $this->getLogType();
            break;
            case 'snmpenable':
                return $this->getSNMPEnable();
            break;
            case 'snmpsenttrapstoallmanagers':
                return $this->getSNMPSentTrapsToAllManagers();
            break;
            case 'snmpcommunity':
                return $this->getSNMPCommunity();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>DomainEnable</td>
<td>Enabled/Disabled Domain Collecting</td>
<tr><td>DomainObjectEnable</td>
<td>Enabled/Disabled Domain Objects Collecting</td>
<tr><td>reportingInterval</td>
<td>Collect samples every (values: 0-5844 days)</td>
<tr><td>logLevel</td>
<td>the log level for the Reporting service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Reporting service</td>
<tr><td>SNMPEnable</td>
<td>the SNMP service as enabled</td>
<tr><td>SNMPSentTrapsToAllManagers</td>
<td> </td>
<tr><td>SNMPCommunity</td>
</table>
     */
    public function __set($name, $value) {
        switch (strtolower($name)) {
            case 'domainenable':
                return $this->setDomainEnable($value);
            break;
            case 'domainobjectenable':
                return $this->setDomainObjectEnable($value);
            break;
            case 'reportinginterval':
                return $this->setReportingInterval($value);
            break;
            case 'loglevel':
                return $this->setLogLevel($value);
            break;
            case 'loghost':
                return $this->setLogHost($value);
            break;
            case 'logtype':
                return $this->setLogType($value);
            break;
            case 'snmpenable':
                switch (strtolower($value)) {
                    case 1:
                        $val = 1;
                    break;
                    case "yes":
                        $val = 1;
                    break;
                    default:
                        $val = 0;
                }
                return $this->setSNMPEnable($val);
            break;
            case 'snmpsenttrapstoallmanagers':
                switch (strtolower($value)) {
                    case 1:
                        $val = 1;
                    break;
                    case "yes":
                        $val = 1;
                    break;
                    default:
                        $val = 0;
                }
                return $this->setSNMPSentTrapsToAllManagers($val);
            break;
            case 'snmpcommunity':
                return $this->setSNMPCommunity($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     *  ignore
     *
     * @return int
     */
    public function getDomainEnable() {
        return report_domain_enable_get($this->getReportObj());
    }
    /**
     * @ignore
     * ignore
     *
     * @return int
     */
    public function getDomainObjectEnable() {
        return report_domain_object_enable_get($this->getReportObj());
    }
    /**
     * @ignore
     * ignore
     *
     * @return int
     */
    public function getReportingInterval() {
        return report_reporting_interval_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return report_log_level_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return report_log_host_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return report_log_type_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the enable parameter for this service.
     *
     * @return Int Expected values are: "0" or "1"
     */
    public function getSNMPEnable() {
        return report_snmp_enable_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the SNMPSentTrapsToAllManagers parameter for this service.
     *
     * @return Int Expected values are: "0" or "1"
     */
    public function getSNMPSentTrapsToAllManagers() {
        return report_snmp_sent_traps_to_all_managers_get($this->getReportObj());
    }
    /**
     * @ignore
     * This function returns the SNMPCommunity parameter for this service.
     *
     * @return String
     */
    public function getSNMPCommunity() {
        return report_snmp_community_get($this->getReportObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * @return bool
     *
     */
    public function setDomainEnable($value) {
        $set = report_domain_enable_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETDOMAINENABLE);
    }
    /**
     * @ignore
     * @return bool
     *
     */
    public function setDomainObjectEnable($value) {
        $set = report_domain_object_enable_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETDOMAINOBJECTENABLE);
    }
    /**
     * @ignore
     * @return bool
     *
     */
    public function setReportingInterval($value) {
        $set = report_reporting_interval_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETREPORTINGINTERVAL);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = report_log_level_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = report_log_host_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = report_log_type_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETLOGTYPE);
    }
    /**
     * @ignore
     * This function sets the enable parameter for SNMP
     * @return bool
     *
     * @param $value int 1 for yes
     */
    public function setSNMPEnable($value) {
        $set = report_snmp_enable_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETENABLE);
    }
    /**
     * @ignore
     * This function sets the SNMPSentTrapsToAllManager parameter for this service
     * @return bool
     *
     * @param $value int 1 for yes
     */
    public function setSNMPSentTrapsToAllManagers($value) {
        $set = report_snmp_sent_traps_to_all_managers_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETSENTTRAPS);
    }
    /**
     * @ignore
     * This function sets the SNMPCommunity parameter for this service
     * @return bool
     *
     * @param string $value
     */
    public function setSNMPCommunity($value) {
        $set = report_snmp_community_set($this->getReportObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::REPORTSETCOMMUNITY);
    }
    /**
     * @private
     * This function saves the Reporting configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = report_save($this->getReportObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::REPORTSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = report_reset($this->getReportObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::REPORTRESET);
    }
    /**
     * This function starts the Reporting service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("report");
    }
    /**
     * This function stops the Reporting service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("report");
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = report_udplisteners_get($this->getReportObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_udplisteners", Debug::INFOERROR, Message::REPORTADDLISTENER)) return false;
        $listenerObj = udplisteners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_udplistener", Debug::INFOERROR, Message::REPORTADDLISTENER)) return false;
        udplisteners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = report_udplisteners_get($this->getReportObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_udplisteners", Debug::INFOERROR, Message::REPORTGETLISTENERS)) return false;
        $resp = udplisteners_remove_by_address($listeners, $this->getSessionObj() , $address);
        udplisteners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REPORTREMOVELISTENER);
    }
    /**
     * This function updates a listener from this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = report_udplisteners_get($this->getReportObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_udplisteners", Debug::FATALERROR, Message::REPORTGETLISTENERS)) return false;
            $listenerObj = udplisteners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_udplistener", Debug::FATALERROR, Message::REPORTUPDATELISTENER)) return false;
            $this->listener[$address] = new UdpListener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = report_udplisteners_get($this->getReportObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_udplisteners", Debug::INFOERROR, Message::REPORTGETLISTENERS)) return false;
        $listenersIterObj = udplistener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_udplistener_iterator", Debug::INFOERROR, Message::REPORTGETLISTENERS)) return false;
        while (udplistener_iterator_has_value($listenersIterObj)) {
            $listenerObj = udplistener_iterator_value($listenersIterObj);
            unset($tmp);
            if (udplistener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = udplistener_address_get($listenerObj);
            array_push($listeners, $tmp);
            udplistener_iterator_next($listenersIterObj);
        }
        udplistener_iterator_destroy($listenersIterObj);
        udplisteners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * lists available SNMP trap destinations
     * @return array
     */
    public function listSNMPTrapDestinations() {
        if (!$this) return false;
        $traps = array();
        $trapIterObj = trap_destination_iterator_begin($this->getReportObj());
        if (!Debug::checkError($trapIterObj, "_p_trap_destination_iterator", Debug::INFOERROR, Message::LISTSNMPTRAP)) return false;
        while (trap_destination_iterator_has_value($trapIterObj)) {
            $trapDestinationObj = trap_destination_iterator_value($trapIterObj);
            array_push($traps, trap_destination_address_get($trapDestinationObj));
            trap_destination_iterator_next($trapIterObj);
        }
        trap_destination_iterator_destroy($trapIterObj);
        return $traps;
    }
    /**
     * adds a SNMP trap destination to the service
     * @return bool
     * @param $address string SNMP Trap Destination Address
     */
    public function addSNMPTrapDestination($address) {
        if (!$this) return false;
        if (!is_string($address)) return false;
        $resp = trap_destination_add($this->getReportObj() , $this->getSessionObj() , $address);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDSNMPTRAP)) return false;
        return $this->save();
    }
    /**
     * removes a SNMP trap destination from the service
     * @return bool
     * @param $address string SNMP Trap Destination Address
     */
    public function removeSNMPTrapDestination($address) {
        if (!$this) return false;
        if (!is_string($address)) return false;
        $resp = trap_destination_remove_by_address($this->getReportObj() , $this->getSessionObj() , $address);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVESNMPTRAP)) return false;
        return $this->save();
    }
}
/** @} */ // end of group
?>
