<?php
/**
 * \ingroup configServer
 * \defgroup configRpop configRpop
 * @{
*/
class Rpop {
    private $rpopObj, $parent;
    public function __construct($rpopObj, $parent) {
        $this->rpopObj = $rpopObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        rpop_destroy($this->getRpopObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getRpopObj() {
        return $this->rpopObj;
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the RPOP service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the RPOP service</td>
<tr><td>logLevel</td>
<td>the log level for the RPOP service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the RPOP service</td>
</table>

     */
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            default:;
            break;
        }
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the RPOP service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the RPOP service</td>
<tr><td>logLevel</td>
<td>the log level for the RPOP service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the RPOP service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return rpop_max_connection_threads_get($this->getRpopObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return rpop_min_connection_threads_get($this->getRpopObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return rpop_log_level_get($this->getRpopObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return string
     */
    public function getLogHost() {
        return rpop_log_host_get($this->getRpopObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return string Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return rpop_log_type_get($this->getRpopObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = rpop_max_connection_threads_set($this->getRpopObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::RPOPSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = rpop_min_connection_threads_set($this->getRpopObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::RPOPSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = rpop_log_level_set($this->getRpopObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::RPOPSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = rpop_log_host_set($this->getRpopObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::RPOPSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param string value Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype string
     */
    public function setLogType($value) {
        $set = rpop_log_type_set($this->getRpopObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::RPOPSETLOGTYPE);
    }
    /**
     * @private
     * This function saves the RPOP configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = rpop_save($this->getRpopObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::RPOPSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = rpop_reset($this->getRpopObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::RPOPRESET);
    }
    /**
     * This function starts the RPOP service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("rpop");
    }
    /**
     * This function stops the RPOP service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("rpop");
    }
}
/** @} */ // end of group
?>
