<?php
/**
 * \ingroup updateAccount
 * \defgroup configSendRecvRestrictions configSendRecvRestrictions
 * @{
 */
class SendRecvRestrictions {
    private $sendrecvrestrictions, $parent;
    public function __construct($sendrecvrestrictionsObj, $parent) {
        $this->sendrecvrestrictions = $sendrecvrestrictionsObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        send_recv_restrictions_destroy($this->getSendRecvRestrictionsObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getSendRecvRestrictionsObj() {
        return $this->sendrecvrestrictions;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = send_recv_restrictions_save($this->getSendRecvRestrictionsObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVESENDRECVRESTRICTIONS);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enableSendRestrictions</td>
<td>enable/disable sending restrictions</td>
<tr><td>sendPolicy</td>
<td>values: 1 - accept | 0 - reject</td>
<tr><td>enableRecvRestrictions</td>
<td>enable/disable receiving restrictions</td>
<tr><td>recvPolicy</td>
<td>values: 1 - accept | 0 - reject</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "enablesendrestrictions":
                $resp = send_recv_restrictions_enable_send_restrictions_set($this->getSendRecvRestrictionsObj() , $varValue);
            break;
            case "sendpolicy":
                $resp = send_recv_restrictions_send_policy_set($this->getSendRecvRestrictionsObj() , $varValue);
            break;
            case "enablerecvrestrictions":
                $resp = send_recv_restrictions_enable_recv_restrictions_set($this->getSendRecvRestrictionsObj() , $varValue);
            break;
            case "recvpolicy":
                $resp = send_recv_restrictions_recv_policy_set($this->getSendRecvRestrictionsObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETSENDRECVRESTRICTIONS);
                return false;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETSENDRECVRESTRICTIONS);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>enableSendRestrictions</td>
<td>enable/disable sending restrictions</td>
<tr><td>sendPolicy</td>
<td>values: 1 - accept | 0 - reject</td>
<tr><td>enableRecvRestrictions</td>
<td>enable/disable receiving restrictions</td>
<tr><td>recvPolicy</td>
<td>values: 1 - accept | 0 - reject</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "enablesendrestrictions":
                return send_recv_restrictions_enable_send_restrictions_get($this->getSendRecvRestrictionsObj());
            break;
            case "sendpolicy":
                return send_recv_restrictions_send_policy_get($this->getSendRecvRestrictionsObj());
            break;
            case "enablerecvrestrictions":
                return send_recv_restrictions_enable_recv_restrictions_get($this->getSendRecvRestrictionsObj());
            break;
            case "recvpolicy":
                return send_recv_restrictions_recv_policy_get($this->getSendRecvRestrictionsObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETSENDRECVRESTRICTIONS);
        }
    }
    /**
     * list send policy exceptions
     * @return array
     */
    public function listSendPolicyExceptions() {
        if (!$this) return false;
        $list = array();
        $sendPolicyObj = send_recv_restrictions_send_policy_exception_iterator_begin($this->getSendRecvRestrictionsObj());
        if (!Debug::checkError($sendPolicyObj, "_p_send_recv_restrictions_send_policy_exception_iterator", Debug::INFOERROR, Message::LISTSENDPOLICY)) return false;
        while (send_recv_restrictions_send_policy_exception_iterator_has_value($sendPolicyObj)) {
            $iterObj = send_recv_restrictions_send_policy_exception_iterator_value($sendPolicyObj);
            array_push($list, send_recv_restrictions_send_policy_exception_get_name($iterObj));
            send_recv_restrictions_send_policy_exception_iterator_next($sendPolicyObj);
        }
        send_recv_restrictions_send_policy_exception_iterator_destroy($sendPolicyObj);
        return $list;
    }
    /**
     * list receiving policy exceptions
     * @return array
     */
    public function listRecvPolicyExceptions() {
        if (!$this) return false;
        $list = array();
        $recvPolicyObj = send_recv_restrictions_recv_policy_exception_iterator_begin($this->getSendRecvRestrictionsObj());
        if (!Debug::checkError($recvPolicyObj, "_p_send_recv_restrictions_recv_policy_exception_iterator", Debug::INFOERROR, Message::LISTRECVPOLICY)) return false;
        while (send_recv_restrictions_recv_policy_exception_iterator_has_value($recvPolicyObj)) {
            $iterObj = send_recv_restrictions_recv_policy_exception_iterator_value($recvPolicyObj);
            array_push($list, send_recv_restrictions_recv_policy_exception_get_name($iterObj));
            send_recv_restrictions_recv_policy_exception_iterator_next($recvPolicyObj);
        }
        send_recv_restrictions_recv_policy_exception_iterator_destroy($recvPolicyObj);
        return $list;
    }
    /**
     * adds send policy exceptions
     * @return bool
     * @param $string string the send policy exception string
     */
    public function addSendPolicyException($string) {
        if (!$this) return false;
        if (!is_string($string)) return false;
        $resp = send_recv_restrictions_send_policy_exception_add($this->getSendRecvRestrictionsObj() , $string);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDSENDPOLICYEXCEPTION)) return false;
        return $this->save();
    }
    /**
     * adds receive policy exceptions
     * @return bool
     * @param $string string the receive policy exception string
     */
    public function addRecvPolicyException($string) {
        if (!$this) return false;
        if (!is_string($string)) return false;
        $resp = send_recv_restrictions_recv_policy_exception_add($this->getSendRecvRestrictionsObj() , $string);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDRECVPOLICYEXCEPTION)) return false;
        return $this->save();
    }
    /**
     * removes send policy exceptions
     * @return bool
     * @param $string string the send policy exception string
     */
    public function removeSendPolicyException($string) {
        if (!$this) return false;
        if (!is_string($string)) return false;
        $resp = send_recv_restrictions_send_policy_exception_remove_by_name($this->getSendRecvRestrictionsObj() , $string);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVESENDPOLICYEXCEPTION)) return false;
        return $this->save();
    }
    /**
     * removes receive policy exceptions
     * @return bool
     * @param $string string the receive policy exception string
     */
    public function removeRecvPolicyException($string) {
        if (!$this) return false;
        if (!is_string($string)) return false;
        $resp = send_recv_restrictions_recv_policy_exception_remove_by_name($this->getSendRecvRestrictionsObj() , $string);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVERECVPOLICYEXCEPTION)) return false;
        return $this->save();
    }
}
/** @} */ // end of group
?>
