<?php
/**
 * \ingroup cliobject
 * \defgroup configServer configServer
 * @{
*/
class Server {
    private $server, $parent, $filters, $log, $cli, $rpop, $smtpIn, $smtpOut, $usermap;
    private $processing, $pop3, $imap, $webmail, $webadmin, $ftpBackup, $dnr;
    private $report, $pop3Proxy, $imapProxy, $webmailProxy, $userDb, $permissions, $services;
    private $mobility;
    public function __construct($serverObj, $parentObj) {
        $this->server = $serverObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        server_destroy($this->getServerObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getServerObj() {
        return $this->server;
    }
    public function getServicesObj() {
        if (!is_resource($this->services)) {
            $this->services = server_services_get($this->getServerObj());
            if (!Debug::checkError($this->services, "_p_services", Debug::FATALERROR, Message::GETSERVERSERVICES)) return false;
        }
        return $this->services;
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>primaryDomain</td>
<td>the name of the Axigen primary domain</td>
<tr><td>sslRandomFile</td>
<td>the path to the SSL random file</td>
<tr><td>defaultLanguage</td>
<td>the default language</td>
<tr><td>defaultTimeZone</td>
<td>the default timezone</td>
<tr><td>serverName</td>
<td>the server name</td>
<tr><td>enableIOSynchronization</td>
<td>the enabled/disabled status for I/O Synchronization</td>
<tr><td>enableProcessing</td>
<td>the enabled/disabled status for Processing</td>
<tr><td>enableSmtpIncoming</td>
<td>the enabled/disabled status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enabled/disabled status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enabled/disabled status for POP3</td>
<tr><td>enablePop3Proxy</td>
<td>the enabled/disabled status for Pop3 Proxy</td>
<tr><td>enableRpop</td>
<td>the enabled/disabled status for RPOP</td>
<tr><td>enableImap</td>
<td>the enabled/disabled status for IMAP</td>
<tr><td>enableImapProxy</td>
<td>the enabled/disabled status for IMAP Proxy</td>
<tr><td>enableWebmail</td>
<td>the enabled/disabled status for Webmail</td>
<tr><td>enableWebmailProxy</td>
<td>the enabled/disabled status for Webmail Proxy</td>
<tr><td>enableCli</td>
<td>the enabled/disabled status for CLI</td>
<tr><td>enableLog</td>
<td>the enabled/disabled status for Log</td>
<tr><td>enableReporting</td>
<td>the enabled/disabled status for Reporting</td>
<tr><td>enableFtpBackup</td>
<td>the enabled/disabled status for Ftp Backup</td>
<tr><td>maxIndexingThreads</td>
<td>the maximum number of threads for the search indexing service</td>
</table>
     */
    public function __set($name, $value) {
        if (!$this) return false;
        if (preg_match("/^enable/i", $name)) {
            if (strtolower($value) == "yes") {
                $value = 1;
            } elseif (strtolower($value) == "no") {
                $value = 0;
            } else {
                $value = $value;
            }
        }
        switch (strtolower($name)) {
            case "primarydomain":
                return $this->setPrimaryDomain($value);
            break;
            case "sslrandomfile":
                return $this->setSslRandomFile($value);
            break;
            case "enableiosynchronization":
                return $this->setEnableIOSync($value);
            break;
            case "defaulttimezone":
                return server_default_time_zone_set($this->getServerObj() , $value);
            break;
            case "defaultlanguage":
                return server_default_language_set($this->getServerObj() , $value);
            break;
            case "servername":
                return server_server_name_set($this->getServerObj() , $value);
            break;
            case "maxindexingthreads":
                return server_max_indexing_threads_set($this->getServerObj() , $value);
            break;
            case "enableprocessing":
                $resp = services_processing_set_enable($this->getServicesObj() , $value);
            break;
            case "enablesmtpincoming":
                $resp = services_smtp_incoming_set_enable($this->getServicesObj() , $value);
            break;
            case "enablesmtpoutgoing":
                $resp = services_smtp_outgoing_set_enable($this->getServicesObj() , $value);
            break;
            case "enablepop3":
                $resp = services_pop3_set_enable($this->getServicesObj() , $value);
            break;
            case "enablepop3proxy":
                $resp = services_pop3_proxy_set_enable($this->getServicesObj() , $value);
            break;
            case "enablerpop":
                $resp = services_rpop_set_enable($this->getServicesObj() , $value);
            break;
            case "enableimap":
                $resp = services_imap_set_enable($this->getServicesObj() , $value);
            break;
            case "enableimapproxy":
                $resp = services_imap_proxy_set_enable($this->getServicesObj() , $value);
            break;
            case "enablewebmail":
                $resp = services_webmail_set_enable($this->getServicesObj() , $value);
            break;
            case "enablewebmailproxy":
                $resp = services_webmail_proxy_set_enable($this->getServicesObj() , $value);
            break;
            case "enablecli":
                $resp = services_cli_set_enable($this->getServicesObj() , $value);
            break;
            case "enablelog":
                $resp = services_log_set_enable($this->getServicesObj() , $value);
            break;
            case "enablereporting":
                $resp = services_reporting_set_enable($this->getServicesObj() , $value);
            break;
            case "enableftpbackup":
                $resp = services_ftp_backup_set_enable($this->getServicesObj() , $value);
            break;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETSERVERVARERROR);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>primaryDomain</td>
<td>the name of the Axigen primary domain</td>
<tr><td>sslRandomFile</td>
<td>the path to the SSL random file</td>
<tr><td>defaultLanguage</td>
<td>the default language</td>
<tr><td>defaultTimeZone</td>
<td>the default timezone</td>
<tr><td>serverName</td>
<td>the server name</td>
<tr><td>enableIOSynchronization</td>
<td>the enabled/disabled status for I/O Synchronization</td>
<tr><td>enableProcessing</td>
<td>the enabled/disabled status for Processing</td>
<tr><td>enableSmtpIncoming</td>
<td>the enabled/disabled status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enabled/disabled status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enabled/disabled status for POP3</td>
<tr><td>enablePop3Proxy</td>
<td>the enabled/disabled status for Pop3 Proxy</td>
<tr><td>enableRpop</td>
<td>the enabled/disabled status for RPOP</td>
<tr><td>enableImap</td>
<td>the enabled/disabled status for IMAP</td>
<tr><td>enableImapProxy</td>
<td>the enabled/disabled status for IMAP Proxy</td>
<tr><td>enableWebmail</td>
<td>the enabled/disabled status for Webmail</td>
<tr><td>enableWebmailProxy</td>
<td>the enabled/disabled status for Webmail Proxy</td>
<tr><td>enableCli</td>
<td>the enabled/disabled status for CLI</td>
<tr><td>enableLog</td>
<td>the enabled/disabled status for Log</td>
<tr><td>enableReporting</td>
<td>the enabled/disabled status for Reporting</td>
<tr><td>enableFtpBackup</td>
<td>the enabled/disabled status for Ftp Backup</td>
<tr><td>maxIndexingThreads</td>
<td>the maximum number of threads for the search indexing service</td>
</table>
     */
    public function __get($name) {
        if (!$this) return false;
        switch (strtolower($name)) {
            case "primarydomain":
                return $this->getPrimaryDomain();
            break;
            case "sslrandomfile":
                return $this->getSslRandomFile();
            break;
            case "enableiosynchronization":
                return $this->getEnableIOSync();
            break;
            case "defaultlanguage":
                return server_default_language_get($this->getServerObj());
            break;
            case "defaulttimezone":
                return server_default_time_zone_get($this->getServerObj());
            break;
            case "servername":
                return server_server_name_get($this->getServerObj());
            break;
            case "maxindexingthreads":
                return server_max_indexing_threads_get($this->getServerObj());
            break;
            case "processingisenabled":
                return services_processing_is_enable($this->getServicesObj());
            break;
            case "smtpincomingisenabled":
                return services_smtp_incoming_is_enable($this->getServicesObj());
            break;
            case "smtpoutgoingisenabled":
                return services_smtp_outgoing_is_enable($this->getServicesObj());
            break;
            case "pop3isenabled":
                return services_pop3_is_enable($this->getServicesObj());
            break;
            case "pop3proxyisenabled":
                return services_pop3_proxy_is_enable($this->getServicesObj());
            break;
            case "rpopisenabled":
                return services_rpop_is_enable($this->getServicesObj());
            break;
            case "imapisenabled":
                return services_imap_is_enable($this->getServicesObj());
            break;
            case "imapproxyisenabled":
                return services_imap_proxy_is_enable($this->getServicesObj());
            break;
            case "webmailisenabled":
                return services_webmail_is_enable($this->getServicesObj());
            break;
            case "webmailproxyisenabled":
                return services_webmail_proxy_is_enable($this->getServicesObj());
            break;
            case "cliisenabled":
                return services_cli_is_enable($this->getServicesObj());
            break;
            case "logisenabled":
                return services_log_is_enable($this->getServicesObj());
            break;
            case "reportingisenabled":
                return services_reporting_is_enable($this->getServicesObj());
            break;
            case "ftpbackupisenabled":
                return services_ftp_backup_is_enable($this->getServicesObj());
            break;
        }
    }
    /**
     * returns an array with all the services and their status
     * @return array
     */
    public function services() {
        $services = array();
        $services['ftpBackup'] = $this->ftpBackupIsEnabled ? true : false;
        $services['processing'] = $this->processingIsEnabled ? true : false;
        $services['smtpIncoming'] = $this->smtpIncomingIsEnabled ? true : false;
        $services['smtpOutgoing'] = $this->smtpOutgoingIsEnabled ? true : false;
        $services['pop3'] = $this->pop3IsEnabled ? true : false;
        $services['pop3Proxy'] = $this->pop3ProxyIsEnabled ? true : false;
        $services['rpop'] = $this->rpopIsEnabled ? true : false;
        $services['imap'] = $this->imapIsEnabled ? true : false;
        $services['imapProxy'] = $this->imapProxyIsEnabled ? true : false;
        $services['webmail'] = $this->webmailIsEnabled ? true : false;
        $services['webmailProxy'] = $this->webmailProxyIsEnabled ? true : false;
        $services['cli'] = $this->cliIsEnabled ? true : false;
        $services['log'] = $this->logIsEnabled ? true : false;
        $services['reporting'] = $this->reportingIsEnabled ? true : false;
        return $services;
    }
    /**
     * starts an Axigen service
     * @return bool
     * @param $serviceName string the name of the service that you want to start
     */
    public function startService($serviceName) {
        if (!$this) return false;
        if (!is_string($serviceName)) return false;
        switch (strtolower($serviceName)) {
            case "cli":
                $resp = server_start_cli_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CLISTART);
            break;
            case "imap":
                $resp = server_start_imap_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::IMAPSTART);
            break;
            case "pop3":
                $resp = server_start_pop3_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::POP3START);
            break;
            case "rpop":
                $resp = server_start_rpop_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::RPOPSTART);
            break;
            case "smtpout":
                $resp = server_start_smtp_outgoing_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SMTPOUTSTART);
            break;
            case "log":
                $resp = server_start_log_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOGSTART);
            break;
            case "smtpin":
                $resp = server_start_smtp_in_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SMTPINSTART);
            break;
            case "processing":
                $resp = server_start_processing_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PROCESSINGSTART);
            break;
            case "webmail":
                $resp = server_start_webmail_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBMAILSTART);
            break;
            case "webadmin":
                $resp = server_start_webadmin_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBADMINSTART);
            break;
            case "ftpbackup":
                $resp = server_start_ftp_backup_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FTPSTART);
            break;
            case "report":
                $resp = server_start_report_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REPORTSTART);
            break;
            case "pop3proxy":
                $resp = server_start_pop3_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::POP3PROXYSTART);
            break;
            case "imapproxy":
                $resp = server_start_imap_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::IMAPPROXYSTART);
            break;
            case "webmailproxy":
                $resp = server_start_webmail_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WMPROXYSTART);
            break;
            default:
                return Debug::checkError(1, 0, Debug::INFOERROR, Message::UNKNOWNSERVICE);
        }
    }
    /**
     * stops an Axigen service
     * @return bool
     * @param $serviceName string the name of the service that you want to stop
     */
    public function stopService($serviceName) {
        if (!$this) return false;
        if (!is_string($serviceName)) return false;
        switch (strtolower($serviceName)) {
            case "cli":
                $resp = server_stop_cli_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CLISTOP);
            break;
            case "imap":
                $resp = server_stop_imap_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::IMAPSTOP);
            break;
            case "pop3":
                $resp = server_stop_pop3_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::POP3STOP);
            break;
            case "rpop":
                $resp = server_stop_rpop_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::RPOPSTOP);
            break;
            case "smtpout":
                $resp = server_stop_smtp_outgoing_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SMTPOUTSTOP);
            break;
            case "log":
                $resp = server_stop_log_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOGSTOP);
            break;
            case "smtpin":
                $resp = server_stop_smtp_in_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SMTPINSTOP);
            break;
            case "processing":
                $resp = server_stop_processing_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PROCESSINGSTOP);
            break;
            case "webmail":
                $resp = server_stop_webmail_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBMAILSTOP);
            break;
            case "webadmin":
                $resp = server_stop_webadmin_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBADMINSTOP);
            break;
            case "ftpbackup":
                $resp = server_stop_ftp_backup_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::FTPSTOP);
            break;
            case "report":
                $resp = server_stop_report_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REPORTSTOP);
            break;
            case "pop3proxy":
                $resp = server_stop_pop3_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::POP3PROXYSTOP);
            break;
            case "imapproxy":
                $resp = server_stop_imap_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::IMAPPROXYSTOP);
            break;
            case "webmailproxy":
                $resp = server_stop_webmail_proxy_service($this->getServerObj() , $this->getSessionObj());
                return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WMPROXYSTOP);
            break;
            default:
                return Debug::checkError(1, 0, Debug::INFOERROR, Message::UNKNOWNSERVICE);
        }
    }
    /**
     * this method returns an object of Filters for the selected server
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = server_filters_get($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADSERVERFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * this method returns an object of Log for the selected server
     * @return object Log
     */
    public function configLog() {
        if (!$this) return false;
        if (!is_object($this->log)) {
            $logObj = server_config_log($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($logObj, "_p_log", Debug::FATALERROR, Message::LOADSERVERLOG)) return false;
            $this->log = new Log($logObj, $this);
        }
        return $this->log;
    }
    /**
     * this method returns an object of CLI for the selected server
     * @return object Cli
     */
    public function configCli() {
        if (!$this) return false;
        if (!is_object($this->cli)) {
            $cliObj = server_config_cli($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($cliObj, "_p_cli", Debug::FATALERROR, Message::LOADSERVERCLI)) return false;
            $this->cli = new Cli($cliObj, $this);
        }
        return $this->cli;
    }
    /**
     * this method returns an object of RPOP for the selected server
     * @return object Rpop
     */
    public function configRpop() {
        if (!$this) return false;
        if (!is_object($this->rpop)) {
            $rpopObj = server_config_rpop($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($rpopObj, "_p_rpop", Debug::FATALERROR, Message::LOADSERVERRPOP)) return false;
            $this->rpop = new Rpop($rpopObj, $this);
        }
        return $this->rpop;
    }
    /**
     * this method returns an object of SmtpIn for the selected server
     * @return object SmtpIn
     */
    public function configSmtpIn() {
        if (!$this) return false;
        if (!is_object($this->smtpIn)) {
            $smtpInObj = server_config_smtp_in($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($smtpInObj, "_p_smtp_in", Debug::FATALERROR, Message::LOADSERVERSMTPIN)) return false;
            $this->smtpIn = new SmtpIn($smtpInObj, $this);
        }
        return $this->smtpIn;
    }
    /**
     * this method returns an object of SmtpOut for the selected server
     * @return object SmtpOut
     */
    public function configSmtpOut() {
        if (!$this) return false;
        if (!is_object($this->smtpOut)) {
            $smtpOutObj = server_config_smtp_outgoing($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($smtpOutObj, "_p_smtp_out", Debug::FATALERROR, Message::LOADSERVERSMTPOUT)) return false;
            $this->smtpOut = new SmtpOut($smtpOutObj, $this);
        }
        return $this->smtpOut;
    }
    /**
     * this method returns an object of Processing for the selected server
     * @return object Processing
     */
    public function configProcessing() {
        if (!$this) return false;
        if (!is_object($this->processing)) {
            $processingObj = server_config_processing($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($processingObj, "_p_processing", Debug::FATALERROR, Message::LOADSERVERPROCESSING)) return false;
            $this->processing = new Processing($processingObj, $this);
        }
        return $this->processing;
    }
    /**
     * this method returns an object of POP3 for the selected server
     * @return object Pop3
     */
    public function configPop3() {
        if (!$this) return false;
        if (!is_object($this->pop3)) {
            $pop3Obj = server_config_pop3($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($pop3Obj, "_p_pop3", Debug::FATALERROR, Message::LOADSERVERPOP3)) return false;
            $this->pop3 = new Pop3($pop3Obj, $this);
        }
        return $this->pop3;
    }
    /**
     * this method returns an object of IMAP for the selected server
     * @return object Imap
     */
    public function configImap() {
        if (!$this) return false;
        if (!is_object($this->imap)) {
            $imapObj = server_config_imap($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($imapObj, "_p_imap", Debug::FATALERROR, Message::LOADSERVERIMAP)) return false;
            $this->imap = new Imap($imapObj, $this);
        }
        return $this->imap;
    }
    /**
     * this method returns an object of Webmail for the selected server
     * @return object Webmail
     */
    public function configWebmail() {
        if (!$this) return false;
        if (!is_object($this->webmail)) {
            $webmailObj = server_config_webmail($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($webmailObj, "_p_webmail", Debug::FATALERROR, Message::LOADSERVERWEBMAIL)) return false;
            $this->webmail = new Webmail($webmailObj, $this);
        }
        return $this->webmail;
    }
    /**
     * this method returns an object of Webadmin for the selected server
     * @return object Webadmin
     */
    public function configWebadmin() {
        if (!$this) return false;
        if (!is_object($this->webadmin)) {
            $webadminObj = server_config_webadmin($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($webadminObj, "_p_webadmin", Debug::FATALERROR, Message::LOADSERVERWEBADMIN)) return false;
            $this->webadmin = new Webadmin($webadminObj, $this);
        }
        return $this->webadmin;
    }
    /**
     * this method returns an object of FtpBackup for the selected server
     * @return object FtpBackup
     */
    public function configFtpBackup() {
        if (!$this) return false;
        if (!is_object($this->ftpBackup)) {
            $ftpBackupObj = server_config_ftp_backup($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($ftpBackupObj, "_p_ftp_backup", Debug::FATALERROR, Message::LOADSERVERFTPBACKUP)) return false;
            $this->ftpBackup = new FtpBackup($ftpBackupObj, $this);
        }
        return $this->ftpBackup;
    }
    /**
     * this method returns an object of DNR for the selected server
     * @return object Dnr
     */
    public function configDnr() {
        if (!$this) return false;
        if (!is_object($this->dnr)) {
            $dnrObj = server_config_dnr($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($dnrObj, "_p_dnr", Debug::FATALERROR, Message::LOADSERVERDNR)) return false;
            $this->dnr = new Dnr($dnrObj, $this);
        }
        return $this->dnr;
    }
    /**
     * this method returns an object of Report for the selected server
     * @return object Report
     */
    public function configReport() {
        if (!$this) return false;
        if (!is_object($this->report)) {
            $reportObj = server_config_report($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($reportObj, "_p_report", Debug::FATALERROR, Message::LOADSERVERREPORT)) return false;
            $this->report = new Report($reportObj, $this);
        }
        return $this->report;
    }
    /**
     * this method returns an object of Pop3Proxy for the selected server
     * @return object Pop3Proxy
     */
    public function configPop3Proxy() {
        if (!$this) return false;
        if (!is_object($this->pop3Proxy)) {
            $pop3ProxyObj = server_config_pop3_proxy($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($pop3ProxyObj, "_p_proxy", Debug::FATALERROR, Message::LOADSERVERPOP3PROXY)) return false;
            $this->pop3Proxy = new Pop3Proxy($pop3ProxyObj, $this);
        }
        return $this->pop3Proxy;
    }
    /**
     * this method returns an object of ImapProxy for the selected server
     * @return object ImapProxy
     */
    public function configImapProxy() {
        if (!$this) return false;
        if (!is_object($this->imapProxy)) {
            $imapProxyObj = server_config_imap_proxy($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($imapProxyObj, "_p_proxy", Debug::FATALERROR, Message::LOADSERVERIMAPPROXY)) return false;
            $this->imapProxy = new ImapProxy($imapProxyObj, $this);
        }
        return $this->imapProxy;
    }
    /**
     * this method returns an object of UserDb for the selected server
     * @return object UserDb
     */
    public function configUserDb() {
        if (!$this) return false;
        if (!is_object($this->userDb)) {
            $userDbObj = server_config_userdb($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($userDbObj, "_p_userdb", Debug::FATALERROR, Message::LOADSERVERUSERDB)) return false;
            $this->userDb = new UserDb($userDbObj, $this);
        }
        return $this->userDb;
    }
    /**
     * this method returns an object of WebmailProxy for the selected server
     * @return object WebmailProxy
     */
    public function configWebmailProxy() {
        if (!$this) return false;
        if (!is_object($this->webmailProxy)) {
            $webmailProxyObj = server_config_webmail_proxy($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($webmailProxyObj, "_p_webmail_proxy", Debug::FATALERROR, Message::LOADSERVERWEBMAILPROXY)) return false;
            $this->webmailProxy = new WebmailProxy($webmailProxyObj, $this);
        }
        return $this->webmailProxy;
    }
    /**
     * this method returns an object of Mobility for the selected server
     * @return object Mobility
     */
    public function configMobility() {
        if (!$this) return false;
        if (!is_object($this->mobility)) {
            $mobilityObj = server_config_mobility($this->getServerObj() , $this->getSessionObj());
            if (!Debug::checkError($mobilityObj, "_p_mobility", Debug::FATALERROR, Message::LOADSERVERMOBILITY)) return false;
            $this->mobility = new Mobility($mobilityObj, $this);
        }
        return $this->mobility;
    }
    /*******************************************************************************
    * Usermap
    */
    /**
     * This method is used at adding a usermap
     *
     * @param $name string name of a usermap
     * @param $type string type of a usermap
     * @param $userdbConnectorType string userdb connector type
     * @param $userdbConnectorName string userdb connector name
     * @param $localFile string usermap local file
     * @return bool
     */
    public function addUsermap($name, $type = 'local', $userdbConnectorType = null, $userdbConnectorName = null, $localFile = null) {
        $usermapObj = usermap_add($this->getServerObj() , $this->getSessionObj() , $name);
        if (!Debug::checkError($usermapObj, "_p_usermap", Debug::INFOERROR, Message::ADDSERVERUSERMAP)) return false;
        if ('ldap' == $type) {
            $setType = usermap_type_set($usermapObj, $type);
            if (!Debug::checkError($setType, 0, Debug::INFOERROR, Message::ADDSERVERUSERMAPTYPE)) return false;
        }
        if (!is_null($userdbConnectorType)) {
            $setConnType = usermap_userdb_connector_type_set($usermapObj, $userdbConnectorType);
            if (!Debug::checkError($setConnType, 0, Debug::INFOERROR, Message::ADDSERVERUSERMAPCONNTYPE)) return false;
        }
        if (!is_null($userdbConnectorName)) {
            $setConnName = usermap_userdb_connector_name_set($usermapObj, $userdbConnectorName);
            if (!Debug::checkError($setConnName, 0, Debug::INFOERROR, Message::ADDSERVERUSERMAPCONNNAME)) return false;
        }
        if (!is_null($localFile)) {
            $setLocalFile = usermap_localFile_set($usermapObj, $localFile);
            if (!Debug::checkError($setLocalFile, 0, Debug::INFOERROR, Message::ADDSERVERUSERMAPLOCALFILE)) return false;
        }
        $serverSave = server_save($this->getServerObj() , $this->getSessionObj());
        return Debug::checkError($serverSave, 0, Debug::INFOERROR, Message::ADDSERVERUSERMAP);
    }
    /**
     * this method returns an array with the usermaps list
     *
     * @return array
     */
    public function listUsermaps() {
        if (!$this) return false;
        $usermaps = array();
        $usermapsObj = usermaps_load($this->getServerObj() , $this->getSessionObj());
        if (!Debug::checkError($usermapsObj, "_p_account_list", Debug::INFOERROR, Message::SERVERUSERMAPLOAD)) return false;
        $usermapsIterObj = usermap_iterator_begin($this->getServerObj());
        if (!Debug::checkError($usermapsIterObj, "_p_usermap_iterator", Debug::INFOERROR, Message::SERVERUSERMAPLIST)) return false;
        $usermapTmp = array();
        while (usermap_iterator_has_value($usermapsIterObj)) {
            $usermapObj = new Usermap(usermap_iterator_value($usermapsIterObj) , $this);
            $usermapTmp['name'] = $usermapObj->name;
            $usermapTmp['type'] = $usermapObj->type;
            $usermapTmp['userdbConnectorType'] = $usermapObj->userdbConnectorType;
            $usermapTmp['userdbConnectorName'] = $usermapObj->userdbConnectorName;
            $usermapTmp['usermapLocalFile'] = $usermapObj->usermapLocalFile;
            array_push($usermaps, $usermapTmp);
            usermap_iterator_next($usermapsIterObj);
        }
        usermap_iterator_destroy($usermapsIterObj);
        return $usermaps;
    }
    /**
     * This method removes a usermap by name
     *
     * @param $name string the name of the usermap that is removed
     *
     * @return bool
     */
    public function removeUsermap($name) {
        $removeUsermap = usermap_remove_by_name($name, $this->getServerObj() , $this->getSessionObj());
        if (Debug::checkError($removeUsermap, 0, Debug::INFOERROR, Message::REMOVESERVERUSERMAP)) {
            $serverSave = server_save($this->getServerObj() , $this->getSessionObj());
            return Debug::checkError($serverSave, 0, Debug::INFOERROR, Message::REMOVESERVERUSERMAP);
        }
        return false;
    }
    /**
     * This method returns an object of usermap type
     *
     * @param $name string the name of the usermap that will be loaded
     * @return object Usermap
     */
    public function updateUsermap($name) {
        if (!$this) return false;
        if (!is_object($this->usermap)) {
            $usermapObj = usermap_get_by_name($this->getServerObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($usermapObj, '_p_usermap', Debug::FATALERROR, Message::UPDATESERVERUSERMAP)) return false;
            $this->usermap = new Usermap($usermapObj, $this);
        }
        return $this->usermap;
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * this method gets the name of the primary domain in the Axigen server
     *
     * @return bool
     */
    public function getPrimaryDomain() {
        return server_primary_domain_get($this->getServerObj());
    }
    /**
     * @ignore
     * gets the name of the SSL random file
     *
     * @return String
     */
    public function getSslRandomFile() {
        return server_ssl_random_file_get($this->getServerObj());
    }
    /**
     * @ignore
     * returns true if disk I/O Synchronization is enabled, false otherwise
     *
     * @return bool
     */
    public function getEnableIOSync() {
        $enableIO = server_enableIOSync_get($this->getServerObj());
        switch ($enableIO) {
            case 1:
                Debug::checkError($enableIO, 1, Debug::INFOERROR, Message::GETENABLEIOSYNC);
                return true;
            break;
            case 0:
                Debug::checkError($enableIO, 0, Debug::INFOERROR, Message::GETENABLEIOSYNC);
                return false;
            break;
            default:
                return false;
            break;
        }
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * this method sets the name of the Axigen primary domain
     *
     * @param $name string domain name
     * @return bool
     */
    public function setPrimaryDomain($name) {
        $set = server_primary_domain_set($this->getServerObj() , $name);
        if (!Debug::checkError($set, 0, Debug::INFOERROR, Message::SETPRIMARYDOMAIN)) {
            return false;
        }
    }
    /**
     * @ignore
     * this method sets the path to the SSL random file
     *
     * @param $file string the random file used by SSL
     *
     * @return bool
     */
    public function setSslRandomFile($file) {
        $set = server_ssl_random_file_set($this->getServerObj() , $file);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SETSSLRANDOMFILE);
    }
    /**
     * @ignore
     * this enables/disables I/O Synchronization. If enabled, the server disables it
     * not cache buffers in memory, but instead writes the received data to the
     * disk every time. This can result in performance degradation
     *
     * @param $enable int If the $enable value is 1, it enables I/O Synchronization and disables it otherwise
     *
     * @return bool
     */
    public function setEnableIOSync($enable) {
        $enableIO = server_enableIOSync_set($this->getServerObj() , $enable);
        return Debug::checkError($enableIO, 0, Debug::INFOERROR, Message::ENABLEIOSYNC);
    }
    /**
     * This function saves a server object back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = server_save($this->getServerObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::SERVERSAVE);
    }
}
/** @} */ // end of group
?>
