<?php
/**
 * \ingroup configServer
 * \defgroup configSmtpOut configSmtpOut
 * @{
*/
class SmtpOut {
    private $smtpOutObj, $parent;
    public function __construct($smtpOutObj, $parent) {
        $this->smtpOutObj = $smtpOutObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        smtp_out_destroy($this->getSmtpOutObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getSmtpOutObj() {
        return $this->smtpOutObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the SMTP Outgoing service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the SMTP Outgoing service</td>
<tr><td>logLevel</td>
<td>the log level for the SMTP Outgoing service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the SMTP Outgoing service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the SMTP Outgoing service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the SMTP Outgoing service</td>
<tr><td>logLevel</td>
<td>the log level for the SMTP Outgoing service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the SMTP Outgoing service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return smtp_out_max_connection_threads_get($this->getSmtpOutObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return smtp_out_min_connection_threads_get($this->getSmtpOutObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return smtp_out_log_level_get($this->getSmtpOutObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return smtp_out_log_host_get($this->getSmtpOutObj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return smtp_out_log_type_get($this->getSmtpOutObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = smtp_out_max_connection_threads_set($this->getSmtpOutObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SMTPOUTSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = smtp_out_min_connection_threads_set($this->getSmtpOutObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SMTPOUTSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = smtp_out_log_level_set($this->getSmtpOutObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SMTPOUTSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = smtp_out_log_host_set($this->getSmtpOutObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SMTPOUTSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = smtp_out_log_type_set($this->getSmtpOutObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::SMTPOUTSETLOGTYPE);
    }
    /**
     * @private
     * This function saves the SMTP Outgoing configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = smtp_out_save($this->getSmtpOutObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::SMTPOUTSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = smtp_out_reset($this->getSmtpOutObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::SMTPOUTRESET);
    }
    /**
     * This function starts the SMTP Outgoing service
     *
     * @return bool
     */
    public function start() {
        return $this->parent->startService("smtpout");
    }
    /**
     * This function stops the SMTP Outgoing service
     *
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("smtpout");
    }
}
/** @} */ // end of group
?>
