<?php
/**
 * \ingroup configFilters
 * \defgroup listSocketFilters listSocketFilters
 * @{
 * This is the object containing the socketfilter data for the selected filter
 * @note
 */
class SocketFilters {
    private $socketfilter, $parent;
    public function __construct($socketfilterObj, $parentObj) {
        $this->socketfilter = $socketfilterObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        //filters_d($this->getActiveFilterObj());
        
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getSocketFilterObj() {
        return $this->socketfilter;
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = filters_save($this->parent->getFiltersObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVESOCKETFILTERDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>sets the name of the filter</td>
<tr><td>address</td>
<td>sets the address of the filter, used to communicate with the filter</td>
<tr><td>protocolFile</td>
<td>sets the path to the ASFL file that describes the communication protocol</td>
<tr><td>actionOnMatch</td>
<td>sets the action to be taken in case the filter matches an email</td>
<tr><td>maxConnections</td>
<td>sets the maximum number of connections that will be made to the filter</td>
<tr><td>idleTimeout</td>
<td>sets the inactivity timeout of the connection (in seconds)</td>
<tr><td>maxMessageSize</td>
<td>the max message size</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = socket_filter_name_set($this->getSocketFilterObj() , $varValue);
            break;
            case "address":
                $resp = socket_filter_address_set($this->getSocketFilterObj() , $varValue);
            break;
            case "protocolfile":
                $resp = socket_filter_protocol_file_set($this->getSocketFilterObj() , $varValue);
            break;
            case "actiononmatch":
                $resp = socket_filter_action_on_match_set($this->getSocketFilterObj() , $varValue);
            break;
            case "maxconnections":
                $resp = socket_filter_max_connections_set($this->getSocketFilterObj() , $varValue);
            break;
            case "idletimeout":
                $resp = socket_filter_idle_timeout_set($this->getSocketFilterObj() , $varValue);
            break;
            case "maxmessagesize":
                $resp = socket_filter_max_message_size_set($this->getSocketFilterObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETSOCKETFILTERVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETSOCKETFILTERVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>sets the name of the filter</td>
<tr><td>address</td>
<td>sets the address of the filter, used to communicate with the filter</td>
<tr><td>protocolFile</td>
<td>sets the path to the ASFL file that describes the communication protocol</td>
<tr><td>actionOnMatch</td>
<td>sets the action to be taken in case the filter matches an email</td>
<tr><td>maxConnections</td>
<td>sets the maximum number of connections that will be made to the filter</td>
<tr><td>idleTimeout</td>
<td>sets the inactivity timeout of the connection (in seconds)</td>
<tr><td>maxMessageSize</td>
<td>the max message size</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return socket_filter_name_get($this->getSocketFilterObj());
            break;
            case "address":
                return socket_filter_address_get($this->getSocketFilterObj());
            break;
            case "protocolfile":
                return socket_filter_protocol_file_get($this->getSocketFilterObj());
            break;
            case "actiononmatch":
                return socket_filter_action_on_match_get($this->getSocketFilterObj());
            break;
            case "maxconnections":
                return socket_filter_max_connections_get($this->getSocketFilterObj());
            break;
            case "idletimeout":
                return socket_filter_idle_timeout_get($this->getSocketFilterObj());
            break;
            case "maxmessagesize":
                return socket_filter_max_message_size_get($this->getSocketFilterObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETSOCKETFILTERVARERROR);
        }
    }
}
/** @} */ // end of group
?>
