<?php
/**
 * \ingroup updateListener
 * \defgroup configSslControl configSslControl
 * @{
*/
class SslControl {
    private $sslcontrol, $parent;
    public function __construct($sslcontrolObj, $parent) {
        $this->sslcontrol = $sslcontrolObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        ssl_control_destroy($this->getSslControlObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getSslControlObj() {
        return $this->sslcontrol;
    }
    /**
     * saves member changes
     * @return bool
     */
    public function save() {
        $resp = ssl_control_save($this->getSslControlObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVESSLCONTROL);
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>allowedVersions</td>
<td>the allowed SSL versions</td>
<tr><td>maxChainDepth</td>
<td>maximum depth of verification</td>
<tr><td>cipherSuite</td>
<td>the cipher suite to be used</td>
<tr><td>useEphemeralKey</td>
<td>use/not use ephemeral keys</td>
<tr><td>certFile</td>
<td>path for certification chain file</td>
<tr><td>caFile</td>
<td>path for Certificate Authority file</td>
<tr><td>dhParamFile</td>
<td>path to Diffie-Hellman parameter file</td>
<tr><td>requestClientAuth</td>
<td>request/not request client authentication</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "allowedversions":
                $resp = ssl_control_allowed_versions_set($this->getSslControlObj() , $varValue);
            break;
            case "maxchaindepth":
                $resp = ssl_control_max_chain_depth_set($this->getSslControlObj() , $varValue);
            break;
            case "ciphersuite":
                $resp = ssl_control_cipher_suite_set($this->getSslControlObj() , $varValue);
            break;
            case "useephemeralkey":
                $resp = ssl_control_use_ephemeral_key_set($this->getSslControlObj() , $varValue);
            break;
            case "certfile":
                $resp = ssl_control_cert_file_set($this->getSslControlObj() , $varValue);
            break;
            case "cafile":
                $resp = ssl_control_ca_file_set($this->getSslControlObj() , $varValue);
            break;
            case "dhparamfile":
                $resp = ssl_control_dh_param_file_set($this->getSslControlObj() , $varValue);
            break;
            case "requestclientauth":
                $resp = ssl_control_request_client_auth_set($this->getSslControlObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETSSLCONTROL);
                return false;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETSSLCONTROL);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>allowedVersions</td>
<td>the allowed SSL versions</td>
<tr><td>maxChainDepth</td>
<td>maximum depth of verification</td>
<tr><td>cipherSuite</td>
<td>the cipher suite to be used</td>
<tr><td>useEphemeralKey</td>
<td>use/not use ephemeral keys</td>
<tr><td>certFile</td>
<td>path for certification chain file</td>
<tr><td>caFile</td>
<td>path for Certificate Authority file</td>
<tr><td>dhParamFile</td>
<td>path to Diffie-Hellman parameter file</td>
<tr><td>requestClientAuth</td>
<td>request/not request client authentication</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "allowedversions":
                return ssl_control_allowed_versions_get($this->getSslControlObj());
            break;
            case "maxchaindepth":
                return ssl_control_max_chain_depth_get($this->getSslControlObj());
            break;
            case "ciphersuite":
                return ssl_control_cipher_suite_get($this->getSslControlObj());
            break;
            case "useephemeralkey":
                return ssl_control_use_ephemeral_key_get($this->getSslControlObj());
            break;
            case "certfile":
                return ssl_control_cert_file_get($this->getSslControlObj());
            break;
            case "cafile":
                return ssl_control_ca_file_get($this->getSslControlObj());
            break;
            case "dhparamfile":
                return ssl_control_dh_param_file_get($this->getSslControlObj());
            break;
            case "requestclientauth":
                return ssl_control_request_client_auth_get($this->getSslControlObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETALLOWRULE);
        }
    }
}
/** @} */ // end of group
?>
