<?php
/**
 * \ingroup configServer
 * \defgroup configUserDb configUserDb
 * @{
*/
class UserDb {
    private $userDbObj, $parent, $ldapObj, $ldapconnector;
    public function __construct($userDbObj, $parent) {
        $this->userDbObj = $userDbObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        userdb_destroy($this->getuserDbObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getUserDbObj() {
        return $this->userDbObj;
    }
    public function getLdapConnectors() {
        if (!$this) return false;
        if (!is_resource($this->ldapObj)) {
            $this->ldapObj = userdb_ldap_connectors_get($this->getUserDbObj() , $this->getSessionObj());
            if (!Debug::checkError($this->ldapObj, "_p_ldap_connectors", Debug::FATALERROR, Message::GETUSERDBLDAPCONNECTORS)) return false;
        }
        return $this->ldapObj;
    }
    /**
     * lists the Ldap connectors
     * @return array
     */
    public function listLdapConnectors() {
        if (!$this) return false;
        $ldap = array();
        $ldapIterObj = ldap_connector_iterator_begin($this->getLdapConnectors());
        if (!Debug::checkError($ldapIterObj, "_p_ldap_connector_iterator", Debug::INFOERROR, Message::LISTUSERDBLDAPCONNECTORS)) return false;
        while (ldap_connector_iterator_has_value($ldapIterObj)) {
            $ldapObj = ldap_connector_iterator_value($ldapIterObj);
            array_push($ldap, ldap_connector_name_get($ldapObj));
            ldap_connector_iterator_next($ldapIterObj);
        }
        ldap_connector_iterator_destroy($ldapIterObj);
        return $ldap;
    }
    /**
     * adds a new Ldap connector
     * @return bool
     * @param $name string the name of the Ldap connector
     * @param $hostUrl string the Ldap Host URL
     */
    public function addLdapConnector($name, $hostUrl) {
        if (!$this) return false;
        $resp = ldap_connectors_add($this->getLdapConnectors() , $this->getSessionObj() , $name, $hostUrl);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDUSERDBLDAPCONNECTOR);
    }
    /**
     * removes a Ldap connector
     * @return bool
     * @param $name string the name of the Ldap connector
     */
    public function removeLdapConnector($name) {
        if (!$this) return false;
        $resp = ldap_connectors_remove_by_name($this->getLdapConnectors() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEUSERDBLDAPCONNECTOR);
    }
    /**
     * updates a Ldap connector
     * @return object LdapConnector
     * @param $name string the name of the Ldap connector
     */
    public function updateLdapConnector($name) {
        if (!$this) return false;
        if (!is_object($this->ldapconnetor[$name])) {
            $ldapObj = ldap_connectors_get_by_name($this->getLdapConnectors() , $name);
            if (!Debug::checkError($ldapObj, "_p_ldap_connector", Debug::FATALERROR, Message::UPDATEUSERDBLDAPCONNECTOR)) return false;
            $this->ldapconnector[$name] = new LdapConnector($ldapObj, $this);
        }
        return $this->ldapconnector[$name];
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = userdb_save($this->getUserDbObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEUSERDBDATA);
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxThreads</td>
<td>the maximum number of threads</td>
<tr><td>logLevel</td>
<td>the log level</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'maxThreads':
                return $this->getMaxThreads();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxThreads</td>
<td>the maximum number of threads</td>
<tr><td>logLevel</td>
<td>the log level</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxThreads':
                return $this->setMaxThreads($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads used by this service
     *
     * @return int
     */
    public function getMaxThreads() {
        return userdb_max_threads_get($this->getUserDbObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return userdb_log_level_get($this->getUserDbObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return userdb_log_host_get($this->getUserDbObj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return userdb_log_type_get($this->getUserDbObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads
     * @return bool
     *
     * @param $value int the maximum number of threads
     */
    public function setMaxThreads($value) {
        $set = userdb_max_threads_set($this->getUserDbObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::USERDBSETMAXTHREADS);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = userdb_log_level_set($this->getUserDbObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::USERDBSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = userdb_log_host_set($this->getUserDbObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::USERDBSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = userdb_log_type_set($this->getUserDbObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::USERDBSETLOGTYPE);
    }
}
/** @} */ // end of group
?>
