<?php
/**
 * \ingroup configServer
 * \defgroup configWebadmin configWebadmin
 * @{
*/
class Webadmin {
    private $waObj, $parent, $listener, $accesscontrol;
    public function __construct($waObj, $parent) {
        $this->waObj = $waObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        webadmin_destroy($this->getWebadminObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getWebadminObj() {
        return $this->waObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webadmin service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>sessionIdleTimeout</td>
<td>the time interval after which an idle session is terminated</td>
<tr><td>sessionActivityTimeout</td>
<td>the maximum time interval after which a Webadmin session is terminated even if activity exists</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>allowLargeIncomingData</td>
<td>the data receiving to be allowed after the session is terminated</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>path</td>
<td>the Webadmin's directory path</td>
<tr><td>logLevel</td>
<td>the log level for the Webadmin service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webadmin service</td>
</table>
     */
    public function __get($name) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->getMaxConnThreads();
            break;
            case 'minConnThreads':
                return $this->getMinConnThreads();
            break;
            case 'maxErrors':
                return $this->getMaxErrors();
            break;
            case 'maxAuthErrors':
                return $this->getMaxAuthErrors();
            break;
            case 'sessionIdleTimeout':
                return $this->getSessionIdleTimeout();
            break;
            case 'sessionActivityTimeout':
                return $this->getSessionActivityTimeout();
            break;
            case 'allowKeepAlive':
                return $this->getAllowKeepAlive();
            break;
            case 'allowLargeIncomingData':
                return $this->getAllowLargeIncomingData();
            break;
            case 'httpHeadersMaxSize':
                return $this->getHttpHeadersMaxSize();
            break;
            case 'httpBodyMaxSize':
                return $this->getHttpBodyMaxSize();
            break;
            case 'uploadMaxSize':
                return $this->getUploadMaxSize();
            break;
            case 'path':
                return $this->getPath();
            break;
            case 'logLevel':
                return $this->getLogLevel();
            break;
            case 'logHost':
                return $this->getLogHost();
            break;
            case 'logType':
                return $this->getLogType();
            break;
            default:;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webadmin service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>sessionIdleTimeout</td>
<td>the time interval after which an idle session is terminated</td>
<tr><td>sessionActivityTimeout</td>
<td>the maximum time interval after which a Webadmin session is terminated even if activity exists</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>allowLargeIncomingData</td>
<td>the data receiving to be allowed after the session is terminated</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>path</td>
<td>the Webadmin's directory path</td>
<tr><td>logLevel</td>
<td>the log level for the Webadmin service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webadmin service</td>
</table>
     */
    public function __set($name, $value) {
        switch ($name) {
            case 'maxConnThreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minConnThreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxErrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxAuthErrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'sessionIdleTimeout':
                return $this->setSessionIdleTimeout($value);
            break;
            case 'sessionActivityTimeout':
                return $this->setSessionActivityTimeout($value);
            break;
            case 'allowKeepAlive':
                return $this->setAllowKeepAlive($value);
            break;
            case 'allowLargeIncomingData':
                return $this->setAllowLargeIncomingData($value);
            break;
            case 'httpHeadersMaxSize':
                return $this->setHttpHeadersMaxSize($value);
            break;
            case 'httpBodyMaxSize':
                return $this->setHttpBodyMaxSize($value);
            break;
            case 'uploadMaxSize':
                return $this->setUploadMaxSize($value);
            break;
            case 'path':
                return $this->setPath($value);
            break;
            case 'logLevel':
                return $this->setLogLevel($value);
            break;
            case 'logHost':
                return $this->setLogHost($value);
            break;
            case 'logType':
                return $this->setLogType($value);
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return webadmin_max_connection_threads_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return webadmin_min_connection_threads_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of protocol errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return webadmin_max_errors_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of authentication errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return webadmin_max_auth_errors_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns idle the time interval (in seconds) after which the session is terminated
     *
     * @return int
     */
    public function getSessionIdleTimeout() {
        return webadmin_session_idle_timeout_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the maximum living time for the Webadmin session
     *
     * @return int
     */
    public function getSessionActivityTimeout() {
        return webadmin_session_activity_timeout_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns 1 if persistent (keep-alive) connections are allowed and 0 if otherwise
     *
     * @return int
     */
    public function getAllowKeepAlive() {
        return webadmin_allow_keep_alive_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns 1 if data receiving is allowed after the maximum living time is over and 0 if otherwise
     *
     * @return int
     */
    public function getAllowLargeIncomingData() {
        return webadmin_allow_large_incoming_data_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for received HTTP headers
     *
     * @return int
     */
    public function getHttpHeadersMaxSize() {
        return webadmin_http_headers_max_size_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for incoming HTTP body
     *
     * @return int
     */
    public function getHttpBodyMaxSize() {
        return webadmin_http_body_max_size_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the the maximum allowed size for incoming upload data
     *
     * @return int
     */
    public function getUploadMaxSize() {
        return webadmin_upload_max_size_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns Webadmin's directory path
     *
     * @return String
     */
    public function getPath() {
        return webadmin_path_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return webadmin_log_level_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return webadmin_log_host_get($this->getWebadminObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return webadmin_log_type_get($this->getWebadminObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = webadmin_max_connection_threads_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = webadmin_min_connection_threads_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum number of protocol errors after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = webadmin_max_errors_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum number of authentication errors after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = webadmin_max_auth_errors_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets idle the time interval (in seconds) after which the session is terminated
     * @return bool
     *
     * @param $value int session idle timeout
     */
    public function setSessionIdleTimeout($value) {
        $set = webadmin_session_idle_timeout_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSESSIONIDLETIMEOUT);
    }
    /**
     * @ignore
     * This function sets the maximum living time for the Webadmin session
     * @return bool
     *
     * @param $value int session activity timeout
     */
    public function setSessionActivityTimeout($value) {
        $set = webadmin_session_activity_timeout_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSESSIONACTIVITY);
    }
    /**
     * @ignore
     * This function sets if persistent connections are allowed or not on Webadmin
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, persistent connections are allowed on Webadmin, if it is 0, they're not
     */
    public function setAllowKeepAlive($value) {
        $set = webadmin_allow_keep_alive_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINALLOWKEEPALIVE);
    }
    /**
     * @ignore
     * This function sets if data receiving is allowed after the maximum living time is over
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, Webadmin allows data receiving when the maximum living time is over, if it is '0', it does not
     */
    public function setAllowLargeIncomingData($value) {
        $set = webadmin_allow_large_incoming_data_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINALLOWLARGEINCOMING);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for received HTTP headers
     * @return bool
     *
     * @param $value int HTTP headers maximum size
     */
    public function setHttpHeadersMaxSize($value) {
        $set = webadmin_http_headers_max_size_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINHTTPHEADERSMAX);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for incoming HTTP body
     * @return bool
     *
     * @param $value int HTTP body max size
     * @paramtype
     */
    public function setHttpBodyMaxSize($value) {
        $set = webadmin_http_body_max_size_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINHTTPBODYMAX);
    }
    /**
     * @ignore
     * This function sets the the maximum allowed size for incoming upload data
     * @return bool
     *
     * @param $value int upload maximum size
     */
    public function setUploadMaxSize($value) {
        $set = webadmin_upload_max_size_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINUPLOADMAXSIZE);
    }
    /**
     * @ignore
     * This function sets the directory path towards the Axigen Webadmin
     * @return bool
     *
     * @param $value string path
     */
    public function setPath($value) {
        $set = webadmin_path_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINPATH);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = webadmin_log_level_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = webadmin_log_host_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = webadmin_log_type_set($this->getWebadminObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBADMINSETLOGTYPE);
    }
    /**
     * @private
     * This function saves the Webadmin configuration back to Axigen
     *
     * @return bool
     */
    public function save() {
        $save = webadmin_save($this->getWebadminObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::WEBADMINSAVE);
    }
    /**
     * @private
     * This function resets the changes made but not yet saved
     *
     * @return bool
     */
    public function reset() {
        $reset = webadmin_reset($this->getWebadminObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::WEBADMINRESET);
    }
    /**
     * This function starts the Webadmin service
     * @return bool
     */
    public function start() {
        return $this->parent->startService("webadmin");
    }
    /**
     * This function stops the Webadmin service
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("webadmin");
    }
    /**
     * This function returns an access control object for the Webadmin service
     * @return AccessControl
     */
    public function getAccessControl() {
        $accessControl = webadmin_get_access_control($this->getWebadminObj() , $this->getSessionObj());
        if (!Debug::checkError($accessControl, "_p_access_control", Debug::FATALERROR, Message::WEBADMINACCESSCONTROL)) return false;
        return $accessControl;
    }
    /**
     * adds an Webadmin URL redirect
     * @return bool
     * @param $address string the address
     * @param $host string the host
     * @param $port int port number for the host
     */
    public function addUrlRedirect($address, $host, $port) {
        $urlRedirect = webadmin_url_redirect_add($this->getWebadminObj() , $address, $port, $host);
        if (!Debug::checkError($urlRedirect, "_p_url_redirect", Debug::INFOERROR, Message::WEBADMINADDURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * removes an Webadmin URL redirect
     * @return bool
     * @param $address string the address
     */
    public function removeUrlRedirect($address) {
        if (!$this) return false;
        $resp = webadmin_url_redirect_remove_by_address($this->getWebadminObj() , $address);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBADMINREMOVEURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * list all URL redirects
     * @return array
     */
    public function listUrlRedirects() {
        $urlRedirect = array();
        $urlRedirectIterObj = webadmin_url_redirect_iterator_begin($this->getWebadminObj());
        if (!Debug::checkError($urlRedirectIterObj, "_p_webadmin_url_redirect_iterator", Debug::INFOERROR, Message::WEBADMINLISTURLREDIRECT)) return false;
        while (webadmin_url_redirect_iterator_has_value($urlRedirectIterObj)) {
            $urlRedirectArr = array();
            $urlRedirectObj = new UrlRedirect(webadmin_url_redirect_iterator_value($urlRedirectIterObj));
            $urlRedirectArr['address'] = $urlRedirectObj->getAddress();
            $urlRedirectArr['host'] = $urlRedirectObj->getHost();
            $urlRedirectArr['port'] = $urlRedirectObj->getPort();
            array_push($urlRedirect, $urlRedirectArr);
            webadmin_url_redirect_iterator_next($urlRedirectIterObj);
        }
        webadmin_url_redirect_iterator_destroy($urlRedirectIterObj);
        return $urlRedirect;
    }
    /**
     * updates an Webadmin URL redirect
     * @return bool
     * @param $address string the address
     * @param $newHost string the new host
     * @param $newPort string the new port
     */
    public function updateUrlRedirect($address, $newHost, $newPort) {
        if (!$this) return false;
        $urlRedirectObj = webadmin_url_redirect_get_by_address($this->getWebadminObj() , $address);
        if (!Debug::checkError($urlRedirectObj, "_p_url_redirect", Debug::INFOERROR, Message::WEBADMINUPDATEURLREDIRECT)) return false;
        $resp = webadmin_url_redirect_change($urlRedirectObj, $newHost, $newPort);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBADMINUPDATEURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = webadmin_listeners_get($this->getWebadminObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WEBADMINGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::WEBADMINADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = webadmin_listeners_get($this->getWebadminObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WEBADMINGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBADMINREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = webadmin_listeners_get($this->getWebadminObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::WEBADMINGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::WEBADMINUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = webadmin_listeners_get($this->getWebadminObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::WEBADMINGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::WEBADMINGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = webadmin_get_access_control($this->getWebadminObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::WEBADMINACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
}
/** @} */ // end of group
?>
