<?php
/**
 * \ingroup configServer
 * \defgroup configWebmail configWebmail
 * @{
*/
class Webmail {
    private $wmObj, $parent, $listener, $accesscontrol;
    public function __construct($wmObj, $parent) {
        $this->wmObj = $wmObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        webmail_destroy($this->getWebmailObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getWebmailObj() {
        return $this->wmObj;
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webmail service</td>
<tr><td>maxErrors</td>
<td>the maximum protocol errors number after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum authentication errors number after which the connection is terminated</td>
<tr><td>sessionIdleTimeout</td>
<td>the time interval after which an idle session is terminated</td>
<tr><td>sessionActivityTimeout</td>
<td>sets the maximum time interval after which a Webmail session is terminated even if activity exists</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>allowLargeIncomingData</td>
<td>data receiving to be allowed after the session is terminated</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>path</td>
<td>the Webmail's directory path</td>
<tr><td>showDomainList</td>
<td>if the domain displaying is enabled</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the Webmail service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webmail service</td>
<tr><td>enableIcalCalendar</td>
<td>enable/disable Calendar (ICS) access through iCal/HTTP</td>
<tr><td>enableIcalFreebusy</td>
<td>enable/disable Free/Busy (IFB) access through iCal/HTTP</td>
<tr><td>userInterfaceType</td>
<td>ajax inteface type [<ajaxDefault | ajaxOnly | standardDefault | standardOnly>]</td>
</table>

     */
    public function __get($name) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->getMaxConnThreads();
            break;
            case 'minconnthreads':
                return $this->getMinConnThreads();
            break;
            case 'maxerrors':
                return $this->getMaxErrors();
            break;
            case 'maxautherrors':
                return $this->getMaxAuthErrors();
            break;
            case 'sessionidletimeout':
                return $this->getSessionIdleTimeout();
            break;
            case 'sessionactivitytimeout':
                return $this->getSessionActivityTimeout();
            break;
            case 'allowkeepalive':
                return $this->getAllowKeepAlive();
            break;
            case 'allowlargeincomingdata':
                return $this->getAllowLargeIncomingData();
            break;
            case 'httpheadersmaxsize':
                return $this->getHttpHeadersMaxSize();
            break;
            case 'httpbodymaxsize':
                return $this->getHttpBodyMaxSize();
            break;
            case 'uploadmaxsize':
                return $this->getUploadMaxSize();
            break;
            case 'path':
                return $this->getPath();
            break;
            case 'showdomainlist':
                return $this->getShowDomainList();
            break;
            case 'userdbconnectortype':
                return $this->getUserdbConnectorType();
            break;
            case 'userdbconnectorname':
                return $this->getUserdbConnectorName();
            break;
            case 'loglevel':
                return $this->getLogLevel();
            break;
            case 'loghost':
                return $this->getLogHost();
            break;
            case 'logtype':
                return $this->getLogType();
            break;
            case 'enableicalcalendar':
                return $this->getEnableICALCalendar();
            break;
            case 'enableicalfreebusy':
                return $this->getEnableICALFreeBusy();
            break;
            case 'userinterfacetype':
                return webmail_user_interface_type_get( $this->getWebmailObj() );
            case 'defaultautodiscoveryurl':
                return webmail_default_autodiscovery_url_get( $this->getWebmailObj() );
            break;
            default:;
            break;
        }
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webmail service</td>
<tr><td>maxErrors</td>
<td>the maximum protocol errors number after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum authentication errors number after which the connection is terminated</td>
<tr><td>sessionIdleTimeout</td>
<td>the time interval after which an idle session is terminated</td>
<tr><td>sessionActivityTimeout</td>
<td>sets the maximum time interval after which a Webmail session is terminated even if activity exists</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>allowLargeIncomingData</td>
<td>data receiving to be allowed after the session is terminated</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>path</td>
<td>the Webmail's directory path</td>
<tr><td>showDomainList</td>
<td>if the domain displaying is enabled</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the Webmail service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webmail service</td>
<tr><td>enableIcalCalendar</td>
<td>enable/disable Calendar (ICS) access through iCal/HTTP</td>
<tr><td>enableIcalFreebusy</td>
<td>enable/disable Free/Busy (IFB) access through iCal/HTTP</td>
<tr><td>userInterfaceType</td>
<td>ajax inteface type [<ajaxDefault | ajaxOnly | standardDefault | standardOnly>]</td>
</table>
     */
    public function __set($name, $value) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minconnthreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxerrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxautherrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'sessionidletimeout':
                return $this->setSessionIdleTimeout($value);
            break;
            case 'sessionactivitytimeout':
                return $this->setSessionActivityTimeout($value);
            break;
            case 'allowkeepalive':
                return $this->setAllowKeepAlive($value);
            break;
            case 'allowlargeincomingdata':
                return $this->setAllowLargeIncomingData($value);
            break;
            case 'httpheadersmaxsize':
                return $this->setHttpHeadersMaxSize($value);
            break;
            case 'httpbodymaxsize':
                return $this->setHttpBodyMaxSize($value);
            break;
            case 'uploadmaxsize':
                return $this->setUploadMaxSize($value);
            break;
            case 'path':
                return $this->setPath($value);
            break;
            case 'showdomainlist':
                return $this->setShowDomainList($value);
            break;
            case 'userdbconnectortype':
                return $this->setUserdbConnectorType($value);
            break;
            case 'userdbconnectorname':
                return $this->setUserdbConnectorName($value);
            break;
            case 'loglevel':
                return $this->setLogLevel($value);
            break;
            case 'loghost':
                return $this->setLogHost($value);
            break;
            case 'logtype':
                return $this->setLogType($value);
            break;
            case 'enablemobilewebmail':
                return $this->setEnableMobileWebmail($value);
            break;
            case 'enableicalcalendar':
                return $this->setEnableICALCalendar($value);
            break;
            case 'enableicalfreebusy':
                return $this->setEnableICALFreeBusy($value);
            break;
            case 'userinterfacetype':
                return webmail_user_interface_type_set($this->getWebmailObj(), $value);
            case 'defaultautodiscoveryurl':
                return webmail_default_autodiscovery_url_set( $this->getWebmailObj(), $value );
            break;
            default:;
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the iCAL Calendar status
     *
     * @return int
     */
    public function getEnableICALCalendar() {
        return webmail_enable_ical_calendar_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the iCAL Free/Busy status
     *
     * @return int
     */
    public function getEnableICALFreeBusy() {
        return webmail_enable_ical_freebusy_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the ActiveSync status
     *
     * @return int
     */
    public function getEnableActiveSync() {
        return webmail_enable_active_sync_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return webmail_max_connection_threads_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return webmail_min_connection_threads_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of protocol errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return webmail_max_errors_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of authentication errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return webmail_max_auth_errors_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the idle time interval (in seconds) after which the session is terminated
     *
     * @return int
     */
    public function getSessionIdleTimeout() {
        return webmail_session_idle_timeout_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum living time for the Webadmin session
     *
     * @return int
     */
    public function getSessionActivityTimeout() {
        return webmail_session_activity_timeout_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns 1 if persistent (keep-alive) connections are allowed and 0 if otherwise
     *
     * @return int
     */
    public function getAllowKeepAlive() {
        return webmail_allow_keep_alive_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns 1 if data receiving is allowed after the maximum living time is over and 0 if otherwise
     *
     * @return int
     */
    public function getAllowLargeIncomingData() {
        return webmail_allow_large_incoming_data_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for received HTTP headers
     *
     * @return int
     */
    public function getHttpHeadersMaxSize() {
        return webmail_http_headers_max_size_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for incoming HTTP body
     *
     * @return int
     */
    public function getHttpBodyMaxSize() {
        return webmail_http_body_max_size_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the the maximum allowed size for incoming upload data
     *
     * @return int
     */
    public function getUploadMaxSize() {
        return webmail_upload_max_size_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns Webadmin's directory path
     *
     * @return String
     */
    public function getPath() {
        return webmail_path_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns 1 if domain displaying is enabled at user login and 0 if otherwise
     *
     * @return int
     */
    public function getShowDomainList() {
        return webmail_show_domain_list_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the userdb connector type
     *
     * @return String
     */
    public function getUserdbConnectorType() {
        return webmail_userdb_connector_type_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the userdb connector name
     *
     * @return String
     */
    public function getUserdbConnectorName() {
        return webmail_userdb_connector_name_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return webmail_log_level_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return webmail_log_host_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns the log the for this service.
     *
     * @return String Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return webmail_log_type_get($this->getWebmailObj());
    }
    /**
     * @ignore
     * This function returns 1 if the Mobile Webmail interface is enabled and 0 otherwise
     *
     * @return int
     */
    public function getEnableMobileWebmail() {
        return webmail_enable_mobile_webmail_get($this->getWebmailObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the iCAL Calendar status
     *
     * @return int
     */
    public function setEnableICALCalendar($value) {
        $set = webmail_enable_ical_calendar_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETICALCALENDAR);
    }
    /**
     * @ignore
     * This function sets the iCAL Free/Busy status
     *
     * @return int
     */
    public function setEnableICALFreeBusy($value) {
        $set = webmail_enable_ical_freebusy_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETICALFREEBUSY);
    }
    /**
     * @ignore
     * This function sets the ActiveSync status
     *
     * @return int
     */
    public function setEnableActiveSync($value) {
        $set = webmail_enable_active_sync_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETACTIVESYNC);
    }
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = webmail_max_connection_threads_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = webmail_min_connection_threads_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum number of protocol errors after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = webmail_max_errors_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum number of authentication errors after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum number of authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = webmail_max_auth_errors_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets the idle time interval (in seconds) after which the session is terminated
     * @return bool
     *
     * @param $value int session idle timeout
     */
    public function setSessionIdleTimeout($value) {
        $set = webmail_session_idle_timeout_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSESSIONIDLETIMEOUT);
    }
    /**
     * @ignore
     * This function sets the maximum living time for the Webmail session
     * @return bool
     *
     * @param $value int session activity timeout
     */
    public function setSessionActivityTimeout($value) {
        $set = webmail_session_activity_timeout_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSESSIONACTIVITY);
    }
    /**
     * @ignore
     * This function sets whether the persistent connections are allowed or not on Webmail
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, persistent connections are allowed on Webmail, if it is 0, they're not
     */
    public function setAllowKeepAlive($value) {
        $set = webmail_allow_keep_alive_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILALLOWKEEPALIVE);
    }
    /**
     * @ignore
     * This function sets if data receiving is allowed after the maximum living time is over
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, Webmail allows data receiving when the maximum living time is over, if it is '0', it does not
     */
    public function setAllowLargeIncomingData($value) {
        $set = webmail_allow_large_incoming_data_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILALLOWLARGEINCOMING);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for received HTTP headers
     * @return bool
     *
     * @param $value int HTTP headers maximum size
     */
    public function setHttpHeadersMaxSize($value) {
        $set = webmail_http_headers_max_size_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILHTTPHEADERSMAX);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for incoming HTTP body
     * @return bool
     *
     * @param $value int HTTP body maximum size
     */
    public function setHttpBodyMaxSize($value) {
        $set = webmail_http_body_max_size_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILHTTPBODYMAX);
    }
    /**
     * @ignore
     * This function sets the the maximum allowed size for incoming upload data
     * @return bool
     *
     * @param $value int upload maximum size
     * @paramtype
     */
    public function setUploadMaxSize($value) {
        $set = webmail_upload_max_size_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILUPLOADMAXSIZE);
    }
    /**
     * @ignore
     * This function sets the directory path towards the Axigen Webmail
     * @return bool
     *
     * @param $value string path
     */
    public function setPath($value) {
        $set = webmail_path_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILPATH);
    }
    /**
     * @ignore
     * If enabled Webmail will display the domains at login
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, Webmail displays the domains at login, if it is '0' it does not display them
     */
    public function setShowDomainList($value) {
        $set = webmail_show_domain_list_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSHOWDOMAINLIST);
    }
    /**
     * @ignore
     * This function sets the userdb connector type
     * @return bool
     *
     * @param $value string Valid string values for the 'value' parameter are: "local", "ldap" or "ldapBind"
     */
    public function setUserdbConnectorType($value) {
        $set = webmail_userdb_connector_type_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILUSERDBCONNTYPE);
    }
    /**
     * @ignore
     * This function sets the name of the userdb connector
     * @return bool
     *
     * @param string value userdb connector name
     */
    public function setUserdbConnectorName($value) {
        $set = webmail_userdb_connector_name_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILUSERDBCONNNAME);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = webmail_log_level_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = webmail_log_host_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     * @paramtype String
     */
    public function setLogType($value) {
        $set = webmail_log_type_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETLOGTYPE);
    }
    /**
     * @ignore
     * This function sets whether the Mobile Webmail interface is enabled or not
     * @return bool
     *
     * @param $value int if the value is 1, then the Mobile Webmail interface will be enabled; if 0, it will be disabled
     */
    public function setEnableMobileWebmail($value) {
        $set = webmail_enable_mobile_webmail_set($this->getWebmailObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WEBMAILSETENABLEMOBILE);
    }
    /**
     * This function saves the Webmail configuration back to Axigen
     * @return bool
     */
    public function save() {
        $save = webmail_save($this->getWebmailObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::WEBMAILSAVE);
    }
    /**
     * This function resets the changes made but not yet saved
     * @return bool
     */
    public function reset() {
        $reset = webmail_reset($this->getWebmailObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::WEBMAILRESET);
    }
    /**
     * This function starts the Webmail service
     * @return bool
     */
    public function start() {
        return $this->parent->startService("webmail");
    }
    /**
     * This function stops the Webmail service
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("webmail");
    }
    /**
     * This function adds a hostname resolver. This maps a hostname to a domain
     *
     * @param $host string hostname
     * @param $domain string domain name
     *
     * @return bool
     */
    public function addHostNameResolver($host, $domain) {
        $add = webmail_hostname_resolver_add($this->getWebmailObj() , $host, $domain);
        if (!Debug::checkError($add, '_p_hostname_resolver', Debug::INFOERROR, Message::WEBMAILADDHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This method lists the hostname resolvers
     *
     * @return array
     */
    public function listHostNameResolvers() {
        $hostnameResolverIterObj = webmail_hostname_resolver_iterator_begin($this->getWebmailObj());
        if (!Debug::checkError($hostnameResolverIterObj, "_p_webmail_hostname_resolver_iterator", Debug::INFOERROR, Message::WEBMAILLISTHOSTNAMERESOLVER)) return false;
        $hostnameResolverList = array();
        while (webmail_hostname_resolver_iterator_has_value($hostnameResolverIterObj)) {
            $hostnameResolverTmp = array();
            $hostnameResolverObj = webmail_hostname_resolver_iterator_value($hostnameResolverIterObj);
            $hostnameResolverTmp['domain'] = hostname_resolver_domain_get($hostnameResolverObj);
            $hostnameResolverTmp['host'] = hostname_resolver_host_get($hostnameResolverObj);
            array_push($hostnameResolverList, $hostnameResolverTmp);
            webmail_hostname_resolver_iterator_next($hostnameResolverIterObj);
        }
        webmail_hostname_resolver_iterator_destroy($hostnameResolverIterObj);
        return $hostnameResolverList;
    }
    /**
     * This function changes the hostname resolver that matches the given host
     * @param $hostname string the hostname
     * @param $newDomain string the new domain value
     * @return bool
     */
    public function updateHostNameResolver($hostname, $newDomain) {
        $update = webmail_hostname_resolver_change_by_host($this->getWebmailObj() , $hostname, $newDomain);
        if (!Debug::checkError($update, 0, Debug::INFOERROR, Message::WEBMAILUPDATEHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This function removes the hostname resolver that matches the given host
     * @param $hostname string the hostname
     * @return bool
     */
    public function removeHostNameResolver($hostname) {
        $remove = webmail_hostname_resolver_remove_by_host($this->getWebmailObj() , $hostname);
        if (!Debug::checkError($remove, 0, Debug::INFOERROR, Message::WEBMAILREMOVEHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This function adds a URL redirect. This can be used to redirect the request for a specific host to another address.
     * @param $address string the address ex. 127.0.0.1:8000
     * @param $host string the hostname
     * @param $port int the port number
     * @return bool
     */
    public function addUrlRedirect($address, $host, $port) {
        $add = webmail_url_redirect_add($this->getWebmailObj() , $address, $port, $host);
        if (!Debug::checkError($add, '_p_url_redirect', Debug::INFOERROR, Message::WEBMAILADDURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * This method lists the URL redirects
     * @return array
     */
    public function listUrlRedirects() {
        $urlRedirectIterObj = webmail_url_redirect_iterator_begin($this->getWebmailObj());
        if (!Debug::checkError($urlRedirectIterObj, "_p_webmail_url_redirect_iterator", Debug::INFOERROR, Message::WEBMAILLISTURLREDIRECT)) return false;
        $urlRedirectList = array();
        while (webmail_url_redirect_iterator_has_value($urlRedirectIterObj)) {
            $urlRedirectTmp = array();
            $urlRedirectObj = webmail_url_redirect_iterator_value($urlRedirectIterObj);
            $urlRedirectTmp['address'] = url_redirect_address_get($urlRedirectObj);
            $urlRedirectTmp['host'] = url_redirect_host_get($urlRedirectObj);
            $urlRedirectTmp['port'] = url_redirect_port_get($urlRedirectObj);
            array_push($urlRedirectList, $urlRedirectTmp);
            webmail_url_redirect_iterator_next($urlRedirectIterObj);
        }
        webmail_url_redirect_iterator_destroy($urlRedirectIterObj);
        return $urlRedirectList;
    }
    /**
     * This function removes an URL redirect with the specified address
     * @param $address string the address of the URL redirect
     * @return bool
     */
    public function removeUrlRedirect($address) {
        $remove = webmail_url_redirect_remove_by_address($this->getWebmailObj() , $address);
        if (!Debug::checkError($remove, 0, Debug::INFOERROR, Message::WEBMAILREMOVEURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * This function changes an existing URL redirect, changing its host and port
     * @param $address string the address of the url redirect
     * @param $newHost string the new host value
     * @param $newPort int the new port value
     * @return bool
     */
    public function updateUrlRedirect($address, $newHost, $newPort) {
        $urlRedirect = webmail_url_redirect_get_by_address($this->getWebmailObj() , $address);
        if (Debug::checkError($urlRedirect, '_p_url_redirect', Debug::INFOERROR, Message::WEBMAILUPDATEURLREDIRECT)) {
            $change = webmail_url_redirect_change($urlRedirect, $newHost, $newPort);
            if (!Debug::checkError($change, 0, Debug::INFOERROR, Message::WEBMAILUPDATEURLREDIRECT)) return false;
            return $this->save();
        }
        return false;
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = webmail_listeners_get($this->getWebmailObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WEBMAILGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::WEBMAILADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function removeListener($address) {
        $listeners = webmail_listeners_get($this->getWebmailObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WEBMAILGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WEBMAILREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return object Listener
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = webmail_listeners_get($this->getWebmailObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::WEBMAILGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::WEBMAILUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = webmail_listeners_get($this->getWebmailObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::WEBMAILGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::WEBMAILGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = webmail_get_access_control($this->getWebmailObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::WEBMAILACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
}
/** @} */ // end of group
?>
