<?php
/**
 * This is the object containing the Webmail data for the selected account
 * \ingroup updateAccount
 * \defgroup configWebmailData configWebmailData
 * @{
 */
class WebmailData {
    private $webmaildata, $parent;
    public function __construct($webmailDataObj, $parentObj) {
        $this->webmaildata = $webmailDataObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        webmaildata_destroy($this->getWebmailData());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getWebmailData() {
        return $this->webmaildata;
    }
    /**      
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = webmaildata_save($this->getWebmailData() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEACCOUNTWEBMAILDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>skin</td>
<td>the skin for Webmail</td>
<tr><td>language</td>
<td>the language for Webmail</td>
<tr><td>signature</td>
<td>the account signature</td>
<tr><td>pageSize</td>
<td>page size</td>
<tr><td>timeZone</td>
<td>the timezone of the account</td>
<tr><td>saveToSent</td>
<td>a mail copy to be saved in the Sent folder</td>
<tr><td>deleteToTrash</td>
<td>deleted mail to be sent in the Trash folder</td>
<tr><td>autoRefreshInterval</td>
<td>the Webmail automatic refresh interval, stated in minutes</td>
<tr><td>confirmMailDelete</td>
<td>confirmation of mail deletion</td>
<tr><td>confirmFolderEmpty</td>
<td>confirmation of emptying folder</td>
<tr><td>htmlFilterLevel</td>
<td>the security level for a HTML mail body</td>
<tr><td>usePublicContacts</td>
<td>if the account should use the domain public contacts in addressbook context</td>
<tr><td>useRcptContacts</td>
<td>if the account should use the domain recipient contacts in addressbook context</td>
<tr><td>requestReadReceipts</td>
<td>enable/disable requesting of read receipts</td>
<tr><td>sendReadReceipts</td>
<td>enable/disable sending of read receipts (values: always|never|ask)</td>
<tr><td>weekStartDay</td>
<td>the account week start day</td>
<tr><td>purgeTrashMessageSelector</td>
<td>the message selector used to purge trash folder</td>
<tr><td>purgeSpamMessageSelector</td>
<td>the message selector used to purge spam folder</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "skin":
                $resp = webmaildata_skin_set($this->getWebmailData() , $varValue);
            break;
            case "language":
                $resp = webmaildata_language_set($this->getWebmailData() , $varValue);
            break;
            case "signature":
                $resp = webmaildata_signature_set($this->getWebmailData() , $varValue);
            break;
            case "pagesize":
                $resp = webmaildata_page_size_set($this->getWebmailData() , $varValue);
            break;
            case "savetosent":
                $resp = webmaildata_save_to_sent_set($this->getWebmailData() , $varValue);
            break;
            case "deletetotrash":
                $resp = webmaildata_delete_to_trash_set($this->getWebmailData() , $varValue);
            break;
            case "autorefreshinterval":
                $resp = webmaildata_auto_refresh_interval_set($this->getWebmailData() , $varValue);
            break;
            case "confirmmaildelete":
                $resp = webmaildata_confirm_mail_delete_set($this->getWebmailData() , $varValue);
            break;
            case "confirmfolderempty":
                $resp = webmaildata_confirm_folder_empty_set($this->getWebmailData() , $varValue);
            break;
            case "htmlfilterlevel":
                $resp = webmaildata_html_filter_level_set($this->getWebmailData() , $varValue);
            break;
            case "timezone":
                return webmaildata_timezone_set($this->getWebmailData() , $varValue);
            break;
            case "usepubliccontacts":
                $resp = webmaildata_use_public_contacts_set($this->getWebmailData() , $varValue);
            break;
            case "usedomaincontacts":
                $resp = webmaildata_use_domain_contacts_set($this->getWebmailData() , $varValue);
            break;
            case "usercptcontacts":
                $resp = webmaildata_use_domain_contacts_set($this->getWebmailData() , $varValue);
            break;
            case "requestreadreceipts":
                $resp = webmaildata_request_read_receipts_set($this->getWebmailData() , $varValue);
            break;
            case "sendreadreceipts":
                $resp = webmaildata_send_read_receipts_set($this->getWebmailData() , $varValue);
            break;
            case "weekstartday":
                $resp = webmaildata_week_start_day_set($this->getWebmailData(), $varValue);
            break;
            case "purgetrashmessageselector":
                $resp = webmaildata_purge_trash_message_selector_set($this->getWebmailData(), $varValue);
            break;
            case "purgespammessageselector":
                $resp = webmaildata_purge_spam_message_selector_set($this->getWebmailData(), $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETACCOUNTWEBMAILDATAVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETACCOUNTWEBMAILDATAVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>skin</td>
<td>the skin for Webmail</td>
<tr><td>language</td>
<td>the language for Webmail</td>
<tr><td>signature</td>
<td>the account signature</td>
<tr><td>pageSize</td>
<td>page size</td>
<tr><td>timeZone</td>
<td>the timezone of the account</td>
<tr><td>saveToSent</td>
<td>a mail copy to be saved in the Sent folder</td>
<tr><td>deleteToTrash</td>
<td>deleted mail to be sent in the Trash folder</td>
<tr><td>autoRefreshInterval</td>
<td>the Webmail automatic refresh interval, stated in minutes</td>
<tr><td>confirmMailDelete</td>
<td>confirmation of mail deletion</td>
<tr><td>confirmFolderEmpty</td>
<td>confirmation of emptying folder</td>
<tr><td>htmlFilterLevel</td>
<td>the security level for a HTML mail body</td>
<tr><td>usePublicContacts</td>
<td>if the account should use the domain public contacts in addressbook context</td>
<tr><td>useRcptContacts</td>
<td>if the account should use the domain recipient contacts in addressbook context</td>
<tr><td>requestReadReceipts</td>
<td>enable/disable requesting of read receipts</td>
<tr><td>sendReadReceipts</td>
<td>enable/disable sending of read receipts (values: always|never|ask)</td>
<tr><td>weekStartDay</td>
<td>the account week start day</td>
<tr><td>purgeTrashMessageSelector</td>
<td>the message selector used to purge trash folder</td>
<tr><td>purgeSpamMessageSelector</td>
<td>the message selector used to purge spam folder</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "skin":
                return webmaildata_skin_get($this->getWebmailData());
            break;
            case "language":
                return webmaildata_language_get($this->getWebmailData());
            break;
            case "signature":
                return webmaildata_signature_get($this->getWebmailData());
            break;
            case "timezone":
                return webmaildata_timezone_get($this->getWebmailData());
            break;
            case "weekstartday":
                return webmaildata_week_start_day_get($this->getWebmailData());
            break;
            case "pagesize":
                return webmaildata_page_size_get($this->getWebmailData());
            break;
            case "savetosent":
                return webmaildata_save_to_sent_get($this->getWebmailData());
            break;
            case "deletetotrash":
                return webmaildata_delete_to_trash_get($this->getWebmailData());
            break;
            case "hidedeletedmessages":
                return webmaildata_hide_deleted_messages_get($this->getWebmailData());
            break;
            case "autorefreshinterval":
                return webmaildata_auto_refresh_interval_get($this->getWebmailData());
            break;
            case "confirmmaildelete":
                return webmaildata_confirm_mail_delete_get($this->getWebmailData());
            break;
            case "confirmfolderempty":
                return webmaildata_confirm_folder_empty_get($this->getWebmailData());
            break;
            case "usepubliccontacts":
                return webmaildata_use_public_contacts_get($this->getWebmailData());
            break;
            case "usercptcontacts":
                return webmaildata_use_domain_contacts_get($this->getWebmailData());
            break;
            case "userdomaincontacts":
                return webmaildata_use_domain_contacts_get($this->getWebmailData());
            break;
            case "replyto":
                return webmaildata_reply_to_get($this->getWebmailData());
            break;
            case "enablenewemailnotification":
                return webmaildata_enable_new_email_notification_get($this->getWebmailData());
            break;
            case "htmlfilterlevel":
                return webmaildata_html_filter_level_get($this->getWebmailData());
            break;
            case "weekstartday":
                return webmaildata_week_start_day_get($this->getWebmailData());
            break;
            case "requestreadreceipts":
                return webmaildata_request_read_receipts_get($this->getWebmailData());
            break;
            case "sendreadreceipts":
                return webmaildata_send_read_receipts_get($this->getWebmailData());
            break;
            case "purgetrashmessageselector":
                return webmaildata_purge_trash_message_selector_get($this->getWebmailData());
            break;
            case "purgespammessageselector":
                return webmaildata_purge_spam_message_selector_get($this->getWebmailData());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETACCOUNTWEBMAILDATAVARERROR);
        }
    }
}
/** @} */ // end of group
?>
