<?php
/**
 * \ingroup configServer
 * \defgroup configWebmailProxy configWebmailProxy
*/
class WebmailProxy {
    private $webmailProxyObj, $parent, $listener, $accesscontrol;
    public function __construct($webmailProxyObj, $parent) {
        $this->webmailProxyObj = $webmailProxyObj;
        $this->parent = $parent;
    }
    public function __destruct() {
        webmail_proxy_destroy($this->getWebmailProxyObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getWebmailProxyObj() {
        return $this->webmailProxyObj;
    }
    /**
Get member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webmail service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the Webmail service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>authenticateOnProxy</td>
<td>if the authentication should be also done on proxy</td>
<tr><td>path</td>
<td>the WebmailProxy's directory path</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>requestsQueueMaxSize</td>
<td>the maximum size of the request queue</td>
<tr><td>allowLargeIncomingData</td>
<td>data receiving to be allowed after the session times out</td>
<tr><td>enableMobileWebmail</td>
<td>enabled/disabled the Mobile Webmail interface</td>
<tr><td>mappingDataUsermapName</td>
<td>the mapping usermap name for the proxy</td>
<tr><td>mappingDataMappingHost</td>
<td>the mapping data host for the proxy</td>
<tr><td>mappingDataMappingPort</td>
<td>the mapping data port for the proxy</td>
<tr><td>connectionDataTimeout</td>
<td>the timeout for the read/write operation</td>
<tr><td>connectionDataMaxConnections</td>
<td>the maximum number of simultaneous connections</td>
<tr><td>connectionDataSslEnable</td>
<td>if the connection should be SSL</td>
<tr><td>connectionDataLocalInterface</td>
<td>the address of the interface used to make the connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the Webmail service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webmail service</td>
<tr><td>userInterfaceType</td>
<td>ajax inteface type [<ajaxDefault | ajaxOnly | standardDefault | standardOnly>]</td>
<tr><td>httpBindBackend</td>
<td>the http url of the IM backend</td>
</table>
     */
    public function __get($name) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->getMaxConnThreads();
            break;
            case 'minconnthreads':
                return $this->getMinConnThreads();
            break;
            case 'maxerrors':
                return $this->getMaxErrors();
            break;
            case 'maxautherrors':
                return $this->getMaxAuthErrors();
            break;
            case 'authenticateonproxy':
                return $this->getAuthenticateOnProxy();
            break;
            case 'path':
                return $this->getPath();
            break;
            case 'allowkeepalive':
                return $this->getAllowKeepAlive();
            break;
            case 'httpheadersmaxsize':
                return $this->getHttpHeadersMaxSize();
            break;
            case 'httpbodymaxsize':
                return $this->getHttpBodyMaxSize();
            break;
            case 'uploadmaxsize':
                return $this->getUploadMaxSize();
            break;
            case 'requestsqueuemaxsize':
                return $this->getRequestsQueueMaxSize();
            break;
            case 'allowlargeincomingdata':
                return $this->getAllowLargeIncomingData();
            break;
            case 'enablemobilewebmail':
                return $this->getEnableMobileWebmail();
            break;
            case 'mappingdatausermapname':
                return $this->getMappingDataUsermapName();
            break;
            case 'mappingdatamappinghost':
                return $this->getMappingDataMappingHost();
            break;
            case 'mappingdatamappingport':
                return $this->getMappingDataMappingPort();
            break;
            case 'connectiondatatimeout':
                return $this->getConnectionDataTimeout();
            break;
            case 'connectiondatamaxconnections':
                return $this->getConnectionDataMaxConnections();
            break;
            case 'connectiondatasslenable':
                return $this->getConnectionDataSslEnable();
            break;
            case 'connectiondatalocalinterface':
                return $this->getConnectionDataLocalInterface();
            break;
            case 'userdbconnectortype':
                return $this->getUserdbConnectorType();
            break;
            case 'userdbconnectorname':
                return $this->getUserdbConnectorName();
            break;
            case 'loglevel':
                return $this->getLogLevel();
            break;
            case 'loghost':
                return $this->getLogHost();
            break;
            case 'logtype':
                return $this->getLogType();
            case 'userinterfacetype':
                return webmail_proxy_user_interface_type_get( $this->getWebmailProxyObj() );
            break;
            case 'httpbindbackend':
                return webmail_proxy_http_bind_backend_get( $this->getWebmailProxyObj() );
            break;
            break;
        }
    }
    /**
Set member.
<table>
<tr><th>member</th><th>description</th>
<tr><td>maxConnThreads</td>
<td>the maximum number of threads involved in I/O for the Webmail service</td>
<tr><td>minConnThreads</td>
<td>the minimum number of threads involved in I/O for the Webmail service</td>
<tr><td>maxErrors</td>
<td>the maximum number of protocol errors after which the connection is terminated</td>
<tr><td>maxAuthErrors</td>
<td>the maximum number of authentication errors after which the connection is terminated</td>
<tr><td>authenticateOnProxy</td>
<td>if the authentication should be also done on proxy</td>
<tr><td>path</td>
<td>the WebmailProxy's directory path</td>
<tr><td>allowKeepAlive</td>
<td>permanent connections</td>
<tr><td>httpHeadersMaxSize</td>
<td>the maximum allowed size for received HTTP headers</td>
<tr><td>httpBodyMaxSize</td>
<td>the maximum allowed size for incoming HTTP body</td>
<tr><td>uploadMaxSize</td>
<td>the maximum allowed size for incoming upload data</td>
<tr><td>requestsQueueMaxSize</td>
<td>the maximum size of the request queue</td>
<tr><td>allowLargeIncomingData</td>
<td>data receiving to be allowed after the session times out</td>
<tr><td>enableMobileWebmail</td>
<td>enabled/disabled the Mobile Webmail interface</td>
<tr><td>mappingDataUsermapName</td>
<td>the mapping usermap name for the proxy</td>
<tr><td>mappingDataMappingHost</td>
<td>the mapping data host for the proxy</td>
<tr><td>mappingDataMappingPort</td>
<td>the mapping data port for the proxy</td>
<tr><td>connectionDataTimeout</td>
<td>the timeout for the read/write operation</td>
<tr><td>connectionDataMaxConnections</td>
<td>the maximum number of simultaneous connections</td>
<tr><td>connectionDataSslEnable</td>
<td>if the connection should be SSL</td>
<tr><td>connectionDataLocalInterface</td>
<td>the address of the interface used to make the connections</td>
<tr><td>userdbConnectorType</td>
<td>the userdb connector type</td>
<tr><td>userdbConnectorName</td>
<td>the userdb connector name</td>
<tr><td>logLevel</td>
<td>the log level for the Webmail service</td>
<tr><td>logHost</td>
<td>the address of the host that offers log services</td>
<tr><td>logType</td>
<td>the log type for the Webmail service</td>
<tr><td>userInterfaceType</td>
<td>ajax inteface type [<ajaxDefault | ajaxOnly | standardDefault | standardOnly>]</td>
<tr><td>httpBindBackend</td>
<td>the http url of the IM backend</td>
</table>
*/ 
    public function __set($name, $value) {
        switch (strtolower($name)) {
            case 'maxconnthreads':
                return $this->setMaxConnThreads($value);
            break;
            case 'minconnthreads':
                return $this->setMinConnThreads($value);
            break;
            case 'maxerrors':
                return $this->setMaxErrors($value);
            break;
            case 'maxautherrors':
                return $this->setMaxAuthErrors($value);
            break;
            case 'authenticateonproxy':
                return $this->setAuthenticateOnProxy($value);
            break;
            case 'path':
                return $this->setPath($value);
            break;
            case 'allowkeepalive':
                return $this->setAllowKeepAlive($value);
            break;
            case 'httpheadersmaxSize':
                return $this->setHttpHeadersMaxSize($value);
            break;
            case 'httpbodymaxsize':
                return $this->setHttpBodyMaxSize($value);
            break;
            case 'uploadmaxsize':
                return $this->setUploadMaxSize($value);
            break;
            case 'requestsqueuemaxsize':
                return $this->setRequestsQueueMaxSize($value);
            break;
            case 'allowlargeIncomingdata':
                return $this->setAllowLargeIncomingData($value);
            break;
            case 'enablemobilewebmail':
                return $this->setEnableMobileWebmail($value);
            break;
            case 'mappingdatausermapname':
                return $this->setMappingDataUsermapName($value);
            break;
            case 'mappingdatamappinghost':
                return $this->setMappingDataMappingHost($value);
            break;
            case 'mappingdatamappingport':
                return $this->setMappingDataMappingPort($value);
            break;
            case 'connectiondatatimeout':
                return $this->setConnectionDataTimeout($value);
            break;
            case 'connectiondatamaxconnections':
                return $this->setConnectionDataMaxConnections($value);
            break;
            case 'connectiondatasslenable':
                return $this->setConnectionDataSslEnable($value);
            break;
            case 'connectiondatalocalinterface':
                return $this->setConnectionDataLocalInterface($value);
            break;
            case 'userdbconnectortype':
                return $this->setUserdbConnectorType($value);
            break;
            case 'userdbconnectorname':
                return $this->setUserdbConnectorName($value);
            break;
            case 'loglevel':
                return $this->setLogLevel($value);
            break;
            case 'loghost':
                return $this->setLogHost($value);
            break;
            case 'logtype':
                return $this->setLogType($value);
            break;
            case 'userinterfacetype':
                return webmail_proxy_user_interface_type_set($this->getWebmailProxyObj(), $value);
            break;
            case 'httpbindbackend':
                return webmail_proxy_http_bind_backend_set($this->getWebmailProxyObj(), $value);
            break;
        }
    }
    /*******************************************************************************
    * Getters
    */
    /**
     * @ignore
     * This function returns the maximum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMaxConnThreads() {
        return webmail_proxy_max_connection_threads_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the minimum number of threads involved in I/O for this service
     *
     * @return int
     */
    public function getMinConnThreads() {
        return webmail_proxy_min_connection_threads_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of protocol errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxErrors() {
        return webmail_proxy_max_errors_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum number of authentication errors after which the connection is terminated
     *
     * @return int
     */
    public function getMaxAuthErrors() {
        return webmail_proxy_max_auth_errors_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if the proxy authentication is also done on proxy and 0 if otherwise
     *
     * @return int
     */
    public function getAuthenticateOnProxy() {
        return webmail_proxy_authenticate_on_proxy_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns webadmin's directory path
     *
     * @return String
     */
    public function getPath() {
        return webmail_proxy_path_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if persistent (keep-alive) connections are allowed and 0 if otherwise
     *
     * @return int
     */
    public function getAllowKeepAlive() {
        return webmail_proxy_allow_keep_alive_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for received HTTP headers
     *
     * @return int
     */
    public function getHttpHeadersMaxSize() {
        return webmail_proxy_http_headers_max_size_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum allowed size for incoming HTTP body
     *
     * @return int
     */
    public function getHttpBodyMaxSize() {
        return webmail_proxy_http_body_max_size_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the the maximum allowed size for incoming upload data
     *
     * @return int
     */
    public function getUploadMaxSize() {
        return webmail_proxy_upload_max_size_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the maximum size of the request queue
     *
     * @return int
     */
    public function getRequestsQueueMaxSize() {
        return webmail_proxy_requests_queue_max_size_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if data receiving is allowed after the maximum living time is over and 0 if otherwise
     *
     * @return int
     */
    public function getAllowLargeIncomingData() {
        return webmail_proxy_allow_large_incoming_data_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns 1 if the Mobile Webmail interface is enabled and 0 if otherwise
     *
     * @return int
     */
    public function getEnableMobileWebmail() {
        return webmail_proxy_enable_mobile_webmail_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the mapping data usermap name
     *
     * @return String
     */
    public function getMappingDataUsermapName() {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::POP3PROXYGETMAPPINGDATA)) {
            return mapping_data_usermap_name_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the mapping data host
     *
     * @return String
     */
    public function getMappingDataMappingHost() {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::POP3PROXYGETMAPPINGDATA)) {
            return mapping_data_mapping_host_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the mapping data port
     *
     * @return String
     */
    public function getMappingDataMappingPort() {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::POP3PROXYGETMAPPINGDATA)) {
            return mapping_data_mapping_port_get($mappingData);
        }
    }
    /**
     * @ignore
     * This function returns the read-write timeout in seconds
     *
     * @return int
     */
    public function getConnectionDataTimeout() {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::POP3PROXYGETCONNDATA)) {
            return connection_data_timeout_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the total number of connections allowed on the proxy to whom the connection data object belongs
     *
     * @return
     */
    public function getConnectionDataMaxConnections() {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::POP3PROXYGETCONNDATA)) {
            return connection_data_max_connections_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns 1 if the proxy is SSL-enabled and 0 if otherwise
     *
     * @return
     */
    public function getConnectionDataSslEnable() {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::POP3PROXYGETCONNDATA)) {
            return connection_data_is_ssl_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the local interface on which the proxy listens to
     *
     * @return
     */
    public function getConnectionDataLocalInterface() {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::POP3PROXYGETCONNDATA)) {
            return connection_data_local_interface_get($connectionData);
        }
    }
    /**
     * @ignore
     * This function returns the userdb connector type
     *
     * @return String
     */
    public function getUserdbConnectorType() {
        return webmail_proxy_userdb_connector_type_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the userdb connector name
     *
     * @return String
     */
    public function getUserdbConnectorName() {
        return webmail_proxy_userdb_connector_name_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the log level for this service
     *
     * @return int
     */
    public function getLogLevel() {
        return webmail_proxy_log_level_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the host which handles the logging (if the log type is not local)
     *
     * @return String
     */
    public function getLogHost() {
        return webmail_proxy_log_host_get($this->getWebmailProxyObj());
    }
    /**
     * @ignore
     * This function returns the log for this service.
     *
     * @return string Expected values are: "internal", "system" or "remote"
     */
    public function getLogType() {
        return webmail_proxy_log_type_get($this->getWebmailProxyObj());
    }
    /*******************************************************************************
    * Setters
    */
    /**
     * @ignore
     * This function sets the maximum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int maximum number of connection threads
     */
    public function setMaxConnThreads($value) {
        $set = webmail_proxy_max_connection_threads_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMAXCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the minimum number of threads involved in I/O for this service
     * @return bool
     *
     * @param $value int minimum number of connection threads
     */
    public function setMinConnThreads($value) {
        $set = webmail_proxy_min_connection_threads_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMINCONNTHREADS);
    }
    /**
     * @ignore
     * This function sets the maximum protocol errors number after which the connection is terminated.
     * @return bool
     *
     * @param $value int maximum number of errors
     */
    public function setMaxErrors($value) {
        $set = webmail_proxy_max_errors_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMAXERRORS);
    }
    /**
     * @ignore
     * This function sets the maximum number of authentication errors after which the connection is terminated
     * @return bool
     *
     * @param $value int maximum authentication errors
     */
    public function setMaxAuthErrors($value) {
        $set = webmail_proxy_max_auth_errors_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETAUTHERRORS);
    }
    /**
     * @ignore
     * This function sets if the user's authentication is also done through proxy
     * @return bool
     *
     * @param $value int if the 'value' parameter is 1, the user's authentication is also done through proxy, if it is 0 the authentication is not done on proxy
     */
    public function setAuthenticateOnProxy($value) {
        $set = webmail_proxy_authenticate_on_proxy_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETAUTHONPROXY);
    }
    /**
     * @ignore
     * This function sets the directory path towards the Axigen Webmail
     * @return bool
     *
     * @param $value string path
     */
    public function setPath($value) {
        $set = webmail_proxy_path_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYPATH);
    }
    /**
     * @ignore
     * This function sets if the persistent connections are allowed or not on Webmail
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, persistent connections are allowed on Webmail, if it is 0, they're not
     */
    public function setAllowKeepAlive($value) {
        $set = webmail_proxy_allow_keep_alive_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYALLOWKEEPALIVE);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for received HTTP headers
     * @return bool
     *
     * @param $value int HTTP headers max size
     */
    public function setHttpHeadersMaxSize($value) {
        $set = webmail_proxy_http_headers_max_size_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYHTTPHEADERSMAX);
    }
    /**
     * @ignore
     * This function sets the maximum allowed size for incoming HTTP body
     * @return bool
     *
     * @param $value int HTTP body max size
     */
    public function setHttpBodyMaxSize($value) {
        $set = webmail_proxy_http_body_max_size_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYHTTPBODYMAX);
    }
    /**
     * @ignore
     * This function sets the the maximum allowed size for incoming upload data
     * @return bool
     *
     * @param $value int upload maximum size
     */
    public function setUploadMaxSize($value) {
        $set = webmail_proxy_upload_max_size_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYUPLOADMAXSIZE);
    }
    /**
     * @ignore
     * This function sets the maximum size of the request queue
     * @return bool
     *
     * @param $value int the maximum size of the request queue
     */
    public function setRequestsQueueMaxSize($value) {
        $set = webmail_proxy_requests_queue_max_size_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYPROXYSETREQQMAXSIZE);
    }
    /**
     * @ignore
     * This function sets if data receiving is allowed after the maximum living time is over
     * @return bool
     *
     * @param $value int If the 'value' parameter is 1, Webmail allows data receiving when the maximum living time is over, if it is '0', it does not
     */
    public function setAllowLargeIncomingData($value) {
        $set = webmail_proxy_allow_large_incoming_data_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYALLOWLARGEINCOMING);
    }
    /**
     * @ignore
     * This function sets if the Mobile Webmail interface is enabled or not
     * @return bool
     *
     * @param $value int if the value is 1 the Mobile Webmail interface will be enabled, if 0 then it will be disabled
     */
    public function setEnableMobileWebmail($value) {
        $set = webmail_proxy_enable_mobile_webmail_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYPROXYSETENABLEMOBILE);
    }
    /**
     * @ignore
     * This function sets the mapping usermap name for Webmail proxy
     * @return bool
     *
     * @param $value string the mapping data name
     */
    public function setMappingDataUsermapName($value) {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::WMPROXYGETMAPPINGDATA)) {
            $set = mapping_data_usermap_name_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
        }
    }
    /**
     * @ignore
     * This function sets the mapping host for Webmail proxy
     * @return bool
     *
     * @param $value string the mapping host
     */
    public function setMappingDataMappingHost($value) {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::WMPROXYGETMAPPINGDATA)) {
            $set = mapping_data_mapping_host_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
        }
    }
    /**
     * @ignore
     * This function sets the mapping port Webmail proxy
     * @return bool
     *
     * @param $value int the mapping port
     */
    public function setMappingDataMappingPort($value) {
        $mappingData = webmail_proxy_mapping_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($mappingData, '_p_mapping_data', Debug::INFOERROR, Message::WMPROXYGETMAPPINGDATA)) {
            $set = mapping_data_mapping_port_set($mappingData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
            $save = mapping_data_save($mappingData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETMAPPINGDATANAME);
        }
    }
    /**
     * @ignore
     * This function sets the timeout for the read/write operation
     * @return bool
     *
     * @param $value int the timeout for the read/write operation
     */
    public function setConnectionDataTimeout($value) {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::WMPROXYGETCONNDATA)) {
            $set = connection_data_timeout_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATATIMEOUT);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATATIMEOUT);
        }
    }
    /**
     * @ignore
     * This function sets the maximum number of simultaneous connections
     * @return bool
     *
     * @param $value int the maximum number of simultaneous connections
     */
    public function setConnectionDataMaxConnections($value) {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::WMPROXYGETCONNDATA)) {
            $set = connection_data_max_connections_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATAMAXCON);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATAMAXCON);
        }
    }
    /**
     * @ignore
     * This function sets if the connection should be SSL
     * @return bool
     *
     * @param $value int If the value paramter is 1, this function enables SSL on the proxy, if it is 0, it disables it.
     */
    public function setConnectionDataSslEnable($value) {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::WMPROXYGETCONNDATA)) {
            $set = connection_data_is_ssl_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATASSLENABLE);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATASSLENABLE);
        }
    }
    /**
     * @ignore
     * This function sets the address of the interface used to make the connections
     * @return bool
     *
     * @param $value string the address of the interface used to make the connections
     */
    public function setConnectionDataLocalInterface($value) {
        $connectionData = webmail_proxy_connection_data_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (Debug::checkError($connectionData, '_p_connection_data', Debug::INFOERROR, Message::WMPROXYGETCONNDATA)) {
            $set = connection_data_local_interface_set($connectionData, $value);
            Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATALOCALI);
            $save = connection_data_save($connectionData, $this->getSessionObj());
            return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSETCONNDATALOCALI);
        }
    }
    public function setUserdbConnectorType($value) {
        $set = webmail_proxy_userdb_connector_type_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYUSERDBCONNTYPE);
    }
    /**
     * @ignore
     * This function sets the name of the userdb connector
     * @return bool
     *
     * @param $value string userdb connector name
     */
    public function setUserdbConnectorName($value) {
        $set = webmail_proxy_userdb_connector_name_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYUSERDBCONNNAME);
    }
    /**
     * @ignore
     * This function sets the log level for this service
     * @return bool
     *
     * @param $value int log level
     */
    public function setLogLevel($value) {
        $set = webmail_proxy_log_level_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETLOGLEVEL);
    }
    /**
     * @ignore
     * This function sets the address of the host that offers log services for Axigen
     * @return bool
     *
     * @param $value string log host
     */
    public function setLogHost($value) {
        $set = webmail_proxy_log_host_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETLOGHOST);
    }
    /**
     * @ignore
     * This function sets the log type for this service
     * @return bool
     *
     * @param $value string Valid values for the 'value' parameter are:
     * "internal"(used at logging in a local file),
     * "system"(used at logging in system log) or
     * "remote"(used at logging on a dedicated logging machine)
     */
    public function setLogType($value) {
        $set = webmail_proxy_log_type_set($this->getWebmailProxyObj() , $value);
        return Debug::checkError($set, 0, Debug::INFOERROR, Message::WMPROXYSETLOGTYPE);
    }
    /**
     * @private
     * This function saves the Webmail Proxy configuration back to Axigen
     * @return bool
     */
    public function save() {
        $save = webmail_proxy_save($this->getWebmailProxyObj() , $this->getSessionObj());
        return Debug::checkError($save, 0, Debug::INFOERROR, Message::WMPROXYSAVE);
    }
    /**
     * This function resets the changes made but not yet saved
     * @return bool
     */
    public function reset() {
        $reset = webmail_proxy_reset($this->getWebmailProxyObj() , $this->getSessionObj());
        return Debug::checkError($reset, 0, Debug::INFOERROR, Message::WMPROXYRESET);
    }
    /**
     * This function starts the Webmail Proxy service
     * @return bool
     */
    public function start() {
        return $this->parent->startService("webmailproxy");
    }
    /**
     * This function stops the Webmail Proxy service
     * @return bool
     */
    public function stop() {
        return $this->parent->stopService("webmailproxy");
    }
    /**
     * This function adds a listener to this service
     * @return bool
     * @param $address string the listener address (ex: 127.0.0.1:25)
     */
    public function addListener($address) {
        $listeners = webmail_proxy_listeners_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WMPROXYGETLISTENERS)) return false;
        $listenerObj = listeners_add($listeners, $this->getSessionObj() , $address);
        if (!Debug::checkError($listenerObj, "_p_listener", Debug::INFOERROR, Message::WMPROXYADDLISTENER)) return false;
        listeners_destroy($listeners);
        return true;
    }
    /**
     * This function removes a listener from this service
     * @return bool
     * @param $address string
     */
    public function removeListener($address) {
        $listeners = webmail_proxy_listeners_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listeners, "_p_listeners", Debug::INFOERROR, Message::WMPROXYGETLISTENERS)) return false;
        $resp = listeners_remove_by_address($listeners, $this->getSessionObj() , $address);
        listeners_destroy($listeners);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::WMPROXYREMOVELISTENER);
    }
    /**
     * This function updates a listener of this service
     * @return objectListener
     * @param $address string
     */
    public function updateListener($address) {
        if (!is_object($this->listener[$address])) {
            $listeners = webmail_proxy_listeners_get($this->getWebmailProxyObj() , $this->getSessionObj());
            if (!Debug::checkError($listeners, "_p_listeners", Debug::FATALERROR, Message::WMPROXYGETLISTENERS)) return false;
            $listenerObj = listeners_get_by_address($listeners, $address);
            if (!Debug::checkError($listenerObj, "_p_listener", Debug::FATALERROR, Message::WMPROXYUPDATELISTENER)) return false;
            $this->listener[$address] = new Listener($listenerObj, $this);
        }
        return $this->listener[$address];
    }
    /**
     * This function lists the listeners for this service
     * @return array
     */
    public function listListeners() {
        $listeners = array();
        $listenersObj = webmail_proxy_listeners_get($this->getWebmailProxyObj() , $this->getSessionObj());
        if (!Debug::checkError($listenersObj, "_p_listeners", Debug::INFOERROR, Message::WMPROXYGETLISTENERS)) return false;
        $listenersIterObj = listener_iterator_begin($listenersObj);
        if (!Debug::checkError($listenersIterObj, "_p_listener_iterator", Debug::INFOERROR, Message::WMPROXYGETLISTENERS)) return false;
        while (listener_iterator_has_value($listenersIterObj)) {
            $listenerObj = listener_iterator_value($listenersIterObj);
            unset($tmp);
            if (listener_enable_get($listenerObj) == 1) $tmp['enabled'] = true;
            else $tmp['enabled'] = false;
            $tmp['address'] = listener_address_get($listenerObj);
            array_push($listeners, $tmp);
            listener_iterator_next($listenersIterObj);
        }
        listener_iterator_destroy($listenersIterObj);
        listeners_destroy($listenersObj);
        return $listeners;
    }
    /**
     * This function returns an access control object for this service
     * @return object AccessControl
     */
    public function configAccessControl() {
        if (!is_object($this->accesscontrol)) {
            $accesscontrolObj = webmail_proxy_get_access_control($this->getWebmailProxyObj() , $this->getSessionObj());
            if (!Debug::checkError($accesscontrolObj, "_p_access_control", Debug::FATALERROR, Message::WMPROXYACCESSCONTROL)) return false;
            $this->accesscontrol = new AccessControl($accesscontrolObj, $this);
        }
        return $this->accesscontrol;
    }
    /**
     * This function adds a hostname resolver. This maps a hostname to a domain
     *
     * @param $host string hostname
     * @param $domain string domain name
     *
     * @return bool
     */
    public function addHostNameResolver($host, $domain) {
        $add = webmail_proxy_hostname_resolver_add($this->getWebmailProxyObj() , $host, $domain);
        if (!Debug::checkError($add, '_p_hostname_resolver', Debug::INFOERROR, Message::WEBMAILPROXYADDHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This method lists the hostname resolvers
     *
     * @return array
     */
    public function listHostNameResolvers() {
        $hostnameResolverIterObj = webmail_proxy_hostname_resolver_iterator_begin($this->getWebmailProxyObj());
        if (!Debug::checkError($hostnameResolverIterObj, "_p_webmail_proxy_hostname_resolver_iterator", Debug::INFOERROR, Message::WEBMAILPROXYLISTHOSTNAMERESOLVER)) return false;
        $hostnameResolverList = array();
        while (webmail_proxy_hostname_resolver_iterator_has_value($hostnameResolverIterObj)) {
            $hostnameResolverTmp = array();
            $hostnameResolverObj = webmail_proxy_hostname_resolver_iterator_value($hostnameResolverIterObj);
            $hostnameResolverTmp['domain'] = hostname_resolver_domain_get($hostnameResolverObj);
            $hostnameResolverTmp['host'] = hostname_resolver_host_get($hostnameResolverObj);
            array_push($hostnameResolverList, $hostnameResolverTmp);
            webmail_proxy_hostname_resolver_iterator_next($hostnameResolverIterObj);
        }
        webmail_proxy_hostname_resolver_iterator_destroy($hostnameResolverIterObj);
        return $hostnameResolverList;
    }
    /**
     * This function changes the hostname resolver that matches the given host
     * @param $hostname string the hostname
     * @param $newDomain string the new domain value
     * @return bool
     */
    public function updateHostNameResolver($hostname, $newDomain) {
        $update = webmail_proxy_hostname_resolver_change_by_host($this->getWebmailProxyObj() , $hostname, $newDomain);
        if (!Debug::checkError($update, 0, Debug::INFOERROR, Message::WEBMAILPROXYUPDATEHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This function removes the hostname resolver that matches the given host
     * @param $hostname string the hostname
     * @return bool
     */
    public function removeHostNameResolver($hostname) {
        $remove = webmail_proxy_hostname_resolver_remove_by_host($this->getWebmailProxyObj() , $hostname);
        if (!Debug::checkError($remove, 0, Debug::INFOERROR, Message::WEBMAILPROXYREMOVEHOSTNAMERESOLVER)) return false;
        return $this->save();
    }
    /**
     * This function adds a URL redirect. This can be used to redirect request for a specific host to another address.
     * @param $address string the address ex. 127.0.0.1:8000
     * @param $host string the hostname
     * @param $port int the port number
     * @return bool
     */
    public function addUrlRedirect($address, $host, $port) {
        $add = webmail_proxy_url_redirect_add($this->getWebmailProxyObj() , $address, $port, $host);
        if (!Debug::checkError($add, '_p_url_redirect', Debug::INFOERROR, Message::WEBMAILPROXYADDURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * This method lists the URL redirects
     * @return array
     */
    public function listUrlRedirects() {
        $urlRedirectIterObj = webmail_proxy_url_redirect_iterator_begin($this->getWebmailProxyObj());
        if (!Debug::checkError($urlRedirectIterObj, "_p_webmail_proxy_url_redirect_iterator", Debug::INFOERROR, Message::WEBMAILPROXYLISTURLREDIRECT)) return false;
        $urlRedirectList = array();
        while (webmail_proxy_url_redirect_iterator_has_value($urlRedirectIterObj)) {
            $urlRedirectTmp = array();
            $urlRedirectObj = webmail_proxy_url_redirect_iterator_value($urlRedirectIterObj);
            $urlRedirectTmp['address'] = url_redirect_address_get($urlRedirectObj);
            $urlRedirectTmp['host'] = url_redirect_host_get($urlRedirectObj);
            $urlRedirectTmp['port'] = url_redirect_port_get($urlRedirectObj);
            array_push($urlRedirectList, $urlRedirectTmp);
            webmail_proxy_url_redirect_iterator_next($urlRedirectIterObj);
        }
        webmail_proxy_url_redirect_iterator_destroy($urlRedirectIterObj);
        return $urlRedirectList;
    }
    /**
     * This function removes an URL redirect with the specified address
     * @param $address string the address of the URL redirect
     * @return bool
     */
    public function removeUrlRedirect($address) {
        $remove = webmail_proxy_url_redirect_remove_by_address($this->getWebmailProxyObj() , $address);
        if (!Debug::checkError($remove, 0, Debug::INFOERROR, Message::WEBMAILPROXYREMOVEURLREDIRECT)) return false;
        return $this->save();
    }
    /**
     * This function changes an existing URL redirect, changing its host and port
     * @param $address string the address of the url redirect
     * @param $newHost string the new host value
     * @param $newPort int the new port value
     * @return bool
     */
    public function updateUrlRedirect($address, $newHost, $newPort) {
        $urlRedirect = webmail_proxy_url_redirect_get_by_address($this->getWebmailProxyObj() , $address);
        if (Debug::checkError($urlRedirect, '_p_url_redirect', Debug::INFOERROR, Message::WEBMAILPROXYUPDATEURLREDIRECT)) {
            $change = webmail_proxy_url_redirect_change($urlRedirect, $newHost, $newPort);
            if (!Debug::checkError($change, 0, Debug::INFOERROR, Message::WEBMAILPROXYUPDATEURLREDIRECT)) return false;
            return $this->save();
        }
        return false;
    }
}
/** @} */ // end of group
?>
